@@ -58,9 +58,9 @@ import org.apache.commons.configuration2.ex.ConfigurationRuntimeException;
  * data delegate to the list of child configurations, the thread-safety of a {@code CompositeConfiguration} object also
  * depends on the {@code Synchronizer} objects used by these children.
  * </p>
- *
  */
 public class CompositeConfiguration extends AbstractConfiguration implements Cloneable {
+
     /** List holding all the configuration */
     private List<Configuration> configList = new LinkedList<>();
 
@@ -81,6 +81,16 @@ public class CompositeConfiguration extends AbstractConfiguration implements Clo
         clear();
     }
 
+    /**
+     * Create a CompositeConfiguration with an empty in memory configuration and adds the collection of configurations
+     * specified.
+     *
+     * @param configurations the collection of configurations to add
+     */
+    public CompositeConfiguration(final Collection<? extends Configuration> configurations) {
+        this(new BaseConfiguration(), configurations);
+    }
+
     /**
      * Creates a CompositeConfiguration object with a specified <em>in-memory configuration</em>. This configuration will
      * store any changes made to the {@code CompositeConfiguration}. Note: Use this constructor if you want to set a special
@@ -90,19 +100,9 @@ public class CompositeConfiguration extends AbstractConfiguration implements Clo
      * @param inMemoryConfiguration the in memory configuration to use
      */
     public CompositeConfiguration(final Configuration inMemoryConfiguration) {
-        configList.clear();
+        this.configList.clear();
         this.inMemoryConfiguration = inMemoryConfiguration;
-        configList.add(inMemoryConfiguration);
-    }
-
-    /**
-     * Create a CompositeConfiguration with an empty in memory configuration and adds the collection of configurations
-     * specified.
-     *
-     * @param configurations the collection of configurations to add
-     */
-    public CompositeConfiguration(final Collection<? extends Configuration> configurations) {
-        this(new BaseConfiguration(), configurations);
+        this.configList.add(inMemoryConfiguration);
     }
 
     /**
@@ -115,11 +115,8 @@ public class CompositeConfiguration extends AbstractConfiguration implements Clo
      */
     public CompositeConfiguration(final Configuration inMemoryConfiguration, final Collection<? extends Configuration> configurations) {
         this(inMemoryConfiguration);
-
         if (configurations != null) {
-            for (final Configuration c : configurations) {
-                addConfiguration(c);
-            }
+            configurations.forEach(this::addConfiguration);
         }
     }
 
@@ -216,34 +213,33 @@ public class CompositeConfiguration extends AbstractConfiguration implements Clo
     }
 
     /**
-     * Remove a configuration. The in memory configuration cannot be removed.
+     * Add this property to the in-memory Configuration.
      *
-     * @param config The configuration to remove
+     * @param key The Key to add the property to.
+     * @param token The Value to add.
      */
-    public void removeConfiguration(final Configuration config) {
-        beginWrite(false);
-        try {
-            // Make sure that you can't remove the inMemoryConfiguration from
-            // the CompositeConfiguration object
-            if (!config.equals(inMemoryConfiguration)) {
-                configList.remove(config);
-            }
-        } finally {
-            endWrite();
-        }
+    @Override
+    protected void addPropertyDirect(final String key, final Object token) {
+        inMemoryConfiguration.addProperty(key, token);
     }
 
     /**
-     * Return the number of configurations.
+     * Adds the value of a property to the given list. This method is used by {@code getList()} for gathering property
+     * values from the child configurations.
      *
-     * @return the number of configuration
+     * @param dest the list for collecting the data
+     * @param config the configuration to query
+     * @param key the key of the property
      */
-    public int getNumberOfConfigurations() {
-        beginRead(false);
-        try {
-            return configList.size();
-        } finally {
-            endRead();
+    private void appendListProperty(final List<Object> dest, final Configuration config, final String key) {
+        final Object value = interpolate(config.getProperty(key));
+        if (value != null) {
+            if (value instanceof Collection) {
+                final Collection<?> col = (Collection<?>) value;
+                dest.addAll(col);
+            } else {
+                dest.add(value);
+            }
         }
     }
 
@@ -262,92 +258,99 @@ public class CompositeConfiguration extends AbstractConfiguration implements Clo
         inMemoryConfigIsChild = false;
     }
 
-    /**
-     * Add this property to the in-memory Configuration.
-     *
-     * @param key The Key to add the property to.
-     * @param token The Value to add.
-     */
     @Override
-    protected void addPropertyDirect(final String key, final Object token) {
-        inMemoryConfiguration.addProperty(key, token);
+    protected void clearPropertyDirect(final String key) {
+        configList.forEach(config -> config.clearProperty(key));
     }
 
     /**
-     * Read property from underlying composite
+     * Returns a copy of this object. This implementation will create a deep clone, i.e. all configurations contained in
+     * this composite will also be cloned. This only works if all contained configurations support cloning; otherwise a
+     * runtime exception will be thrown. Registered event handlers won't get cloned.
      *
-     * @param key key to use for mapping
-     *
-     * @return object associated with the given configuration key.
+     * @return the copy
+     * @since 1.3
      */
     @Override
-    protected Object getPropertyInternal(final String key) {
-        Configuration firstMatchingConfiguration = null;
-        for (final Configuration config : configList) {
-            if (config.containsKey(key)) {
-                firstMatchingConfiguration = config;
-                break;
-            }
-        }
+    public Object clone() {
+        try {
+            final CompositeConfiguration copy = (CompositeConfiguration) super.clone();
+            copy.configList = new LinkedList<>();
+            copy.inMemoryConfiguration = ConfigurationUtils.cloneConfiguration(getInMemoryConfiguration());
+            copy.configList.add(copy.inMemoryConfiguration);
 
-        if (firstMatchingConfiguration != null) {
-            return firstMatchingConfiguration.getProperty(key);
+            configList.forEach(config -> {
+                if (config != getInMemoryConfiguration()) {
+                    copy.addConfiguration(ConfigurationUtils.cloneConfiguration(config));
+                }
+            });
+
+            copy.cloneInterpolator(this);
+            return copy;
+        } catch (final CloneNotSupportedException cnex) {
+            // cannot happen
+            throw new ConfigurationRuntimeException(cnex);
+        }
+    }
+
+    @Override
+    protected boolean containsKeyInternal(final String key) {
+        return configList.stream().anyMatch(config -> config.containsKey(key));
+    }
+
+    /**
+     * Tests whether this configuration contains one or more matches to this value. This operation stops at first
+     * match but may be more expensive than the containsKey method.
+     * @since 2.11.0
+     */
+    @Override
+    protected boolean containsValueInternal(final Object value) {
+        return configList.stream().anyMatch(config -> config.containsValue(value));
+    }
+
+    /**
+     * Gets the configuration at the specified index.
+     *
+     * @param index The index of the configuration to retrieve
+     * @return the configuration at this index
+     */
+    public Configuration getConfiguration(final int index) {
+        beginRead(false);
+        try {
+            return configList.get(index);
+        } finally {
+            endRead();
+        }
+    }
+
+    /**
+     * Gets the &quot;in memory configuration&quot;. In this configuration changes are stored.
+     *
+     * @return the in memory configuration
+     */
+    public Configuration getInMemoryConfiguration() {
+        beginRead(false);
+        try {
+            return inMemoryConfiguration;
+        } finally {
+            endRead();
         }
-        return null;
     }
 
     @Override
     protected Iterator<String> getKeysInternal() {
         final Set<String> keys = new LinkedHashSet<>();
-        for (final Configuration config : configList) {
-            for (final Iterator<String> it = config.getKeys(); it.hasNext();) {
-                keys.add(it.next());
-            }
-        }
-
+        configList.forEach(config -> config.getKeys().forEachRemaining(keys::add));
         return keys.iterator();
     }
 
     @Override
     protected Iterator<String> getKeysInternal(final String key) {
         final Set<String> keys = new LinkedHashSet<>();
-        for (final Configuration config : configList) {
-            for (final Iterator<String> it = config.getKeys(key); it.hasNext();) {
-                keys.add(it.next());
-            }
-        }
-
+        configList.forEach(config -> config.getKeys(key).forEachRemaining(keys::add));
         return keys.iterator();
     }
 
-    @Override
-    protected boolean isEmptyInternal() {
-        for (final Configuration config : configList) {
-            if (!config.isEmpty()) {
-                return false;
-            }
-        }
-
-        return true;
-    }
-
-    @Override
-    protected void clearPropertyDirect(final String key) {
-        for (final Configuration config : configList) {
-            config.clearProperty(key);
-        }
-    }
-
-    @Override
-    protected boolean containsKeyInternal(final String key) {
-        for (final Configuration config : configList) {
-            if (config.containsKey(key)) {
-                return true;
-            }
-        }
-        return false;
-    }
-
     @Override
     public List<Object> getList(final String key, final List<?> defaultValue) {
         final List<Object> list = new ArrayList<>();
@@ -379,92 +382,34 @@ public class CompositeConfiguration extends AbstractConfiguration implements Clo
         return list;
     }
 
-    @Override
-    public String[] getStringArray(final String key) {
-        final List<Object> list = getList(key);
-
-        // transform property values into strings
-        final String[] tokens = new String[list.size()];
-
-        for (int i = 0; i < tokens.length; i++) {
-            tokens[i] = String.valueOf(list.get(i));
-        }
-
-        return tokens;
-    }
-
     /**
-     * Return the configuration at the specified index.
+     * Gets the number of configurations.
      *
-     * @param index The index of the configuration to retrieve
-     * @return the configuration at this index
+     * @return the number of configuration
      */
-    public Configuration getConfiguration(final int index) {
+    public int getNumberOfConfigurations() {
         beginRead(false);
         try {
-            return configList.get(index);
+            return configList.size();
         } finally {
             endRead();
         }
     }
 
     /**
-     * Returns the &quot;in memory configuration&quot;. In this configuration changes are stored.
+     * Read property from underlying composite
      *
-     * @return the in memory configuration
-     */
-    public Configuration getInMemoryConfiguration() {
-        beginRead(false);
-        try {
-            return inMemoryConfiguration;
-        } finally {
-            endRead();
-        }
-    }
-
-    /**
-     * Returns a copy of this object. This implementation will create a deep clone, i.e. all configurations contained in
-     * this composite will also be cloned. This only works if all contained configurations support cloning; otherwise a
-     * runtime exception will be thrown. Registered event handlers won't get cloned.
+     * @param key key to use for mapping
      *
-     * @return the copy
-     * @since 1.3
+     * @return object associated with the given configuration key.
      */
     @Override
-    public Object clone() {
-        try {
-            final CompositeConfiguration copy = (CompositeConfiguration) super.clone();
-            copy.configList = new LinkedList<>();
-            copy.inMemoryConfiguration = ConfigurationUtils.cloneConfiguration(getInMemoryConfiguration());
-            copy.configList.add(copy.inMemoryConfiguration);
-
-            for (final Configuration config : configList) {
-                if (config != getInMemoryConfiguration()) {
-                    copy.addConfiguration(ConfigurationUtils.cloneConfiguration(config));
-                }
-            }
-
-            copy.cloneInterpolator(this);
-            return copy;
-        } catch (final CloneNotSupportedException cnex) {
-            // cannot happen
-            throw new ConfigurationRuntimeException(cnex);
-        }
+    protected Object getPropertyInternal(final String key) {
+        return configList.stream().filter(config -> config.containsKey(key)).findFirst().map(config -> config.getProperty(key)).orElse(null);
     }
 
     /**
-     * {@inheritDoc} This implementation ensures that the in memory configuration is correctly initialized.
-     */
-    @Override
-    public void setListDelimiterHandler(final ListDelimiterHandler listDelimiterHandler) {
-        if (inMemoryConfiguration instanceof AbstractConfiguration) {
-            ((AbstractConfiguration) inMemoryConfiguration).setListDelimiterHandler(listDelimiterHandler);
-        }
-        super.setListDelimiterHandler(listDelimiterHandler);
-    }
-
-    /**
-     * Returns the configuration source, in which the specified key is defined. This method will iterate over all existing
+     * Gets the configuration source, in which the specified key is defined. This method will iterate over all existing
      * child configurations and check whether they contain the specified key. The following constellations are possible:
      * <ul>
      * <li>If exactly one child configuration contains the key, this configuration is returned as the source configuration.
@@ -497,6 +442,43 @@ public class CompositeConfiguration extends AbstractConfiguration implements Clo
         return source;
     }
 
+    @Override
+    public String[] getStringArray(final String key) {
+        final List<Object> list = getList(key);
+
+        // transform property values into strings
+        final String[] tokens = new String[list.size()];
+
+        for (int i = 0; i < tokens.length; i++) {
+            tokens[i] = String.valueOf(list.get(i));
+        }
+
+        return tokens;
+    }
+
+    @Override
+    protected boolean isEmptyInternal() {
+        return configList.stream().allMatch(Configuration::isEmpty);
+    }
+
+    /**
+     * Remove a configuration. The in memory configuration cannot be removed.
+     *
+     * @param config The configuration to remove
+     */
+    public void removeConfiguration(final Configuration config) {
+        beginWrite(false);
+        try {
+            // Make sure that you can't remove the inMemoryConfiguration from
+            // the CompositeConfiguration object
+            if (!config.equals(inMemoryConfiguration)) {
+                configList.remove(config);
+            }
+        } finally {
+            endWrite();
+        }
+    }
+
     /**
      * Replaces the current in-memory configuration by the given one.
      *
@@ -511,22 +493,13 @@ public class CompositeConfiguration extends AbstractConfiguration implements Clo
     }
 
     /**
-     * Adds the value of a property to the given list. This method is used by {@code getList()} for gathering property
-     * values from the child configurations.
-     *
-     * @param dest the list for collecting the data
-     * @param config the configuration to query
-     * @param key the key of the property
+     * {@inheritDoc} This implementation ensures that the in memory configuration is correctly initialized.
      */
-    private void appendListProperty(final List<Object> dest, final Configuration config, final String key) {
-        final Object value = interpolate(config.getProperty(key));
-        if (value != null) {
-            if (value instanceof Collection) {
-                final Collection<?> col = (Collection<?>) value;
-                dest.addAll(col);
-            } else {
-                dest.add(value);
-            }
+    @Override
+    public void setListDelimiterHandler(final ListDelimiterHandler listDelimiterHandler) {
+        if (inMemoryConfiguration instanceof AbstractConfiguration) {
+            ((AbstractConfiguration) inMemoryConfiguration).setListDelimiterHandler(listDelimiterHandler);
         }
+        super.setListDelimiterHandler(listDelimiterHandler);
     }
 }
