@@ -50,71 +50,27 @@ public class ConfigurationDeclaration extends XMLBeanDeclaration {
     }
 
     /**
-     * Returns the associated configuration builder.
-     *
-     * @return the configuration builder
-     */
-    public CombinedConfigurationBuilder getConfigurationBuilder() {
-        return configurationBuilder;
-    }
-
-    /**
-     * Returns the value of the {@code at} attribute.
+     * Gets the value of the {@code at} attribute.
      *
      * @return the value of the {@code at} attribute (can be <b>null</b>)
      */
     public String getAt() {
-        final String result = this.getConfiguration().getString(CombinedConfigurationBuilder.ATTR_AT_RES);
-        return result == null ? this.getConfiguration().getString(CombinedConfigurationBuilder.ATTR_AT) : result;
+        final String result = getConfiguration().getString(CombinedConfigurationBuilder.ATTR_AT_RES);
+        return result == null ? getConfiguration().getString(CombinedConfigurationBuilder.ATTR_AT) : result;
     }
 
     /**
-     * Returns a flag whether this is an optional configuration.
+     * Gets the bean's class name. This implementation will always return <b>null</b>.
      *
-     * @return a flag if this declaration points to an optional configuration
+     * @return the name of the bean's class
      */
-    public boolean isOptional() {
-        Boolean value = this.getConfiguration().getBoolean(CombinedConfigurationBuilder.ATTR_OPTIONAL_RES, null);
-        if (value == null) {
-            value = this.getConfiguration().getBoolean(CombinedConfigurationBuilder.ATTR_OPTIONAL, Boolean.FALSE);
-        }
-        return value.booleanValue();
+    @Override
+    public String getBeanClassName() {
+        return null;
     }
 
     /**
-     * Returns a flag whether this configuration should always be created and added to the resulting combined configuration.
-     * This flag is evaluated only for optional configurations whose normal creation has caused an error. If for such a
-     * configuration the {@code forceCreate} attribute is set and the corresponding configuration provider supports this
-     * mode, an empty configuration will be created and added to the resulting combined configuration.
-     *
-     * @return the value of the {@code forceCreate} attribute
-     */
-    public boolean isForceCreate() {
-        return this.getConfiguration().getBoolean(CombinedConfigurationBuilder.ATTR_FORCECREATE, false);
-    }
-
-    /**
-     * Returns a flag whether a builder with reloading support should be created. This may not be supported by all
-     * configuration builder providers.
-     *
-     * @return a flag whether a reloading builder should be created
-     */
-    public boolean isReload() {
-        return getConfiguration().getBoolean(CombinedConfigurationBuilder.ATTR_RELOAD, false);
-    }
-
-    /**
-     * Returns the name for the represented configuration source. The name is optional, so this method can return
-     * <b>null</b>.
-     *
-     * @return the name of the associated configuration source or <b>null</b>
-     */
-    public String getName() {
-        return getConfiguration().getString(CombinedConfigurationBuilder.ATTR_NAME);
-    }
-
-    /**
-     * Returns the name of the bean factory. For configuration source declarations always a reserved factory is used. This
+     * Gets the name of the bean factory. For configuration source declarations always a reserved factory is used. This
      * factory's name is returned by this implementation.
      *
      * @return the name of the bean factory
@@ -125,13 +81,57 @@ public class ConfigurationDeclaration extends XMLBeanDeclaration {
     }
 
     /**
-     * Returns the bean's class name. This implementation will always return <b>null</b>.
+     * Gets the associated configuration builder.
      *
-     * @return the name of the bean's class
+     * @return the configuration builder
      */
-    @Override
-    public String getBeanClassName() {
-        return null;
+    public CombinedConfigurationBuilder getConfigurationBuilder() {
+        return configurationBuilder;
+    }
+
+    /**
+     * Gets the name for the represented configuration source. The name is optional, so this method can return
+     * <b>null</b>.
+     *
+     * @return the name of the associated configuration source or <b>null</b>
+     */
+    public String getName() {
+        return getConfiguration().getString(CombinedConfigurationBuilder.ATTR_NAME);
+    }
+
+    /**
+     * Gets a flag whether this configuration should always be created and added to the resulting combined configuration.
+     * This flag is evaluated only for optional configurations whose normal creation has caused an error. If for such a
+     * configuration the {@code forceCreate} attribute is set and the corresponding configuration provider supports this
+     * mode, an empty configuration will be created and added to the resulting combined configuration.
+     *
+     * @return the value of the {@code forceCreate} attribute
+     */
+    public boolean isForceCreate() {
+        return getConfiguration().getBoolean(CombinedConfigurationBuilder.ATTR_FORCECREATE, false);
+    }
+
+    /**
+     * Gets a flag whether this is an optional configuration.
+     *
+     * @return a flag if this declaration points to an optional configuration
+     */
+    public boolean isOptional() {
+        Boolean value = getConfiguration().getBoolean(CombinedConfigurationBuilder.ATTR_OPTIONAL_RES, null);
+        if (value == null) {
+            value = getConfiguration().getBoolean(CombinedConfigurationBuilder.ATTR_OPTIONAL, Boolean.FALSE);
+        }
+        return value.booleanValue();
+    }
+
+    /**
+     * Returns a flag whether a builder with reloading support should be created. This may not be supported by all
+     * configuration builder providers.
+     *
+     * @return a flag whether a reloading builder should be created
+     */
+    public boolean isReload() {
+        return getConfiguration().getBoolean(CombinedConfigurationBuilder.ATTR_RELOAD, false);
     }
 
     /**
@@ -148,8 +148,8 @@ public class ConfigurationDeclaration extends XMLBeanDeclaration {
         }
 
         final Set<String> attributes = getAttributeNames();
-        return (CombinedConfigurationBuilder.ATTR_ATNAME.equals(name) && !attributes.contains(RESERVED_PREFIX + CombinedConfigurationBuilder.ATTR_ATNAME))
-            || (CombinedConfigurationBuilder.ATTR_OPTIONALNAME.equals(name)
-                && !attributes.contains(RESERVED_PREFIX + CombinedConfigurationBuilder.ATTR_OPTIONALNAME));
+        return CombinedConfigurationBuilder.ATTR_ATNAME.equals(name) && !attributes.contains(RESERVED_PREFIX + CombinedConfigurationBuilder.ATTR_ATNAME)
+            || CombinedConfigurationBuilder.ATTR_OPTIONALNAME.equals(name)
+                && !attributes.contains(RESERVED_PREFIX + CombinedConfigurationBuilder.ATTR_OPTIONALNAME);
     }
 }
