@@ -17,10 +17,12 @@
 package org.apache.commons.configuration2.convert;
 
 import java.lang.reflect.Array;
+import java.nio.file.Path;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Iterator;
 import java.util.LinkedList;
+import java.util.Set;
 
 /**
  * <p>
@@ -36,6 +38,84 @@ import java.util.LinkedList;
  * @since 2.0
  */
 public abstract class AbstractListDelimiterHandler implements ListDelimiterHandler {
+
+    static Collection<?> flatten(final ListDelimiterHandler handler, final Object value, final int limit, final Set<Object> dejaVu) {
+        dejaVu.add(value);
+        if (value instanceof String) {
+            return handler.split((String) value, true);
+        }
+        final Collection<Object> result = new LinkedList<>();
+        if (value instanceof Path) {
+            // Don't handle as an Iterable.
+            result.add(value);
+        } else if (value instanceof Iterable) {
+            flattenIterator(handler, result, ((Iterable<?>) value).iterator(), limit, dejaVu);
+        } else if (value instanceof Iterator) {
+            flattenIterator(handler, result, (Iterator<?>) value, limit, dejaVu);
+        } else if (value != null) {
+            if (value.getClass().isArray()) {
+                for (int len = Array.getLength(value), idx = 0, size = 0; idx < len && size < limit; idx++, size = result.size()) {
+                    result.addAll(handler.flatten(Array.get(value, idx), limit - size));
+                }
+            } else {
+                result.add(value);
+            }
+        }
+        return result;
+    }
+
+    /**
+     * Flattens the given iterator. For each element in the iteration {@code flatten()} is called recursively.
+     *
+     * @param handler the working handler
+     * @param target the target collection
+     * @param iterator the iterator to process
+     * @param limit a limit for the number of elements to extract
+     * @param dejaVue Previously visited objects.
+     */
+    static void flattenIterator(final ListDelimiterHandler handler, final Collection<Object> target, final Iterator<?> iterator, final int limit,
+            final Set<Object> dejaVue) {
+        int size = target.size();
+        while (size < limit && iterator.hasNext()) {
+            final Object next = iterator.next();
+            if (!dejaVue.contains(next)) {
+                target.addAll(flatten(handler, next, limit - size, dejaVue));
+                size = target.size();
+            }
+        }
+    }
+
+    /**
+     * {@inheritDoc} This implementation checks whether the object to be escaped is a string. If yes, it delegates to
+     * {@link #escapeString(String)}, otherwise no escaping is performed. Eventually, the passed in transformer is invoked
+     * so that additional encoding can be performed.
+     */
+    @Override
+    public Object escape(final Object value, final ValueTransformer transformer) {
+        return transformer.transformValue(value instanceof String ? escapeString((String) value) : value);
+    }
+
+    /**
+     * Escapes the specified string. This method is called by {@code escape()} if the passed in object is a string. Concrete
+     * subclasses have to implement their specific escaping logic here, so that the list delimiters they support are
+     * properly escaped.
+     *
+     * @param s the string to be escaped (not <b>null</b>)
+     * @return the escaped string
+     */
+    protected abstract String escapeString(String s);
+
+    /**
+     * Performs the actual work as advertised by the {@code parse()} method. This method delegates to
+     * {@link #flatten(Object, int)} without specifying a limit.
+     *
+     * @param value the value to be processed
+     * @return a &quot;flat&quot; collection containing all primitive values of the passed in object
+     */
+    private Collection<?> flatten(final Object value) {
+        return flatten(value, Integer.MAX_VALUE);
+    }
+
     /**
      * {@inheritDoc} Depending on the type of the passed in object the following things happen:
      * <ul>
@@ -60,21 +140,7 @@ public abstract class AbstractListDelimiterHandler implements ListDelimiterHandl
      */
     @Override
     public Collection<String> split(final String s, final boolean trim) {
-        if (s == null) {
-            return new ArrayList<>(0);
-        }
-        return splitString(s, trim);
-    }
-
-    /**
-     * {@inheritDoc} This implementation checks whether the object to be escaped is a string. If yes, it delegates to
-     * {@link #escapeString(String)}, otherwise no escaping is performed. Eventually, the passed in transformer is invoked
-     * so that additional encoding can be performed.
-     */
-    @Override
-    public Object escape(final Object value, final ValueTransformer transformer) {
-        final Object escValue = value instanceof String ? escapeString((String) value) : value;
-        return transformer.transformValue(escValue);
+        return s == null ? new ArrayList<>(0) : splitString(s, trim);
     }
 
     /**
@@ -86,74 +152,4 @@ public abstract class AbstractListDelimiterHandler implements ListDelimiterHandl
      * @return a collection with the extracted components of the passed in string
      */
     protected abstract Collection<String> splitString(String s, boolean trim);
-
-    /**
-     * Escapes the specified string. This method is called by {@code escape()} if the passed in object is a string. Concrete
-     * subclasses have to implement their specific escaping logic here, so that the list delimiters they support are
-     * properly escaped.
-     *
-     * @param s the string to be escaped (not <b>null</b>)
-     * @return the escaped string
-     */
-    protected abstract String escapeString(String s);
-
-    /**
-     * Extracts all values contained in the specified object up to the given limit. The passed in object is evaluated (if
-     * necessary in a recursive way). If it is a complex object (e.g. a collection or an array), all its elements are
-     * processed recursively and added to a target collection. The process stops if the limit is reached, but depending on
-     * the input object, it might be exceeded. (The limit is just an indicator to stop the process to avoid unnecessary work
-     * if the caller is only interested in a few values.)
-     *
-     * @param value the value to be processed
-     * @param limit the limit for aborting the processing
-     * @return a &quot;flat&quot; collection containing all primitive values of the passed in object
-     */
-    Collection<?> flatten(final Object value, final int limit) {
-        if (value instanceof String) {
-            return split((String) value, true);
-        }
-
-        final Collection<Object> result = new LinkedList<>();
-        if (value instanceof Iterable) {
-            flattenIterator(result, ((Iterable<?>) value).iterator(), limit);
-        } else if (value instanceof Iterator) {
-            flattenIterator(result, (Iterator<?>) value, limit);
-        } else if (value != null) {
-            if (value.getClass().isArray()) {
-                for (int len = Array.getLength(value), idx = 0, size = 0; idx < len && size < limit; idx++, size = result.size()) {
-                    result.addAll(flatten(Array.get(value, idx), limit - size));
-                }
-            } else {
-                result.add(value);
-            }
-        }
-
-        return result;
-    }
-
-    /**
-     * Performs the actual work as advertised by the {@code parse()} method. This method delegates to
-     * {@link #flatten(Object, int)} without specifying a limit.
-     *
-     * @param value the value to be processed
-     * @return a &quot;flat&quot; collection containing all primitive values of the passed in object
-     */
-    private Collection<?> flatten(final Object value) {
-        return flatten(value, Integer.MAX_VALUE);
-    }
-
-    /**
-     * Flattens the given iterator. For each element in the iteration {@code flatten()} is called recursively.
-     *
-     * @param target the target collection
-     * @param it the iterator to process
-     * @param limit a limit for the number of elements to extract
-     */
-    private void flattenIterator(final Collection<Object> target, final Iterator<?> it, final int limit) {
-        int size = target.size();
-        while (size < limit && it.hasNext()) {
-            target.addAll(flatten(it.next(), limit - size));
-            size = target.size();
-        }
-    }
 }
