@@ -42,37 +42,20 @@ import java.util.Objects;
  */
 public class MergeCombiner extends NodeCombiner {
     /**
-     * Combines the given nodes to a new union node.
+     * Checks whether the attributes of the passed in node are compatible.
      *
-     * @param node1 the first source node
-     * @param node2 the second source node
-     * @return the union node
+     * @param attrs1 the attributes of the first node
+     * @param node the 2nd node
+     * @return a flag whether these nodes can be combined regarding their attributes
      */
-
-    @Override
-    public ImmutableNode combine(final ImmutableNode node1, final ImmutableNode node2) {
-        final ImmutableNode.Builder result = new ImmutableNode.Builder();
-        result.name(node1.getNodeName());
-        result.value(node1.getValue());
-        addAttributes(result, node1, node2);
-
-        // Check if nodes can be combined
-        final List<ImmutableNode> children2 = new LinkedList<>(node2.getChildren());
-        for (final ImmutableNode child1 : node1) {
-            final ImmutableNode child2 = canCombine(node2, child1, children2);
-            if (child2 != null) {
-                result.addChild(combine(child1, child2));
-                children2.remove(child2);
-            } else {
-                result.addChild(child1);
+    private static boolean matchAttributes(final Map<String, Object> attrs1, final ImmutableNode node) {
+        final Map<String, Object> attrs2 = node.getAttributes();
+        for (final Map.Entry<String, Object> e : attrs1.entrySet()) {
+            if (attrs2.containsKey(e.getKey()) && !Objects.equals(e.getValue(), attrs2.get(e.getKey()))) {
+                return false;
             }
         }
-
-        // Add remaining children of node 2
-        for (final ImmutableNode c : children2) {
-            result.addChild(c);
-        }
-        return result.create();
+        return true;
     }
 
     /**
@@ -85,11 +68,7 @@ public class MergeCombiner extends NodeCombiner {
      */
     protected void addAttributes(final ImmutableNode.Builder result, final ImmutableNode node1, final ImmutableNode node2) {
         final Map<String, Object> attributes = new HashMap<>(node1.getAttributes());
-        for (final Map.Entry<String, Object> e : node2.getAttributes().entrySet()) {
-            if (!attributes.containsKey(e.getKey())) {
-                attributes.put(e.getKey(), e.getValue());
-            }
-        }
+        node2.getAttributes().forEach(attributes::putIfAbsent);
         result.addAttributes(attributes);
     }
 
@@ -107,38 +86,51 @@ public class MergeCombiner extends NodeCombiner {
         final List<ImmutableNode> nodes = new ArrayList<>();
 
         final List<ImmutableNode> children = HANDLER.getChildren(node2, child.getNodeName());
-        for (final ImmutableNode node : children) {
+        children.forEach(node -> {
             if (matchAttributes(attrs1, node)) {
                 nodes.add(node);
             }
-        }
+        });
 
         if (nodes.size() == 1) {
             return nodes.get(0);
         }
         if (nodes.size() > 1 && !isListNode(child)) {
-            for (final ImmutableNode node : nodes) {
-                children2.remove(node);
-            }
+            nodes.forEach(children2::remove);
         }
 
         return null;
     }
 
     /**
-     * Checks whether the attributes of the passed in node are compatible.
+     * Combines the given nodes to a new union node.
      *
-     * @param attrs1 the attributes of the first node
-     * @param node the 2nd node
-     * @return a flag whether these nodes can be combined regarding their attributes
+     * @param node1 the first source node
+     * @param node2 the second source node
+     * @return the union node
      */
-    private static boolean matchAttributes(final Map<String, Object> attrs1, final ImmutableNode node) {
-        final Map<String, Object> attrs2 = node.getAttributes();
-        for (final Map.Entry<String, Object> e : attrs1.entrySet()) {
-            if (attrs2.containsKey(e.getKey()) && !Objects.equals(e.getValue(), attrs2.get(e.getKey()))) {
-                return false;
+
+    @Override
+    public ImmutableNode combine(final ImmutableNode node1, final ImmutableNode node2) {
+        final ImmutableNode.Builder result = new ImmutableNode.Builder();
+        result.name(node1.getNodeName());
+        result.value(node1.getValue());
+        addAttributes(result, node1, node2);
+
+        // Check if nodes can be combined
+        final List<ImmutableNode> children2 = new LinkedList<>(node2.getChildren());
+        node1.forEach(child1 -> {
+            final ImmutableNode child2 = canCombine(node2, child1, children2);
+            if (child2 != null) {
+                result.addChild(combine(child1, child2));
+                children2.remove(child2);
+            } else {
+                result.addChild(child1);
             }
-        }
-        return true;
+        });
+
+        // Add remaining children of node 2
+        children2.forEach(result::addChild);
+        return result.create();
     }
 }
