@@ -17,8 +17,8 @@
 
 package org.apache.commons.configuration2;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertTrue;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 
 import java.io.File;
 import java.net.MalformedURLException;
@@ -34,9 +34,9 @@ import org.apache.commons.configuration2.ex.ConfigurationRuntimeException;
 
 /**
  * Assertions on configurations for the unit tests. This class also provides access to test files.
- *
  */
-public class ConfigurationAssert {
+public final class ConfigurationAssert {
+
     /** Constant for the name of the directory with the test files. */
     public static final String TEST_DIR_NAME = "target/test-classes";
 
@@ -71,14 +71,14 @@ public class ConfigurationAssert {
         // check that the actual configuration contains all the properties of the expected configuration
         for (final Iterator<String> it = expected.getKeys(); it.hasNext();) {
             final String key = it.next();
-            assertTrue("The actual configuration doesn't contain the expected key '" + key + "'", actual.containsKey(key));
-            assertEquals("Value of the '" + key + "' property", expected.getProperty(key), actual.getProperty(key));
+            assertTrue(actual.containsKey(key), "The actual configuration doesn't contain the expected key '" + key + "'");
+            assertEquals(expected.getProperty(key), actual.getProperty(key), "Value of the '" + key + "' property");
         }
 
         // check that the actual configuration has no extra properties
         for (final Iterator<String> it = actual.getKeys(); it.hasNext();) {
             final String key = it.next();
-            assertTrue("The actual configuration contains an extra key '" + key + "'", expected.containsKey(key));
+            assertTrue(expected.containsKey(key), "The actual configuration contains an extra key '" + key + "'");
         }
     }
 
@@ -91,12 +91,12 @@ public class ConfigurationAssert {
      * @param expEquals the expected result of equals()
      */
     public static void checkEquals(final Object o1, final Object o2, final boolean expEquals) {
-        assertEquals("Wrong result of equals()", expEquals, o1.equals(o2));
+        assertEquals(expEquals, o1.equals(o2));
         if (o2 != null) {
-            assertEquals("Not symmetric", expEquals, o2.equals(o1));
+            assertEquals(expEquals, o2.equals(o1));
         }
         if (expEquals) {
-            assertEquals("Different hash codes", o1.hashCode(), o2.hashCode());
+            assertEquals(o1.hashCode(), o2.hashCode());
         }
     }
 
@@ -178,4 +178,8 @@ public class ConfigurationAssert {
             throw new ConfigurationRuntimeException(mex);
         }
     }
+
+    private ConfigurationAssert() {
+        // empty
+    }
 }
