@@ -17,31 +17,33 @@
 
 package org.apache.commons.configuration2;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.assertNull;
-import static org.junit.Assert.assertSame;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
+import static org.hamcrest.MatcherAssert.assertThat;
+import static org.hamcrest.Matchers.containsInAnyOrder;
+import static org.hamcrest.Matchers.containsString;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.assertSame;
+import static org.junit.jupiter.api.Assertions.assertThrows;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 
 import java.math.BigInteger;
 import java.util.ArrayList;
+import java.util.Arrays;
 import java.util.Iterator;
 import java.util.List;
 
-import junitx.framework.ListAssert;
 import org.apache.commons.configuration2.ex.ConversionException;
 import org.apache.commons.configuration2.io.ConfigurationLogger;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 /**
  * Abstract TestCase for implementations of {@link AbstractConfiguration}.
- *
  */
 public abstract class TestAbstractConfiguration {
     /**
-     * Return an abstract configuration with the following data:<br>
+     * Gets an abstract configuration with the following data:<br>
      *
      * <pre>
      * key1 = value1
@@ -53,41 +55,72 @@ public abstract class TestAbstractConfiguration {
     protected abstract AbstractConfiguration getConfiguration();
 
     /**
-     * Return an empty configuration.
+     * Gets an empty configuration.
      */
     protected abstract AbstractConfiguration getEmptyConfiguration();
 
+    @Test
+    public void givenNullIteratorTestContains() {
+        final AbstractConfiguration config = getConfiguration();
+
+        assertThrows(NullPointerException.class, () -> config.contains(null, "value1"));
+    }
+
+    @Test
+    public void givenNullValueTestContains() {
+        final AbstractConfiguration config = getConfiguration();
+        final Iterator<String> keys = config.getKeys();
+        assertFalse(config.contains(keys, null));
+        assertFalse(config.contains(keys, ""));
+    }
+
     @Test
     public void testAddPropertyDirect() {
         final AbstractConfiguration config = getConfiguration();
         config.addPropertyDirect("key3", "value3");
-        assertEquals("key3", "value3", config.getProperty("key3"));
+        assertEquals("value3", config.getProperty("key3"));
 
         config.addPropertyDirect("key3", "value4");
         config.addPropertyDirect("key3", "value5");
         final List<Object> list = config.getList("key3");
-        assertNotNull("no list found for the 'key3' property", list);
+        assertNotNull(list);
 
         final List<Object> expected = new ArrayList<>();
         expected.add("value3");
         expected.add("value4");
         expected.add("value5");
 
-        ListAssert.assertEquals("values for the 'key3' property", expected, list);
+        assertEquals(expected, list);
     }
 
     @Test
     public void testClearProperty() {
         final Configuration config = getConfiguration();
         config.clearProperty("key2");
-        assertFalse("key2 not cleared", config.containsKey("key2"));
+        assertFalse(config.containsKey("key2"));
+    }
+
+    @Test
+    public void testContains() {
+        final AbstractConfiguration config = getConfiguration();
+        assertTrue(config.contains(config.getKeys(), "value1"));
+        assertFalse(config.contains(config.getKeys(), "value99999"));
     }
 
     @Test
     public void testContainsKey() {
         final Configuration config = getConfiguration();
-        assertTrue("key1 not found", config.containsKey("key1"));
-        assertFalse("key3 found", config.containsKey("key3"));
+        assertTrue(config.containsKey("key1"));
+        assertFalse(config.containsKey("key3"));
+    }
+
+    @Test
+    public void testContainsValue() {
+        final Configuration config = getConfiguration();
+        assertFalse(config.containsValue(null));
+        assertFalse(config.containsValue(""));
+        assertTrue(config.containsValue("value1"));
+        assertFalse(config.containsValue("value99999"));
     }
 
     /**
@@ -96,14 +129,10 @@ public abstract class TestAbstractConfiguration {
     @Test
     public void testGetBigIntegerConversion() {
         final Configuration config = getConfiguration();
-        try {
-            config.getBigInteger("key1");
-            fail("No conversion exception thrown!");
-        } catch (final ConversionException cex) {
-            assertTrue("Key not found in exception message: " + cex, cex.getMessage().contains("'key1'"));
-            assertTrue("Target class not found in exception message: " + cex, cex.getMessage().contains(BigInteger.class.getName()));
-            assertTrue("Value not found in exception message: " + cex, cex.getMessage().contains(config.getString("key1")));
-        }
+        final ConversionException cex = assertThrows(ConversionException.class, () -> config.getBigInteger("key1"));
+        assertThat(cex.getMessage(), containsString("'key1'"));
+        assertThat(cex.getMessage(), containsString(BigInteger.class.getName()));
+        assertThat(cex.getMessage(), containsString(config.getString("key1")));
     }
 
     @Test
@@ -111,36 +140,32 @@ public abstract class TestAbstractConfiguration {
         final Configuration config = getConfiguration();
         final Iterator<String> keys = config.getKeys();
 
-        final List<String> expectedKeys = new ArrayList<>();
-        expectedKeys.add("key1");
-        expectedKeys.add("key2");
-        expectedKeys.add("list");
-        expectedKeys.add("listesc");
+        final String[] expectedKeys = {"key1", "key2", "list", "listesc"};
 
-        assertNotNull("null iterator", keys);
-        assertTrue("empty iterator", keys.hasNext());
+        assertNotNull(keys);
+        assertTrue(keys.hasNext());
 
         final List<String> actualKeys = new ArrayList<>();
         while (keys.hasNext()) {
             actualKeys.add(keys.next());
         }
 
-        ListAssert.assertEquals("keys", expectedKeys, actualKeys);
+        assertThat("keys", actualKeys, containsInAnyOrder(expectedKeys));
     }
 
     @Test
     public void testGetProperty() {
         final Configuration config = getConfiguration();
-        assertEquals("key1", "value1", config.getProperty("key1"));
-        assertEquals("key2", "value2", config.getProperty("key2"));
-        assertNull("key3", config.getProperty("key3"));
+        assertEquals("value1", config.getProperty("key1"));
+        assertEquals("value2", config.getProperty("key2"));
+        assertNull(config.getProperty("key3"));
     }
 
     @Test
     public void testIsEmpty() {
         final Configuration config = getConfiguration();
-        assertFalse("the configuration is empty", config.isEmpty());
-        assertTrue("the configuration is not empty", getEmptyConfiguration().isEmpty());
+        assertFalse(config.isEmpty());
+        assertTrue(getEmptyConfiguration().isEmpty());
     }
 
     @Test
@@ -148,10 +173,8 @@ public abstract class TestAbstractConfiguration {
         final Configuration config = getConfiguration();
 
         final List<?> list = config.getList("list");
-        assertNotNull("list not found", config.getProperty("list"));
-        assertEquals("list size", 2, list.size());
-        assertTrue("'value1' is not in the list", list.contains("value1"));
-        assertTrue("'value2' is not in the list", list.contains("value2"));
+        assertNotNull(config.getProperty("list"));
+        assertEquals(Arrays.asList("value1", "value2"), list);
     }
 
     /**
@@ -159,7 +182,7 @@ public abstract class TestAbstractConfiguration {
      */
     @Test
     public void testListEscaped() {
-        assertEquals("Wrong value for escaped list", "value1,value2", getConfiguration().getString("listesc"));
+        assertEquals("value1,value2", getConfiguration().getString("listesc"));
     }
 
     /**
@@ -168,19 +191,19 @@ public abstract class TestAbstractConfiguration {
     @Test
     public void testSetLogger() {
         final AbstractConfiguration config = getEmptyConfiguration();
-        assertNotNull("Default logger is null", config.getLogger());
+        assertNotNull(config.getLogger());
         final ConfigurationLogger log = new ConfigurationLogger(config.getClass());
         config.setLogger(log);
-        assertSame("Logger was not set", log, config.getLogger());
+        assertSame(log, config.getLogger());
     }
 
     @Test
     public void testSize() {
-        assertEquals("Wrong size", 4, getConfiguration().size());
+        assertEquals(4, getConfiguration().size());
     }
 
     @Test
     public void testSizeEmpty() {
-        assertEquals("Wrong size of empty configuration", 0, getEmptyConfiguration().size());
+        assertEquals(0, getEmptyConfiguration().size());
     }
 }
