@@ -178,6 +178,11 @@ public class TestBaseConfiguration {
         assertEquals("hey, that's a test", config.getString("prop.string"));
     }
 
+    @Test
+    public void testContainsValue() {
+        assertFalse(config.containsValue(null));
+    }
+
     @Test
     public void testGetBigDecimal() {
         config.setProperty("numberBigD", "123.456");
@@ -242,7 +247,8 @@ public class TestBaseConfiguration {
     @Test
     public void testGetBoolean() {
         config.setProperty("boolA", Boolean.TRUE);
-        final boolean boolT = true, boolF = false;
+        final boolean boolT = true;
+        final boolean boolF = false;
         assertEquals(boolT, config.getBoolean("boolA"));
         assertEquals(boolT, config.getBoolean("boolA", boolF));
         assertEquals(boolF, config.getBoolean("boolNotInConfig", boolF));
