@@ -17,12 +17,13 @@
 
 package org.apache.commons.configuration2;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.assertNull;
-import static org.junit.Assert.assertSame;
-import static org.junit.Assert.assertTrue;
+import static org.apache.commons.configuration2.TempDirUtils.newFile;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.assertSame;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 
 import java.io.File;
 import java.io.IOException;
@@ -48,13 +49,12 @@ import org.apache.commons.configuration2.sync.LockMode;
 import org.apache.commons.configuration2.sync.ReadWriteSynchronizer;
 import org.apache.commons.configuration2.tree.xpath.XPathExpressionEngine;
 import org.apache.commons.io.FileUtils;
-import org.junit.BeforeClass;
-import org.junit.Rule;
-import org.junit.Test;
-import org.junit.rules.TemporaryFolder;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.io.TempDir;
 
 public class TestDynamicCombinedConfiguration {
-    private class ReaderThread extends Thread {
+    private final class ReaderThread extends Thread {
         private volatile boolean running = true;
         private volatile boolean failed;
         private final CombinedConfigurationBuilder builder;
@@ -99,7 +99,7 @@ public class TestDynamicCombinedConfiguration {
         }
 
     }
-    private static class ReloadThread extends Thread {
+    private static final class ReloadThread extends Thread {
         private final CombinedConfigurationBuilder builder;
         private final int[] failures;
         private final int index;
@@ -145,11 +145,13 @@ public class TestDynamicCombinedConfiguration {
             }
         }
     }
+
     public static class ThreadLookup implements Lookup {
-        private static final ThreadLocal<String> id = new ThreadLocal<>();
+
+        private static final ThreadLocal<String> ID = new ThreadLocal<>();
 
         public static void setId(final String value) {
-            id.set(value);
+            ID.set(value);
         }
 
         public ThreadLookup() {
@@ -164,7 +166,7 @@ public class TestDynamicCombinedConfiguration {
             if (value != null) {
                 return value;
             }
-            return id.get();
+            return ID.get();
 
         }
     }
@@ -187,17 +189,19 @@ public class TestDynamicCombinedConfiguration {
     /** A helper object for creating builder parameters. */
     private static Parameters parameters;
 
-    @BeforeClass
+    @BeforeAll
     public static void setUpOnce() {
         parameters = new Parameters();
     }
 
-    /** Helper object for creating temporary files. */
-    @Rule
-    public TemporaryFolder folder = new TemporaryFolder();
+    /** A folder for temporary files. */
+    @TempDir
+    public File tempFolder;
 
     private void copyFile(final File input, final File output) throws IOException {
         FileUtils.copyFile(input, output, StandardCopyOption.REPLACE_EXISTING);
+        // On Windows, the last modified time is copied by default. Change the last modified time manually.
+        output.setLastModified(System.currentTimeMillis());
     }
 
     /**
@@ -234,9 +238,9 @@ public class TestDynamicCombinedConfiguration {
         builder.configure(parameters.fileBased().setFile(MULTI_TENENT_FILE).setSynchronizer(new ReadWriteSynchronizer()));
         final CombinedConfiguration config = builder.getConfiguration();
 
-        assertEquals("Wrong value", "50", config.getString("rowsPerPage"));
-        final Thread testThreads[] = new Thread[THREAD_COUNT];
-        final int failures[] = new int[THREAD_COUNT];
+        assertEquals("50", config.getString("rowsPerPage"));
+        final Thread[] testThreads = new Thread[THREAD_COUNT];
+        final int[] failures = new int[THREAD_COUNT];
 
         for (int i = 0; i < testThreads.length; ++i) {
             testThreads[i] = new ReloadThread(builder, failures, i, LOOP_COUNT, false, null, "50");
@@ -248,7 +252,7 @@ public class TestDynamicCombinedConfiguration {
             testThreads[i].join();
             totalFailures += failures[i];
         }
-        assertEquals(totalFailures + " failures Occurred", 0, totalFailures);
+        assertEquals(0, totalFailures);
     }
 
     @Test
@@ -258,12 +262,12 @@ public class TestDynamicCombinedConfiguration {
         builder.configure(parameters.fileBased().setFile(MULTI_TENENT_FILE).setSynchronizer(new ReadWriteSynchronizer()));
         final CombinedConfiguration config = builder.getConfiguration();
 
-        assertEquals(config.getString("rowsPerPage"), "50");
+        assertEquals("50", config.getString("rowsPerPage"));
 
-        final Thread testThreads[] = new Thread[THREAD_COUNT];
-        final int failures[] = new int[THREAD_COUNT];
+        final Thread[] testThreads = new Thread[THREAD_COUNT];
+        final int[] failures = new int[THREAD_COUNT];
         System.setProperty("Id", "2002");
-        assertEquals("Wrong value", "25", config.getString("rowsPerPage"));
+        assertEquals("25", config.getString("rowsPerPage"));
         for (int i = 0; i < testThreads.length; ++i) {
             testThreads[i] = new ReloadThread(builder, failures, i, LOOP_COUNT, false, null, "25");
             testThreads[i].start();
@@ -275,17 +279,17 @@ public class TestDynamicCombinedConfiguration {
             totalFailures += failures[i];
         }
         System.getProperties().remove("Id");
-        assertEquals(totalFailures + " failures Occurred", 0, totalFailures);
+        assertEquals(0, totalFailures);
     }
 
     @Test
     public void testConcurrentGetAndReloadFile() throws Exception {
         final int threadCount = 25;
         System.getProperties().remove("Id");
-        System.setProperty("TemporaryFolder", folder.getRoot().getAbsolutePath());
+        System.setProperty("TemporaryFolder", tempFolder.getAbsolutePath());
         // create a new configuration
         File input = new File("target/test-classes/testMultiDynamic_default.xml");
-        final File output = folder.newFile("testMultiDynamic_default.xml");
+        final File output = newFile("testMultiDynamic_default.xml", tempFolder);
         output.delete();
         output.getParentFile().mkdir();
         copyFile(input, output);
@@ -295,9 +299,9 @@ public class TestDynamicCombinedConfiguration {
             .setDefinitionBuilderParameters(new FileBasedBuilderParametersImpl().setFile(MULTI_DYNAMIC_FILE)).registerChildDefaultsHandler(
                 FileBasedBuilderProperties.class, new CopyObjectDefaultHandler(new FileBasedBuilderParametersImpl().setReloadingRefreshDelay(1L))));
         CombinedConfiguration config = builder.getConfiguration();
-        assertEquals("Wrong property value (1)", "ID0001", config.getString("Product/FIIndex/FI[@id='123456781']"));
+        assertEquals("ID0001", config.getString("Product/FIIndex/FI[@id='123456781']"));
 
-        final ReaderThread testThreads[] = new ReaderThread[threadCount];
+        final ReaderThread[] testThreads = new ReaderThread[threadCount];
         for (int i = 0; i < testThreads.length; ++i) {
             testThreads[i] = new ReaderThread(builder);
             testThreads[i].start();
@@ -310,12 +314,12 @@ public class TestDynamicCombinedConfiguration {
         copyFile(input, output);
 
         Thread.sleep(2000);
-        assertTrue("Changed file not detected", builder.getReloadingController().checkForReloading(null));
+        assertTrue(builder.getReloadingController().checkForReloading(null));
         config = builder.getConfiguration();
         final String id = config.getString("Product/FIIndex/FI[@id='123456782']");
-        assertNotNull("File did not reload, id is null", id);
+        assertNotNull(id);
         final String rows = config.getString("rowsPerPage");
-        assertEquals("Incorrect value for rowsPerPage", "25", rows);
+        assertEquals("25", rows);
 
         for (final ReaderThread testThread : testThreads) {
             testThread.shutdown();
@@ -335,10 +339,10 @@ public class TestDynamicCombinedConfiguration {
         builder.configure(parameters.fileBased().setFile(MULTI_TENENT_FILE).setSynchronizer(new ReadWriteSynchronizer()));
         final CombinedConfiguration config = builder.getConfiguration();
 
-        assertEquals(config.getString("rowsPerPage"), "50");
+        assertEquals("50", config.getString("rowsPerPage"));
 
-        final Thread testThreads[] = new Thread[THREAD_COUNT];
-        final int failures[] = new int[THREAD_COUNT];
+        final Thread[] testThreads = new Thread[THREAD_COUNT];
+        final int[] failures = new int[THREAD_COUNT];
         final String[] ids = {null, "2002", "3001", "3002", "3003"};
         final String[] expected = {"50", "25", "15", "25", "50"};
         for (int i = 0; i < testThreads.length; ++i) {
@@ -358,7 +362,7 @@ public class TestDynamicCombinedConfiguration {
                 System.out.println("Thread " + i + " " + failures[i]);
             }
         }
-        assertEquals(totalFailures + " failures Occurred", 0, totalFailures);
+        assertEquals(0, totalFailures);
     }
 
     @Test
@@ -391,9 +395,9 @@ public class TestDynamicCombinedConfiguration {
         assertEquals("OK-1", config.getString("buttons/name"));
         assertEquals(3, config.getMaxIndex("buttons/name"));
         assertEquals("a\\,b\\,c", config.getString("split/list2"));
-        assertEquals("Wrong size", 18, config.size());
+        assertEquals(18, config.size());
         config.addProperty("listDelimiterTest", "1,2,3");
-        assertEquals("List delimiter not detected", "1", config.getString("listDelimiterTest"));
+        assertEquals("1", config.getString("listDelimiterTest"));
     }
 
     /**
@@ -405,7 +409,7 @@ public class TestDynamicCombinedConfiguration {
         final Configuration child = new PropertiesConfiguration();
         config.addConfiguration(child);
         final SynchronizerTestImpl sync = prepareSynchronizerTest(config);
-        assertSame("Wrong configuration", child, config.getConfiguration(0));
+        assertSame(child, config.getConfiguration(0));
         sync.verify(Methods.BEGIN_READ, Methods.END_READ);
     }
 
@@ -416,7 +420,7 @@ public class TestDynamicCombinedConfiguration {
     public void testGetConfigurationByNameSynchronized() {
         final DynamicCombinedConfiguration config = new DynamicCombinedConfiguration();
         final SynchronizerTestImpl sync = prepareSynchronizerTest(config);
-        assertNull("Wrong result", config.getConfiguration("unknown config"));
+        assertNull(config.getConfiguration("unknown config"));
         sync.verify(Methods.BEGIN_READ, Methods.END_READ);
     }
 
@@ -465,7 +469,7 @@ public class TestDynamicCombinedConfiguration {
         builder.configure(parameters.fileBased().setFile(MULTI_TENENT_FILE).setSynchronizer(new ReadWriteSynchronizer()));
         final CombinedConfiguration config = builder.getConfiguration();
         config.getConfiguration(1).setProperty("rowsPerPage", "25");
-        assertEquals("Value not changed", "25", config.getString("rowsPerPage"));
+        assertEquals("25", config.getString("rowsPerPage"));
     }
 
     private void verify(final String key, final DynamicCombinedConfiguration config, final int rows) {
