@@ -16,11 +16,13 @@
  */
 package org.apache.commons.configuration2;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.assertNull;
-import static org.junit.Assert.assertTrue;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertInstanceOf;
+import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.assertThrows;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 
+import java.util.ArrayList;
 import java.util.Collection;
 import java.util.List;
 
@@ -30,12 +32,11 @@ import org.apache.commons.configuration2.tree.DefaultConfigurationKey;
 import org.apache.commons.configuration2.tree.DefaultExpressionEngine;
 import org.apache.commons.configuration2.tree.ImmutableNode;
 import org.apache.commons.configuration2.tree.NodeStructureHelper;
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 /**
  * Test class for {@code BaseHierarchicalConfiguration}.
- *
  */
 public class TestHierarchicalConfiguration {
     /** Constant for a changed name. */
@@ -63,10 +64,10 @@ public class TestHierarchicalConfiguration {
         final String key = "tables.table(0)";
         final List<HierarchicalConfiguration<ImmutableNode>> children = withUpdates ? config.childConfigurationsAt(key, true)
             : config.childConfigurationsAt(key);
-        assertEquals("Wrong number of elements", 2, children.size());
+        assertEquals(2, children.size());
         final HierarchicalConfiguration<ImmutableNode> sub = children.get(0);
         sub.setProperty(null, NEW_NAME);
-        assertEquals("Wrong value in parent", expectedName, config.getString(key + ".name"));
+        assertEquals(expectedName, config.getString(key + ".name"));
     }
 
     /**
@@ -77,7 +78,7 @@ public class TestHierarchicalConfiguration {
     private void checkConfigurationAtAttributeNode(final boolean withUpdates) {
         final String key = "tables.table(0)[@type]";
         config.addProperty(key, "system");
-        config.configurationAt(key, withUpdates);
+        assertThrows(ConfigurationRuntimeException.class, () -> config.configurationAt(key, withUpdates));
     }
 
     /**
@@ -92,7 +93,7 @@ public class TestHierarchicalConfiguration {
         final List<HierarchicalConfiguration<ImmutableNode>> lstFlds = withUpdates ? config.configurationsAt(key, true) : config.configurationsAt(key);
         checkSubConfigurations(lstFlds);
         lstFlds.get(0).setProperty("name", NEW_NAME);
-        assertEquals("Wrong name in parent", expName, config.getString("tables.table(1).fields.field(0).name"));
+        assertEquals(expName, config.getString("tables.table(1).fields.field(0).name"));
     }
 
     /**
@@ -115,14 +116,14 @@ public class TestHierarchicalConfiguration {
      * @param lstFlds the list with sub configurations
      */
     private void checkSubConfigurations(final List<? extends ImmutableConfiguration> lstFlds) {
-        assertEquals("Wrong size of fields", NodeStructureHelper.fieldsLength(1), lstFlds.size());
+        assertEquals(NodeStructureHelper.fieldsLength(1), lstFlds.size());
         for (int i = 0; i < NodeStructureHelper.fieldsLength(1); i++) {
             final ImmutableConfiguration sub = lstFlds.get(i);
-            assertEquals("Wrong field at position " + i, NodeStructureHelper.field(1, i), sub.getString("name"));
+            assertEquals(NodeStructureHelper.field(1, i), sub.getString("name"), "Wrong field at position " + i);
         }
     }
 
-    @Before
+    @BeforeEach
     public void setUp() throws Exception {
         final ImmutableNode root = new ImmutableNode.Builder(1).addChild(NodeStructureHelper.ROOT_TABLES_TREE).create();
         config = new BaseHierarchicalConfiguration();
@@ -134,7 +135,7 @@ public class TestHierarchicalConfiguration {
      */
     @Test
     public void testChildConfigurationsAtNotFound() {
-        assertTrue("Got children", config.childConfigurationsAt("not.existing.key").isEmpty());
+        assertTrue(config.childConfigurationsAt("not.existing.key").isEmpty());
     }
 
     /**
@@ -142,7 +143,7 @@ public class TestHierarchicalConfiguration {
      */
     @Test
     public void testChildConfigurationsAtNoUniqueKey() {
-        assertTrue("Got children", config.childConfigurationsAt("tables.table").isEmpty());
+        assertTrue(config.childConfigurationsAt("tables.table").isEmpty());
     }
 
     /**
@@ -164,7 +165,7 @@ public class TestHierarchicalConfiguration {
     @Test
     public void testClone() {
         final Configuration copy = (Configuration) config.clone();
-        assertTrue(copy instanceof BaseHierarchicalConfiguration);
+        assertInstanceOf(BaseHierarchicalConfiguration.class, copy);
         config.setProperty("tables.table(0).name", "changed table name");
         checkContent(copy);
     }
@@ -172,7 +173,7 @@ public class TestHierarchicalConfiguration {
     /**
      * Tests configurationAt() if the passed in key selects an attribute result.
      */
-    @Test(expected = ConfigurationRuntimeException.class)
+    @Test
     public void testConfigurationAtAttributeNode() {
         checkConfigurationAtAttributeNode(false);
     }
@@ -180,7 +181,7 @@ public class TestHierarchicalConfiguration {
     /**
      * Tests configurationAt() if the passed in key selects an attribute result and the updates flag is set.
      */
-    @Test(expected = ConfigurationRuntimeException.class)
+    @Test
     public void testConfigurationAtAttributeNodeWithUpdates() {
         checkConfigurationAtAttributeNode(true);
     }
@@ -195,26 +196,26 @@ public class TestHierarchicalConfiguration {
         config.addProperty("test.other", "check");
         final HierarchicalConfiguration<ImmutableNode> sub = config.configurationAt("test.sub", true);
         sub.clear();
-        assertTrue("Sub not empty", sub.isEmpty());
-        assertNull("Key still found", config.getString("test.sub.test"));
+        assertTrue(sub.isEmpty());
+        assertNull(config.getString("test.sub.test"));
         sub.setProperty("test", "failure!");
-        assertNull("Node not detached", config.getString("test.sub.test"));
+        assertNull(config.getString("test.sub.test"));
     }
 
     /**
      * Tests the configurationAt() method if the passed in key selects multiple nodes. This should cause an exception.
      */
-    @Test(expected = ConfigurationRuntimeException.class)
+    @Test
     public void testConfigurationAtMultipleNodes() {
-        config.configurationAt("tables.table.name");
+        assertThrows(ConfigurationRuntimeException.class, () -> config.configurationAt("tables.table.name"));
     }
 
     /**
      * Tests configurationAt() if the passed in key selects multiple nodes and the update flag is set.
      */
-    @Test(expected = ConfigurationRuntimeException.class)
+    @Test
     public void testConfigurationAtMultipleNodesWithUpdates() {
-        config.configurationAt("tables.table.name", true);
+        assertThrows(ConfigurationRuntimeException.class, () -> config.configurationAt("tables.table.name", true));
     }
 
     /**
@@ -223,28 +224,30 @@ public class TestHierarchicalConfiguration {
     @Test
     public void testConfigurationAtReadAccess() {
         final HierarchicalConfiguration<ImmutableNode> subConfig = config.configurationAt("tables.table(1)");
-        assertEquals("Wrong table name", NodeStructureHelper.table(1), subConfig.getString("name"));
+        assertEquals(NodeStructureHelper.table(1), subConfig.getString("name"));
         final List<Object> lstFlds = subConfig.getList("fields.field.name");
-        assertEquals("Wrong number of fields", NodeStructureHelper.fieldsLength(1), lstFlds.size());
+
+        final List<String> expected = new ArrayList<>();
         for (int i = 0; i < NodeStructureHelper.fieldsLength(1); i++) {
-            assertEquals("Wrong field at position " + i, NodeStructureHelper.field(1, i), lstFlds.get(i));
+            expected.add(NodeStructureHelper.field(1, i));
         }
+        assertEquals(expected, lstFlds);
     }
 
     /**
      * Tests the configurationAt() method if the passed in key does not exist.
      */
-    @Test(expected = ConfigurationRuntimeException.class)
+    @Test
     public void testConfigurationAtUnknownSubTree() {
-        config.configurationAt("non.existing.key");
+        assertThrows(ConfigurationRuntimeException.class, () -> config.configurationAt("non.existing.key"));
     }
 
     /**
      * Tests configurationAt() for a non existing key if the update flag is set.
      */
-    @Test(expected = ConfigurationRuntimeException.class)
+    @Test
     public void testConfigurationAtUnknownSubTreeWithUpdates() {
-        config.configurationAt("non.existing.key", true);
+        assertThrows(ConfigurationRuntimeException.class, () -> config.configurationAt("non.existing.key", true));
     }
 
     /**
@@ -254,7 +257,7 @@ public class TestHierarchicalConfiguration {
     public void testConfigurationAtUpdateParentConnected() {
         final HierarchicalConfiguration<ImmutableNode> subConfig = config.configurationAt("tables.table(1)", true);
         config.setProperty("tables.table(1).fields.field(2).name", "testField");
-        assertEquals("Change visible in sub config", "testField", subConfig.getString("fields.field(2).name"));
+        assertEquals("testField", subConfig.getString("fields.field(2).name"));
     }
 
     /**
@@ -264,7 +267,7 @@ public class TestHierarchicalConfiguration {
     public void testConfigurationAtUpdateParentIndependent() {
         final HierarchicalConfiguration<ImmutableNode> subConfig = config.configurationAt("tables.table(1)");
         config.setProperty("tables.table(1).fields.field(2).name", "testField");
-        assertEquals("Change visible in sub config", NodeStructureHelper.field(1, 2), subConfig.getString("fields.field(2).name"));
+        assertEquals(NodeStructureHelper.field(1, 2), subConfig.getString("fields.field(2).name"));
     }
 
     /**
@@ -274,7 +277,7 @@ public class TestHierarchicalConfiguration {
     public void testConfigurationAtUpdateSubConfigConnected() {
         final HierarchicalConfiguration<ImmutableNode> subConfig = config.configurationAt("tables.table(1)", true);
         subConfig.setProperty("name", "testTable");
-        assertEquals("Change not visible in parent", "testTable", config.getString("tables.table(1).name"));
+        assertEquals("testTable", config.getString("tables.table(1).name"));
     }
 
     /**
@@ -284,8 +287,8 @@ public class TestHierarchicalConfiguration {
     public void testConfigurationAtUpdateSubConfigIndependent() {
         final HierarchicalConfiguration<ImmutableNode> subConfig = config.configurationAt("tables.table(1)");
         subConfig.setProperty("name", "testTable");
-        assertEquals("Value not changed", "testTable", subConfig.getString("name"));
-        assertEquals("Change visible in parent", NodeStructureHelper.table(1), config.getString("tables.table(1).name"));
+        assertEquals("testTable", subConfig.getString("name"));
+        assertEquals(NodeStructureHelper.table(1), config.getString("tables.table(1).name"));
     }
 
     /**
@@ -298,8 +301,8 @@ public class TestHierarchicalConfiguration {
         config.setThrowExceptionOnMissing(true);
         final List<HierarchicalConfiguration<ImmutableNode>> subs = config.configurationsAt(key, true);
         final BaseHierarchicalConfiguration sub = (BaseHierarchicalConfiguration) subs.get(0);
-        assertEquals("Wrong delimiter handler", config.getListDelimiterHandler(), sub.getListDelimiterHandler());
-        assertTrue("Wrong exception flag", sub.isThrowExceptionOnMissing());
+        assertEquals(config.getListDelimiterHandler(), sub.getListDelimiterHandler());
+        assertTrue(sub.isThrowExceptionOnMissing());
     }
 
     /**
@@ -309,7 +312,7 @@ public class TestHierarchicalConfiguration {
     public void testConfigurationsAtAttributeKey() {
         final String attrKey = "tables.table(0)[@type]";
         config.addProperty(attrKey, "user");
-        assertTrue("Got configurations", config.configurationsAt(attrKey).isEmpty());
+        assertTrue(config.configurationsAt(attrKey).isEmpty());
     }
 
     /**
@@ -317,7 +320,7 @@ public class TestHierarchicalConfiguration {
      */
     @Test
     public void testConfigurationsAtEmpty() {
-        assertTrue("List is not empty", config.configurationsAt("unknown.key").isEmpty());
+        assertTrue(config.configurationsAt("unknown.key").isEmpty());
     }
 
     /**
@@ -342,13 +345,13 @@ public class TestHierarchicalConfiguration {
     @Test
     public void testImmutableChildConfigurationsAt() {
         final List<ImmutableHierarchicalConfiguration> children = config.immutableChildConfigurationsAt("tables.table(0)");
-        assertEquals("Wrong number of elements", 2, children.size());
+        assertEquals(2, children.size());
         final ImmutableHierarchicalConfiguration c1 = children.get(0);
-        assertEquals("Wrong name (1)", "name", c1.getRootElementName());
-        assertEquals("Wrong table name", NodeStructureHelper.table(0), c1.getString(null));
+        assertEquals("name", c1.getRootElementName());
+        assertEquals(NodeStructureHelper.table(0), c1.getString(null));
         final ImmutableHierarchicalConfiguration c2 = children.get(1);
-        assertEquals("Wrong name (2)", "fields", c2.getRootElementName());
-        assertEquals("Wrong field name", NodeStructureHelper.field(0, 0), c2.getString("field(0).name"));
+        assertEquals("fields", c2.getRootElementName());
+        assertEquals(NodeStructureHelper.field(0, 0), c2.getString("field(0).name"));
     }
 
     /**
@@ -357,12 +360,14 @@ public class TestHierarchicalConfiguration {
     @Test
     public void testImmutableConfigurationAt() {
         final ImmutableHierarchicalConfiguration subConfig = config.immutableConfigurationAt("tables.table(1)");
-        assertEquals("Wrong table name", NodeStructureHelper.table(1), subConfig.getString("name"));
+        assertEquals(NodeStructureHelper.table(1), subConfig.getString("name"));
         final List<Object> lstFlds = subConfig.getList("fields.field.name");
-        assertEquals("Wrong number of fields", NodeStructureHelper.fieldsLength(1), lstFlds.size());
+
+        final List<String> expected = new ArrayList<>();
         for (int i = 0; i < NodeStructureHelper.fieldsLength(1); i++) {
-            assertEquals("Wrong field at position " + i, NodeStructureHelper.field(1, i), lstFlds.get(i));
+            expected.add(NodeStructureHelper.field(1, i));
         }
+        assertEquals(expected, lstFlds);
     }
 
     /**
@@ -374,7 +379,7 @@ public class TestHierarchicalConfiguration {
         final ImmutableHierarchicalConfiguration subConfig = config.immutableConfigurationAt("tables.table(1)", true);
         config.addProperty("tables.table(-1).name", newTableName);
         config.clearTree("tables.table(1)");
-        assertEquals("Name not updated", newTableName, subConfig.getString("name"));
+        assertEquals(newTableName, subConfig.getString("name"));
     }
 
     /**
@@ -401,7 +406,7 @@ public class TestHierarchicalConfiguration {
     @Test
     public void testInitCopyNull() {
         final BaseHierarchicalConfiguration copy = new BaseHierarchicalConfiguration((HierarchicalConfiguration<ImmutableNode>) null);
-        assertTrue("Configuration not empty", copy.isEmpty());
+        assertTrue(copy.isEmpty());
     }
 
     /**
@@ -432,7 +437,7 @@ public class TestHierarchicalConfiguration {
     @Test
     public void testInterpolatedConfigurationEmpty() {
         config = new BaseHierarchicalConfiguration();
-        assertTrue("Got content", config.interpolatedConfiguration().isEmpty());
+        assertTrue(config.interpolatedConfiguration().isEmpty());
     }
 
     /**
@@ -453,7 +458,7 @@ public class TestHierarchicalConfiguration {
         config.addProperty("prop2.prop[@attr]", "${var}");
         final Configuration sub1 = config.subset("prop2");
         final Configuration sub2 = sub1.subset("prop");
-        assertEquals("Wrong value", "value", sub2.getString("[@attr]"));
+        assertEquals("value", sub2.getString("[@attr]"));
     }
 
     @Test
@@ -463,9 +468,8 @@ public class TestHierarchicalConfiguration {
         assertEquals(NodeStructureHelper.table(0), subset.getProperty("name"));
 
         Object prop = subset.getProperty("fields.field.name");
-        assertNotNull(prop);
-        assertTrue(prop instanceof Collection);
-        assertEquals(5, ((Collection<?>) prop).size());
+        Collection<?> collection = assertInstanceOf(Collection.class, prop);
+        assertEquals(5, collection.size());
 
         for (int i = 0; i < NodeStructureHelper.fieldsLength(0); i++) {
             final DefaultConfigurationKey key = createConfigurationKey();
@@ -475,23 +479,23 @@ public class TestHierarchicalConfiguration {
         }
 
         // test the subset on the second table
-        assertTrue("subset is not empty", config.subset("tables.table(2)").isEmpty());
+        assertTrue(config.subset("tables.table(2)").isEmpty());
 
         // test the subset on the fields
         subset = config.subset("tables.table.fields.field");
         prop = subset.getProperty("name");
-        assertTrue("prop is not a collection", prop instanceof Collection);
+        collection = assertInstanceOf(Collection.class, prop);
         int expectedFieldCount = 0;
         for (int i = 0; i < NodeStructureHelper.tablesLength(); i++) {
             expectedFieldCount += NodeStructureHelper.fieldsLength(i);
         }
-        assertEquals("Wrong number of fields", expectedFieldCount, ((Collection<?>) prop).size());
+        assertEquals(expectedFieldCount, collection.size());
 
         assertEquals(NodeStructureHelper.field(0, 0), subset.getProperty("name(0)"));
 
         // test the subset on the field names
         subset = config.subset("tables.table.fields.field.name");
-        assertTrue("subset is not empty", subset.isEmpty());
+        assertTrue(subset.isEmpty());
     }
 
     /**
@@ -502,8 +506,8 @@ public class TestHierarchicalConfiguration {
         final String key = "tables.table(0)[@type]";
         config.addProperty(key, "system");
         final BaseHierarchicalConfiguration subset = (BaseHierarchicalConfiguration) config.subset(key);
-        assertTrue("Got children of root node", subset.getModel().getNodeHandler().getRootNode().getChildren().isEmpty());
-        assertEquals("Attribute not found", "system", subset.getString("[@type]"));
+        assertTrue(subset.getModel().getNodeHandler().getRootNode().getChildren().isEmpty());
+        assertEquals("system", subset.getString("[@type]"));
     }
 
     /**
@@ -514,10 +518,10 @@ public class TestHierarchicalConfiguration {
     public void testSubsetMultipleNodesWithValues() {
         config.setProperty("tables.table(0).fields", "My fields");
         Configuration subset = config.subset("tables.table.fields");
-        assertEquals("Wrong value of root", "My fields", subset.getString(""));
+        assertEquals("My fields", subset.getString(""));
         config.setProperty("tables.table(1).fields", "My other fields");
         subset = config.subset("tables.table.fields");
-        assertNull("Root value is not null though there are multiple values", subset.getString(""));
+        assertNull(subset.getString(""));
     }
 
     /**
@@ -528,7 +532,7 @@ public class TestHierarchicalConfiguration {
     public void testSubsetNodeWithValue() {
         config.setProperty("tables.table(0).fields", "My fields");
         final Configuration subset = config.subset("tables.table(0).fields");
-        assertEquals("Wrong field name", NodeStructureHelper.field(0, 0), subset.getString("field(0).name"));
-        assertEquals("Wrong value of root", "My fields", subset.getString(""));
+        assertEquals(NodeStructureHelper.field(0, 0), subset.getString("field(0).name"));
+        assertEquals("My fields", subset.getString(""));
     }
 }
