@@ -41,6 +41,7 @@ import com.fasterxml.jackson.databind.type.MapType;
  * {@link JSONConfiguration} itself
  */
 public class TestJSONConfiguration {
+
     /** The files that we test with. */
     private final String testJson = ConfigurationAssert.getTestFile("test.json").getAbsolutePath();
 
@@ -64,53 +65,53 @@ public class TestJSONConfiguration {
     /**
      * Tests CONFIGURATION-793.
      */
-    public void testGetList_nested_with_list() {
+    public void testGetListNestedWithList() {
         assertEquals(Arrays.asList("col1", "col2"), jsonConfiguration.getList(String.class, "key4.key5"));
     }
 
     @Test
-    public void testGetProperty_dictionary() {
+    public void testGetPropertyDictionary() {
         assertEquals("Martin D'vloper", jsonConfiguration.getProperty("martin.name"));
         assertEquals("Developer", jsonConfiguration.getProperty("martin.job"));
         assertEquals("Elite", jsonConfiguration.getProperty("martin.skill"));
     }
 
     @Test
-    public void testGetProperty_dictionaryInList() {
+    public void testGetPropertyDictionaryInList() {
         assertEquals("UK", jsonConfiguration.getString("capitals(1).country"));
         assertEquals("Washington", jsonConfiguration.getString("capitals(0).capital"));
     }
 
     @Test
-    public void testGetProperty_integer() {
+    public void testGetPropertyInteger() {
         final Object property = jsonConfiguration.getProperty("int1");
         assertInstanceOf(Integer.class, property);
         assertEquals(37, property);
     }
 
     @Test
-    public void testGetProperty_nested() {
+    public void testGetPropertyNested() {
         assertEquals("value23", jsonConfiguration.getProperty("key2.key3"));
     }
 
     @Test
-    public void testGetProperty_nested_with_list() {
+    public void testGetPropertyNestedWithList() {
         assertEquals(Arrays.asList("col1", "col2"), jsonConfiguration.getProperty("key4.key5"));
     }
 
     @Test
-    public void testGetProperty_simple() {
+    public void testGetPropertySimple() {
         assertEquals("value1", jsonConfiguration.getProperty("key1"));
     }
 
     @Test
-    public void testGetProperty_subset() {
+    public void testGetPropertySubset() {
         final Configuration subset = jsonConfiguration.subset("key4");
         assertEquals(Arrays.asList("col1", "col2"), subset.getProperty("key5"));
     }
 
     @Test
-    public void testGetProperty_very_nested_properties() {
+    public void testGetPropertyVeryNestedProperties() {
         final Object property = jsonConfiguration.getProperty("very.nested.properties");
         assertEquals(Arrays.asList("nested1", "nested2", "nested3"), property);
     }
@@ -149,7 +150,7 @@ public class TestJSONConfiguration {
         assertEquals(7, parsed.entrySet().size());
         assertEquals("value1", parsed.get("key1"));
 
-        final Map<?, ?> key2 = (Map<? , ?>) parsed.get("key2");
+        final Map<?, ?> key2 = (Map<?, ?>) parsed.get("key2");
         assertEquals("value23", key2.get("key3"));
 
         final List<?> key5 = (List<?>) ((Map<?, ?>) parsed.get("key4")).get("key5");
