@@ -16,13 +16,14 @@
  */
 package org.apache.commons.configuration2;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertNotEquals;
-import static org.junit.Assert.assertNull;
-import static org.junit.Assert.assertSame;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
+import static org.junit.jupiter.api.Assertions.assertDoesNotThrow;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNotEquals;
+import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.assertSame;
+import static org.junit.jupiter.api.Assertions.assertThrows;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 
 import java.io.Reader;
 import java.io.StringReader;
@@ -36,19 +37,21 @@ import org.apache.commons.configuration2.convert.LegacyListDelimiterHandler;
 import org.apache.commons.configuration2.event.ConfigurationEvent;
 import org.apache.commons.configuration2.event.EventListener;
 import org.apache.commons.configuration2.ex.ConfigurationException;
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 /**
  * Test class for PropertiesConfigurationLayout.
  */
 public class TestPropertiesConfigurationLayout {
+
     /**
      * A mock properties configuration implementation that is used to check whether some expected methods are called.
      */
     static class LayoutTestConfiguration extends PropertiesConfiguration {
+
         /** Stores a builder object. */
-        public PropertiesBuilder builder;
+        private PropertiesBuilder builder;
 
         /**
          * Simulates the propertyLoaded() callback. If a builder was set, a load() call on the layout is invoked.
@@ -164,7 +167,7 @@ public class TestPropertiesConfigurationLayout {
      * @throws ConfigurationException if an error occurs
      */
     private void checkLayoutString(final String expected) throws ConfigurationException {
-        assertEquals("Wrong layout file content", expected, getLayoutString());
+        assertEquals(expected, getLayoutString());
     }
 
     /**
@@ -178,12 +181,7 @@ public class TestPropertiesConfigurationLayout {
         builder.addProperty(TEST_KEY, TEST_VALUE);
         builder.addProperty("anotherProp", "anotherValue");
         builder.addComment("A footer comment");
-        try {
-            layout.load(config, builder.getReader());
-        } catch (final ConfigurationException cex) {
-            // should not happen
-            fail("Exception was thrown: " + cex);
-        }
+        assertDoesNotThrow(() -> layout.load(config, builder.getReader()));
     }
 
     /**
@@ -198,7 +196,7 @@ public class TestPropertiesConfigurationLayout {
         return out.toString();
     }
 
-    @Before
+    @BeforeEach
     public void setUp() throws Exception {
         config = new LayoutTestConfiguration();
         config.setListDelimiterHandler(new LegacyListDelimiterHandler(','));
@@ -219,9 +217,9 @@ public class TestPropertiesConfigurationLayout {
         builder.addComment(null);
         builder.addProperty(TEST_KEY, TEST_VALUE);
         layout.load(config, builder.getReader());
-        assertEquals("Wrong number of blank lines", 2, layout.getBlankLinesBefore(TEST_KEY));
-        assertEquals("Wrong comment", TEST_COMMENT + CRNORM, layout.getCanonicalComment(TEST_KEY, false));
-        assertEquals("Wrong property value", TEST_VALUE, config.getString(TEST_KEY));
+        assertEquals(2, layout.getBlankLinesBefore(TEST_KEY));
+        assertEquals(TEST_COMMENT + CRNORM, layout.getCanonicalComment(TEST_KEY, false));
+        assertEquals(TEST_VALUE, config.getString(TEST_KEY));
     }
 
     /**
@@ -235,9 +233,9 @@ public class TestPropertiesConfigurationLayout {
         builder.addComment(TEST_COMMENT);
         builder.addProperty(TEST_KEY, TEST_VALUE);
         layout.load(config, builder.getReader());
-        assertEquals("Wrong number of blank lines", 2, layout.getBlankLinesBefore(TEST_KEY));
-        assertEquals("Wrong comment", TEST_COMMENT, layout.getCanonicalComment(TEST_KEY, false));
-        assertEquals("Wrong property value", TEST_VALUE, config.getString(TEST_KEY));
+        assertEquals(2, layout.getBlankLinesBefore(TEST_KEY));
+        assertEquals(TEST_COMMENT, layout.getCanonicalComment(TEST_KEY, false));
+        assertEquals(TEST_VALUE, config.getString(TEST_KEY));
     }
 
     /**
@@ -251,8 +249,8 @@ public class TestPropertiesConfigurationLayout {
         builder.addComment(TEST_COMMENT);
         builder.addProperty(TEST_KEY, TEST_VALUE + "2");
         layout.load(config, builder.getReader());
-        assertEquals("Wrong combined comment", TEST_COMMENT + CRNORM + TEST_COMMENT, layout.getCanonicalComment(TEST_KEY, false));
-        assertEquals("Wrong combined blank numbers", 0, layout.getBlankLinesBefore(TEST_KEY));
+        assertEquals(TEST_COMMENT + CRNORM + TEST_COMMENT, layout.getCanonicalComment(TEST_KEY, false));
+        assertEquals(0, layout.getBlankLinesBefore(TEST_KEY));
     }
 
     /**
@@ -262,10 +260,10 @@ public class TestPropertiesConfigurationLayout {
     public void testEventAdd() {
         final ConfigurationEvent event = new ConfigurationEvent(this, ConfigurationEvent.ADD_PROPERTY, TEST_KEY, TEST_VALUE, false);
         layout.onEvent(event);
-        assertTrue("Property not stored", layout.getKeys().contains(TEST_KEY));
-        assertEquals("Blanc lines before new property", 0, layout.getBlankLinesBefore(TEST_KEY));
-        assertTrue("No single line property", layout.isSingleLine(TEST_KEY));
-        assertEquals("Wrong separator", " = ", layout.getSeparator(TEST_KEY));
+        assertTrue(layout.getKeys().contains(TEST_KEY));
+        assertEquals(0, layout.getBlankLinesBefore(TEST_KEY));
+        assertTrue(layout.isSingleLine(TEST_KEY));
+        assertEquals(" = ", layout.getSeparator(TEST_KEY));
     }
 
     /**
@@ -275,7 +273,7 @@ public class TestPropertiesConfigurationLayout {
     public void testEventAddBefore() {
         final ConfigurationEvent event = new ConfigurationEvent(this, ConfigurationEvent.ADD_PROPERTY, TEST_KEY, TEST_VALUE, true);
         layout.onEvent(event);
-        assertFalse("Property already stored", layout.getKeys().contains(TEST_KEY));
+        assertFalse(layout.getKeys().contains(TEST_KEY));
     }
 
     /**
@@ -288,8 +286,8 @@ public class TestPropertiesConfigurationLayout {
         layout.load(config, builder.getReader());
         final ConfigurationEvent event = new ConfigurationEvent(this, ConfigurationEvent.ADD_PROPERTY, TEST_KEY, TEST_VALUE, false);
         layout.onEvent(event);
-        assertFalse("No multi-line property", layout.isSingleLine(TEST_KEY));
-        assertEquals("Comment was modified", TEST_COMMENT, layout.getCanonicalComment(TEST_KEY, false));
+        assertFalse(layout.isSingleLine(TEST_KEY));
+        assertEquals(TEST_COMMENT, layout.getCanonicalComment(TEST_KEY, false));
     }
 
     /**
@@ -300,7 +298,7 @@ public class TestPropertiesConfigurationLayout {
         final ConfigurationEvent event = new ConfigurationEvent(this, ConfigurationEvent.ADD_PROPERTY, TEST_KEY, TEST_VALUE, false);
         layout.onEvent(event);
         layout.onEvent(event);
-        assertFalse("No multi-line property", layout.isSingleLine(TEST_KEY));
+        assertFalse(layout.isSingleLine(TEST_KEY));
     }
 
     /**
@@ -311,8 +309,8 @@ public class TestPropertiesConfigurationLayout {
         fillLayout();
         final ConfigurationEvent event = new ConfigurationEvent(this, ConfigurationEvent.CLEAR, null, null, false);
         layout.onEvent(event);
-        assertTrue("Keys not empty", layout.getKeys().isEmpty());
-        assertNull("Header comment was not reset", layout.getHeaderComment());
+        assertTrue(layout.getKeys().isEmpty());
+        assertNull(layout.getHeaderComment());
     }
 
     /**
@@ -324,7 +322,7 @@ public class TestPropertiesConfigurationLayout {
         layout.onEvent(event);
         event = new ConfigurationEvent(this, ConfigurationEvent.CLEAR_PROPERTY, TEST_KEY, null, false);
         layout.onEvent(event);
-        assertFalse("Property still existing", layout.getKeys().contains(TEST_KEY));
+        assertFalse(layout.getKeys().contains(TEST_KEY));
     }
 
     /**
@@ -334,7 +332,7 @@ public class TestPropertiesConfigurationLayout {
     public void testEventSetNonExisting() {
         final ConfigurationEvent event = new ConfigurationEvent(this, ConfigurationEvent.SET_PROPERTY, TEST_KEY, TEST_VALUE, false);
         layout.onEvent(event);
-        assertTrue("New property was not found", layout.getKeys().contains(TEST_KEY));
+        assertTrue(layout.getKeys().contains(TEST_KEY));
     }
 
     /**
@@ -342,17 +340,17 @@ public class TestPropertiesConfigurationLayout {
      */
     @Test
     public void testGetNonExistingLayouData() {
-        assertNull("A comment was found", layout.getComment("unknown"));
-        assertTrue("A multi-line property", layout.isSingleLine("unknown"));
-        assertEquals("Leading blank lines", 0, layout.getBlankLinesBefore("unknown"));
+        assertNull(layout.getComment("unknown"));
+        assertTrue(layout.isSingleLine("unknown"));
+        assertEquals(0, layout.getBlankLinesBefore("unknown"));
     }
 
     /**
      * Tests accessing a property with a null key. This should throw an exception.
      */
-    @Test(expected = IllegalArgumentException.class)
+    @Test
     public void testGetNullLayouttData() {
-        layout.setComment(null, TEST_COMMENT);
+        assertThrows(IllegalArgumentException.class, () -> layout.setComment(null, TEST_COMMENT));
     }
 
     /**
@@ -364,8 +362,8 @@ public class TestPropertiesConfigurationLayout {
         builder.addComment(null);
         builder.addProperty(TEST_KEY, TEST_VALUE);
         layout.load(config, builder.getReader());
-        assertEquals("Wrong header comment", TEST_COMMENT, layout.getCanonicalHeaderComment(false));
-        assertNull("Wrong comment for property", layout.getCanonicalComment(TEST_KEY, false));
+        assertEquals(TEST_COMMENT, layout.getCanonicalHeaderComment(false));
+        assertNull(layout.getCanonicalComment(TEST_KEY, false));
     }
 
     /**
@@ -373,8 +371,8 @@ public class TestPropertiesConfigurationLayout {
      */
     @Test
     public void testHeaderCommentNull() {
-        assertNull("No null comment with comment chars", layout.getCanonicalHeaderComment(true));
-        assertNull("No null comment without comment chars", layout.getCanonicalHeaderComment(false));
+        assertNull(layout.getCanonicalHeaderComment(true));
+        assertNull(layout.getCanonicalHeaderComment(false));
     }
 
     /**
@@ -388,8 +386,8 @@ public class TestPropertiesConfigurationLayout {
         builder.addComment(null);
         builder.addProperty(TEST_KEY, TEST_VALUE);
         layout.load(config, builder.getReader());
-        assertEquals("Wrong header comment", TEST_COMMENT + CRNORM + CRNORM + TEST_COMMENT, layout.getCanonicalHeaderComment(false));
-        assertNull("Wrong comment for property", layout.getComment(TEST_KEY));
+        assertEquals(TEST_COMMENT + CRNORM + CRNORM + TEST_COMMENT, layout.getCanonicalHeaderComment(false));
+        assertNull(layout.getComment(TEST_KEY));
     }
 
     /**
@@ -406,8 +404,8 @@ public class TestPropertiesConfigurationLayout {
         builder.addProperty(TEST_KEY, TEST_VALUE);
         layout.setHeaderComment(presetHeaderComment);
         layout.load(config, builder.getReader());
-        assertEquals("Wrong header comment", presetHeaderComment, layout.getCanonicalHeaderComment(false));
-        assertNull("Wrong comment for property", layout.getComment(TEST_KEY));
+        assertEquals(presetHeaderComment, layout.getCanonicalHeaderComment(false));
+        assertNull(layout.getComment(TEST_KEY));
     }
 
     /**
@@ -423,8 +421,8 @@ public class TestPropertiesConfigurationLayout {
         builder.addComment(TEST_COMMENT);
         builder.addProperty(TEST_KEY, TEST_VALUE);
         layout.load(config, builder.getReader());
-        assertEquals("Wrong header comment", TEST_COMMENT + CRNORM + CRNORM + TEST_COMMENT, layout.getCanonicalHeaderComment(false));
-        assertEquals("Wrong comment for property", TEST_COMMENT, layout.getCanonicalComment(TEST_KEY, false));
+        assertEquals(TEST_COMMENT + CRNORM + CRNORM + TEST_COMMENT, layout.getCanonicalHeaderComment(false));
+        assertEquals(TEST_COMMENT, layout.getCanonicalComment(TEST_KEY, false));
     }
 
     /**
@@ -432,14 +430,14 @@ public class TestPropertiesConfigurationLayout {
      */
     @Test
     public void testInit() {
-        assertTrue("Object contains keys", layout.getKeys().isEmpty());
-        assertNull("Header comment not null", layout.getHeaderComment());
+        assertTrue(layout.getKeys().isEmpty());
+        assertNull(layout.getHeaderComment());
         final Iterator<EventListener<? super ConfigurationEvent>> it = config.getEventListeners(ConfigurationEvent.ANY).iterator();
-        assertTrue("No event listener registered", it.hasNext());
-        assertSame("Layout not registered as event listener", layout, it.next());
-        assertFalse("Multiple event listeners registered", it.hasNext());
-        assertFalse("Force single line flag set", layout.isForceSingleLine());
-        assertNull("Got a global separator", layout.getGlobalSeparator());
+        assertTrue(it.hasNext());
+        assertSame(layout, it.next());
+        assertFalse(it.hasNext());
+        assertFalse(layout.isForceSingleLine());
+        assertNull(layout.getGlobalSeparator());
     }
 
     /**
@@ -449,12 +447,9 @@ public class TestPropertiesConfigurationLayout {
     public void testInitCopy() {
         fillLayout();
         final PropertiesConfigurationLayout l2 = new PropertiesConfigurationLayout(layout);
-        assertEquals("Wrong number of keys", layout.getKeys().size(), l2.getKeys().size());
-        for (final String key : layout.getKeys()) {
-            assertTrue("Key was not found: " + key, l2.getKeys().contains(key));
-        }
-        assertEquals("Wrong header comment", layout.getHeaderComment(), l2.getHeaderComment());
-        assertEquals("Wrong footer comment", layout.getFooterComment(), l2.getFooterComment());
+        assertEquals(l2.getKeys(), layout.getKeys());
+        assertEquals(layout.getHeaderComment(), l2.getHeaderComment());
+        assertEquals(layout.getFooterComment(), l2.getFooterComment());
     }
 
     /**
@@ -464,11 +459,11 @@ public class TestPropertiesConfigurationLayout {
     public void testInitCopyModify() {
         fillLayout();
         final PropertiesConfigurationLayout l2 = new PropertiesConfigurationLayout(layout);
-        assertEquals("Comments are not equal", layout.getComment(TEST_KEY), l2.getComment(TEST_KEY));
+        assertEquals(layout.getComment(TEST_KEY), l2.getComment(TEST_KEY));
         layout.setComment(TEST_KEY, "A new comment");
-        assertEquals("Comment was changed", TEST_COMMENT, l2.getCanonicalComment(TEST_KEY, false));
+        assertEquals(TEST_COMMENT, l2.getCanonicalComment(TEST_KEY, false));
         l2.setBlankLinesBefore(TEST_KEY, l2.getBlankLinesBefore(TEST_KEY) + 1);
-        assertNotEquals("Blanc lines do not differ", layout.getBlankLinesBefore(TEST_KEY), l2.getBlankLinesBefore(TEST_KEY));
+        assertNotEquals(layout.getBlankLinesBefore(TEST_KEY), l2.getBlankLinesBefore(TEST_KEY));
     }
 
     /**
@@ -477,7 +472,7 @@ public class TestPropertiesConfigurationLayout {
     @Test
     public void testInitNull() {
         layout = new PropertiesConfigurationLayout(null);
-        assertTrue("Object contains keys", layout.getKeys().isEmpty());
+        assertTrue(layout.getKeys().isEmpty());
     }
 
     /**
@@ -487,8 +482,8 @@ public class TestPropertiesConfigurationLayout {
     public void testIsSingleLine() throws ConfigurationException {
         builder.addProperty(TEST_KEY, TEST_VALUE + "," + TEST_VALUE + "2");
         layout.load(config, builder.getReader());
-        assertTrue("Wrong single line flag", layout.isSingleLine(TEST_KEY));
-        assertEquals("Wrong number of values", 2, config.getList(TEST_KEY).size());
+        assertTrue(layout.isSingleLine(TEST_KEY));
+        assertEquals(2, config.getList(TEST_KEY).size());
     }
 
     /**
@@ -500,8 +495,8 @@ public class TestPropertiesConfigurationLayout {
         builder.addProperty("anotherProp", "a value");
         builder.addProperty(TEST_KEY, TEST_VALUE + "2");
         layout.load(config, builder.getReader());
-        assertFalse("Wrong single line flag", layout.isSingleLine(TEST_KEY));
-        assertEquals("Wrong number of values", 2, config.getList(TEST_KEY).size());
+        assertFalse(layout.isSingleLine(TEST_KEY));
+        assertEquals(2, config.getList(TEST_KEY).size());
     }
 
     /**
@@ -513,7 +508,7 @@ public class TestPropertiesConfigurationLayout {
         builder.addLine(" ");
         builder.addProperty(TEST_KEY, TEST_VALUE);
         layout.load(config, builder.getReader());
-        assertEquals("Wrong comment", TEST_COMMENT + CRNORM + " ", layout.getCanonicalComment(TEST_KEY, false));
+        assertEquals(TEST_COMMENT + CRNORM + " ", layout.getCanonicalComment(TEST_KEY, false));
     }
 
     /**
@@ -543,13 +538,13 @@ public class TestPropertiesConfigurationLayout {
         builder.addComment(TEST_COMMENT);
         builder.addProperty(TEST_KEY, TEST_VALUE);
         layout.load(config, builder.getReader());
-        assertNull("A header comment was found", layout.getHeaderComment());
-        assertEquals("Wrong number of properties", 1, layout.getKeys().size());
-        assertTrue("Property not found", layout.getKeys().contains(TEST_KEY));
-        assertEquals("Comment not found", TEST_COMMENT, layout.getCanonicalComment(TEST_KEY, false));
-        assertEquals("Wrong number of blank lines", 0, layout.getBlankLinesBefore(TEST_KEY));
-        assertTrue("Wrong single line flag", layout.isSingleLine(TEST_KEY));
-        assertEquals("Property not stored in config", TEST_VALUE, config.getString(TEST_KEY));
+        assertNull(layout.getHeaderComment());
+        assertEquals(1, layout.getKeys().size());
+        assertTrue(layout.getKeys().contains(TEST_KEY));
+        assertEquals(TEST_COMMENT, layout.getCanonicalComment(TEST_KEY, false));
+        assertEquals(0, layout.getBlankLinesBefore(TEST_KEY));
+        assertTrue(layout.isSingleLine(TEST_KEY));
+        assertEquals(TEST_VALUE, config.getString(TEST_KEY));
     }
 
     /**
@@ -575,11 +570,10 @@ public class TestPropertiesConfigurationLayout {
 
         layout.load(config, builder.getReader());
 
-        assertEquals("Wrong header comment", "Header comment", layout.getCanonicalHeaderComment(false));
-        assertFalse("Include property was stored", layout.getKeys().contains(PropertiesConfiguration.getInclude()));
-        assertEquals("Wrong comment for property",
-            TEST_COMMENT + CRNORM + "A nested header comment." + CRNORM + "With multiple lines" + CRNORM + CRNORM + "Second comment",
-            layout.getCanonicalComment(TEST_KEY, false));
+        assertEquals("Header comment", layout.getCanonicalHeaderComment(false));
+        assertFalse(layout.getKeys().contains(PropertiesConfiguration.getInclude()));
+        assertEquals(TEST_COMMENT + CRNORM + "A nested header comment." + CRNORM + "With multiple lines" + CRNORM + CRNORM + "Second comment",
+                layout.getCanonicalComment(TEST_KEY, false));
     }
 
     /**
@@ -609,8 +603,8 @@ public class TestPropertiesConfigurationLayout {
         fillLayout();
         layout.setComment("NonExistingKey", "NonExistingComment");
         final String output = getLayoutString();
-        assertFalse("Non existing key was found", output.contains("NonExistingKey"));
-        assertFalse("Non existing comment was found", output.contains("NonExistingComment"));
+        assertFalse(output.contains("NonExistingKey"));
+        assertFalse(output.contains("NonExistingComment"));
     }
 
     /**
@@ -683,7 +677,7 @@ public class TestPropertiesConfigurationLayout {
     public void testSetNullComment() {
         fillLayout();
         layout.setComment(TEST_KEY, null);
-        assertNull("Comment was not reset", layout.getComment(TEST_KEY));
+        assertNull(layout.getComment(TEST_KEY));
     }
 
     /**
@@ -701,9 +695,11 @@ public class TestPropertiesConfigurationLayout {
      */
     @Test
     public void testTrimComment() {
-        assertEquals("Wrong trimmed comment", "This is a comment" + CR + "that spans multiple" + CR + "lines in a" + CR + " complex way.",
-            PropertiesConfigurationLayout.trimComment("   # This is a comment" + CR + "that spans multiple" + CR + "!lines in a" + CR + " complex way.",
-                false));
+        assertEquals("This is a comment" + CR + "that spans multiple" + CR + "lines in a" + CR + " complex way.",
+                PropertiesConfigurationLayout.trimComment(
+                        "   # This is a comment" + CR + "that spans multiple" + CR + "!lines in a" + CR + " complex way.",
+                        false
+                ));
     }
 
     /**
@@ -711,8 +707,8 @@ public class TestPropertiesConfigurationLayout {
      */
     @Test
     public void testTrimCommentFalse() {
-        assertEquals("Wrong trimmed comment", "# Comment with" + CR + " ! some mixed " + CR + "#comment" + CR + "# lines",
-            PropertiesConfigurationLayout.trimComment("Comment with" + CR + " ! some mixed " + CR + "#comment" + CR + "lines", true));
+        assertEquals("# Comment with" + CR + " ! some mixed " + CR + "#comment" + CR + "# lines",
+                PropertiesConfigurationLayout.trimComment("Comment with" + CR + " ! some mixed " + CR + "#comment" + CR + "lines", true));
     }
 
     /**
@@ -720,7 +716,7 @@ public class TestPropertiesConfigurationLayout {
      */
     @Test
     public void testTrimCommentTrainlingCR() {
-        assertEquals("Wrong trimmed comment", "Comment with" + CR + "trailing CR" + CR,
-            PropertiesConfigurationLayout.trimComment("Comment with" + CR + "! trailing CR" + CR, false));
+        assertEquals("Comment with" + CR + "trailing CR" + CR,
+                PropertiesConfigurationLayout.trimComment("Comment with" + CR + "! trailing CR" + CR, false));
     }
 }
