@@ -6,7 +6,7 @@
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -17,34 +17,33 @@
 
 package org.apache.commons.configuration2.beanutils;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.assertNull;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertInstanceOf;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.assertThrows;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 
 import java.util.Arrays;
 import java.util.HashMap;
 import java.util.List;
 
-import junitx.framework.ObjectAssert;
-
 import org.apache.commons.beanutils.DynaProperty;
 import org.apache.commons.configuration2.BaseConfiguration;
 import org.apache.commons.configuration2.Configuration;
 import org.apache.commons.configuration2.MapConfiguration;
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 /**
  * <p>
  * Test Case for the {@code ConfigurationDynaBean} implementation class. These tests were based on the ones in
  * {@code BasicDynaBeanTestCase} because the two classes provide similar levels of functionality.
  * </p>
- *
  */
 public class TestConfigurationDynaBean {
+
     /**
      * The basic test bean for each test.
      */
@@ -54,22 +53,22 @@ public class TestConfigurationDynaBean {
      * The set of property names we expect to have returned when calling {@code getDynaProperties()}. You should update this
      * list when new properties are added to TestBean.
      */
-    String[] properties = {"booleanProperty", "booleanSecond", "doubleProperty", "floatProperty", "intProperty", "longProperty", "mappedProperty.key1",
-        "mappedProperty.key2", "mappedProperty.key3", "mappedIntProperty.key1", "shortProperty", "stringProperty", "byteProperty", "charProperty"};
+    private final String[] properties = {"booleanProperty", "booleanSecond", "doubleProperty", "floatProperty", "intProperty", "longProperty",
+            "mappedProperty.key1", "mappedProperty.key2", "mappedProperty.key3", "mappedIntProperty.key1", "shortProperty", "stringProperty", "byteProperty",
+            "charProperty"};
 
-    Object[] values = {Boolean.TRUE, Boolean.TRUE, Double.valueOf(Double.MAX_VALUE), Float.valueOf(Float.MAX_VALUE), Integer.valueOf(Integer.MAX_VALUE),
-        Long.valueOf(Long.MAX_VALUE), "First Value", "Second Value", "Third Value", Integer.valueOf(Integer.MAX_VALUE), Short.valueOf(Short.MAX_VALUE),
-        "This is a string", Byte.valueOf(Byte.MAX_VALUE), Character.valueOf(Character.MAX_VALUE)};
+    private final Object[] values = {Boolean.TRUE, Boolean.TRUE, Double.MAX_VALUE, Float.MAX_VALUE, Integer.MAX_VALUE, Long.MAX_VALUE, "First Value",
+            "Second Value", "Third Value", Integer.MAX_VALUE, Short.MAX_VALUE, "This is a string", Byte.MAX_VALUE, Character.MAX_VALUE};
 
-    int[] intArray = {0, 10, 20, 30, 40};
-    boolean[] booleanArray = {true, false, true, false, true};
-    char[] charArray = {'a', 'b', 'c', 'd', 'e'};
-    byte[] byteArray = {0, 10, 20, 30, 40};
-    long[] longArray = {0, 10, 20, 30, 40};
-    short[] shortArray = {0, 10, 20, 30, 40};
-    float[] floatArray = {0, 10, 20, 30, 40};
-    double[] doubleArray = {0.0, 10.0, 20.0, 30.0, 40.0};
-    String[] stringArray = {"String 0", "String 1", "String 2", "String 3", "String 4"};
+    private final int[] intArray = {0, 10, 20, 30, 40};
+    private final boolean[] booleanArray = {true, false, true, false, true};
+    private final char[] charArray = {'a', 'b', 'c', 'd', 'e'};
+    private final byte[] byteArray = {0, 10, 20, 30, 40};
+    private final long[] longArray = {0, 10, 20, 30, 40};
+    private final short[] shortArray = {0, 10, 20, 30, 40};
+    private final float[] floatArray = {0, 10, 20, 30, 40};
+    private final double[] doubleArray = {0.0, 10.0, 20.0, 30.0, 40.0};
+    private final String[] stringArray = {"String 0", "String 1", "String 2", "String 3", "String 4"};
 
     /**
      * Creates the underlying configuration object for the dyna bean.
@@ -81,9 +80,9 @@ public class TestConfigurationDynaBean {
     }
 
     /**
-     * Set up instance variables required by this test case.
+     * Sets up instance variables required by this test case.
      */
-    @Before
+    @BeforeEach
     public void setUp() throws Exception {
         final Configuration configuration = createConfiguration();
 
@@ -92,7 +91,7 @@ public class TestConfigurationDynaBean {
         }
 
         for (final int element : intArray) {
-            configuration.addProperty("intIndexed", Integer.valueOf(element));
+            configuration.addProperty("intIndexed", element);
         }
 
         for (final String element : stringArray) {
@@ -119,19 +118,19 @@ public class TestConfigurationDynaBean {
     /**
      * Tests set on a null value: should throw NPE.
      */
-    @Test(expected = NullPointerException.class)
+    @Test
     public void testAddNullPropertyValue() {
-        bean.set("nullProperty", null);
+        assertThrows(NullPointerException.class, () -> bean.set("nullProperty", null));
     }
 
     /**
      * Corner cases on getDynaProperty invalid arguments.
      */
-    @Test(expected = IllegalArgumentException.class)
+    @Test
     public void testGetDescriptorArguments() {
         final DynaProperty descriptor = bean.getDynaClass().getDynaProperty("unknown");
-        assertNull("Unknown property descriptor should be null", descriptor);
-        bean.getDynaClass().getDynaProperty(null);
+        assertNull(descriptor);
+        assertThrows(IllegalArgumentException.class, () -> bean.getDynaClass().getDynaProperty(null));
     }
 
     /**
@@ -143,8 +142,8 @@ public class TestConfigurationDynaBean {
     protected void testGetDescriptorBase(final String name, final Class<?> type) {
         final DynaProperty descriptor = bean.getDynaClass().getDynaProperty(name);
 
-        assertNotNull("Failed to get descriptor", descriptor);
-        assertEquals("Got incorrect type", type, descriptor.getType());
+        assertNotNull(descriptor);
+        assertEquals(type, descriptor.getType());
     }
 
     /**
@@ -193,9 +192,9 @@ public class TestConfigurationDynaBean {
      */
     @Test
     public void testGetDescriptors() {
-        final DynaProperty pd[] = bean.getDynaClass().getDynaProperties();
-        assertNotNull("Got descriptors", pd);
-        final int count[] = new int[properties.length];
+        final DynaProperty[] pd = bean.getDynaClass().getDynaProperties();
+        assertNotNull(pd);
+        final int[] count = new int[properties.length];
         for (final DynaProperty element : pd) {
             final String name = element.getName();
             for (int j = 0; j < properties.length; j++) {
@@ -206,11 +205,8 @@ public class TestConfigurationDynaBean {
         }
 
         for (int j = 0; j < properties.length; j++) {
-            if (count[j] < 0) {
-                fail("Missing property " + properties[j]);
-            } else if (count[j] > 1) {
-                fail("Duplicate property " + properties[j]);
-            }
+            assertFalse(count[j] < 0, "Missing property " + properties[j]);
+            assertFalse(count[j] > 1, "Duplicate property " + properties[j]);
         }
     }
 
@@ -241,26 +237,26 @@ public class TestConfigurationDynaBean {
     /**
      * Corner cases on getIndexedProperty invalid arguments.
      */
-    @Test(expected = IndexOutOfBoundsException.class)
+    @Test
     public void testGetIndexedArguments() {
-        bean.get("intArray", -1);
+        assertThrows(IndexOutOfBoundsException.class, () -> bean.get("intArray", -1));
     }
 
     /**
      * Tests whether an indexed access to a non-existing property causes an exception.
      */
-    @Test(expected = IllegalArgumentException.class)
+    @Test
     public void testGetIndexedNonExisting() {
-        bean.get("Non existing property", 0);
+        assertThrows(IllegalArgumentException.class, () -> bean.get("Non existing property", 0));
     }
 
     /**
      * Tests whether accessing a non-indexed string property using the index get method causes an exception.
      */
-    @Test(expected = IllegalArgumentException.class)
+    @Test
     public void testGetIndexedString() {
         bean.set("stringProp", "value");
-        bean.get("stringProp", 0);
+        assertThrows(IllegalArgumentException.class, () -> bean.get("stringProp", 0));
     }
 
     /**
@@ -271,34 +267,28 @@ public class TestConfigurationDynaBean {
         for (int i = 0; i < 5; i++) {
             Object value = bean.get("intArray", i);
 
-            assertNotNull("intArray index " + i + " did not return value.", value);
-            ObjectAssert.assertInstanceOf("intArray index " + i, Integer.class, value);
-            assertEquals("intArray " + i + " returned incorrect value.", i * 10, ((Integer) value).intValue());
+            int intValue = assertInstanceOf(Integer.class, value, "intArray index " + i);
+            assertEquals(i * 10, intValue, "intArray " + i);
 
             value = bean.get("intIndexed", i);
 
-            assertNotNull("intIndexed index " + i + "returned value " + i, value);
-            ObjectAssert.assertInstanceOf("intIndexed index " + i, Integer.class, value);
-            assertEquals("intIndexed index " + i + "returned correct " + i, i * 10, ((Integer) value).intValue());
+            intValue = assertInstanceOf(Integer.class, value, "intIndexed index " + i);
+            assertEquals(i * 10, intValue, "intIndexed index " + i);
 
             value = bean.get("listIndexed", i);
 
-            assertNotNull("listIndexed index " + i + "returned value " + i, value);
-            ObjectAssert.assertInstanceOf("list index " + i, String.class, value);
-            assertEquals("listIndexed index " + i + "returned correct " + i, "String " + i, value);
+            assertInstanceOf(String.class, value, "list index " + i);
+            assertEquals("String " + i, value, "listIndexed index " + i);
 
             value = bean.get("stringArray", i);
 
-            assertNotNull("stringArray index " + i + " returnde null.", value);
-            assertFalse("stringArray index " + i + " returned array instead of String.", value.getClass().isArray());
-            ObjectAssert.assertInstanceOf("stringArray index " + i, String.class, value);
-            assertEquals("stringArray returned correct " + i, "String " + i, value);
+            assertInstanceOf(String.class, value, "stringArray index " + i);
+            assertEquals("String " + i, value, "stringArray index " + i);
 
             value = bean.get("stringIndexed", i);
 
-            assertNotNull("stringIndexed returned value " + i, value);
-            ObjectAssert.assertInstanceOf("stringIndexed", String.class, value);
-            assertEquals("stringIndexed returned correct " + i, "String " + i, value);
+            assertInstanceOf(String.class, value, "stringIndexed index " + i);
+            assertEquals("String " + i, value, "stringIndexed index " + i);
         }
     }
 
@@ -307,12 +297,8 @@ public class TestConfigurationDynaBean {
      */
     @Test
     public void testGetMappedArguments() {
-        try {
-            final Object value = bean.get("mappedProperty", "unknown");
-            assertNull("Should not return a value", value);
-        } catch (final Throwable t) {
-            fail("Threw " + t + " instead of returning null");
-        }
+        final Object value = bean.get("mappedProperty", "unknown");
+        assertNull(value);
     }
 
     /**
@@ -321,37 +307,37 @@ public class TestConfigurationDynaBean {
     @Test
     public void testGetMappedValues() {
         Object value = bean.get("mappedProperty", "key1");
-        assertEquals("Can find first value", "First Value", value);
+        assertEquals("First Value", value);
 
         value = bean.get("mappedProperty", "key2");
-        assertEquals("Can find second value", "Second Value", value);
+        assertEquals("Second Value", value);
 
         value = bean.get("mappedProperty", "key3");
-        assertNotNull("Cannot find third value", value);
+        assertNotNull(value);
     }
 
     /**
      * Test the retrieval of a non-existent property.
      */
-    @Test(expected = IllegalArgumentException.class)
+    @Test
     public void testGetNonExistentProperty() {
-        bean.get("nonexistProperty");
+        assertThrows(IllegalArgumentException.class, () -> bean.get("nonexistProperty"));
     }
 
     /**
      * Tests if reading a non-indexed property using the index get method throws an IllegalArgumentException as it should.
      */
-    @Test(expected = IllegalArgumentException.class)
+    @Test
     public void testGetNonIndexedProperties() {
-        bean.get("booleanProperty", 0);
+        assertThrows(IllegalArgumentException.class, () -> bean.get("booleanProperty", 0));
     }
 
     /**
      * Corner cases on getSimpleProperty invalid arguments.
      */
-    @Test(expected = IllegalArgumentException.class)
+    @Test
     public void testGetSimpleArguments() {
-        bean.get("a non existing property");
+        assertThrows(IllegalArgumentException.class, () -> bean.get("a non existing property"));
     }
 
     /**
@@ -360,9 +346,8 @@ public class TestConfigurationDynaBean {
     @Test
     public void testGetSimpleBoolean() {
         final Object value = bean.get("booleanProperty");
-        assertNotNull("Got a value", value);
-        ObjectAssert.assertInstanceOf("Got correct type", Boolean.class, value);
-        assertTrue("Got correct value", ((Boolean) value).booleanValue());
+        assertInstanceOf(Boolean.class, value);
+        assertEquals(Boolean.TRUE, value);
     }
 
     /**
@@ -371,9 +356,8 @@ public class TestConfigurationDynaBean {
     @Test
     public void testGetSimpleDouble() {
         final Object value = bean.get("doubleProperty");
-        assertNotNull("Got a value", value);
-        ObjectAssert.assertInstanceOf("Got correct type", Double.class, value);
-        assertEquals("Got correct value", ((Double) value).doubleValue(), Double.MAX_VALUE, 0.005);
+        final double doubleValue = assertInstanceOf(Double.class, value);
+        assertEquals(Double.MAX_VALUE, doubleValue, 0.005);
     }
 
     /**
@@ -382,9 +366,8 @@ public class TestConfigurationDynaBean {
     @Test
     public void testGetSimpleFloat() {
         final Object value = bean.get("floatProperty");
-        assertNotNull("Got a value", value);
-        ObjectAssert.assertInstanceOf("Got correct type", Float.class, value);
-        assertEquals("Got correct value", ((Float) value).floatValue(), Float.MAX_VALUE, 0.005f);
+        final float floatValue = assertInstanceOf(Float.class, value);
+        assertEquals(Float.MAX_VALUE, floatValue, 0.005f);
     }
 
     /**
@@ -393,9 +376,8 @@ public class TestConfigurationDynaBean {
     @Test
     public void testGetSimpleInt() {
         final Object value = bean.get("intProperty");
-        assertNotNull("Failed to get value", value);
-        ObjectAssert.assertInstanceOf("Incorrect type", Integer.class, value);
-        assertEquals("Incorrect value", ((Integer) value).intValue(), Integer.MAX_VALUE);
+        final int intValue = assertInstanceOf(Integer.class, value);
+        assertEquals(Integer.MAX_VALUE, intValue);
     }
 
     /**
@@ -404,9 +386,8 @@ public class TestConfigurationDynaBean {
     @Test
     public void testGetSimpleLong() {
         final Object value = bean.get("longProperty");
-        assertNotNull("Got a value", value);
-        ObjectAssert.assertInstanceOf("Returned incorrect type", Long.class, value);
-        assertEquals("Returned value of Incorrect value", ((Long) value).longValue(), Long.MAX_VALUE);
+        final long longValue = assertInstanceOf(Long.class, value);
+        assertEquals(Long.MAX_VALUE, longValue);
     }
 
     /**
@@ -415,9 +396,8 @@ public class TestConfigurationDynaBean {
     @Test
     public void testGetSimpleShort() {
         final Object value = bean.get("shortProperty");
-        assertNotNull("Got a value", value);
-        ObjectAssert.assertInstanceOf("Got correct type", Short.class, value);
-        assertEquals("Got correct value", ((Short) value).shortValue(), Short.MAX_VALUE);
+        final short shortValue = assertInstanceOf(Short.class, value);
+        assertEquals(Short.MAX_VALUE, shortValue);
     }
 
     /**
@@ -426,9 +406,8 @@ public class TestConfigurationDynaBean {
     @Test
     public void testGetSimpleString() {
         final Object value = bean.get("stringProperty");
-        assertNotNull("Got a value", value);
-        ObjectAssert.assertInstanceOf("Got correct type", String.class, value);
-        assertEquals("Got correct value", value, "This is a string");
+        assertInstanceOf(String.class, value);
+        assertEquals("This is a string", value);
     }
 
     /**
@@ -436,8 +415,8 @@ public class TestConfigurationDynaBean {
      */
     @Test
     public void testMappedContains() {
-        assertTrue("Can't see first key", bean.contains("mappedProperty", "key1"));
-        assertFalse("Can see unknown key", bean.contains("mappedProperty", "Unknown Key"));
+        assertTrue(bean.contains("mappedProperty", "key1"));
+        assertFalse(bean.contains("mappedProperty", "Unknown Key"));
     }
 
     /**
@@ -445,13 +424,13 @@ public class TestConfigurationDynaBean {
      */
     @Test
     public void testMappedRemove() {
-        assertTrue("Can see first key", bean.contains("mappedProperty", "key1"));
+        assertTrue(bean.contains("mappedProperty", "key1"));
         bean.remove("mappedProperty", "key1");
-        assertFalse("Can not see first key", bean.contains("mappedProperty", "key1"));
+        assertFalse(bean.contains("mappedProperty", "key1"));
 
-        assertFalse("Can not see unknown key", bean.contains("mappedProperty", "key4"));
+        assertFalse(bean.contains("mappedProperty", "key4"));
         bean.remove("mappedProperty", "key4");
-        assertFalse("Can not see unknown key", bean.contains("mappedProperty", "key4"));
+        assertFalse(bean.contains("mappedProperty", "key4"));
     }
 
     /**
@@ -462,10 +441,10 @@ public class TestConfigurationDynaBean {
         final ConfigurationDynaBean nested = (ConfigurationDynaBean) bean.get("mappedProperty");
 
         final String value = (String) nested.get("key1");
-        assertEquals("Can find first value", "First Value", value);
+        assertEquals("First Value", value);
 
         nested.set("key1", "undefined");
-        assertEquals("Incorrect value returned", "undefined", bean.get("mappedProperty.key1"));
+        assertEquals("undefined", bean.get("mappedProperty.key1"));
     }
 
     /**
@@ -481,17 +460,16 @@ public class TestConfigurationDynaBean {
         bean.set("objectArray", 1, "New Value 1");
         final Object value = bean.get("objectArray", 1);
 
-        assertNotNull("Returned new value 1", value);
-        ObjectAssert.assertInstanceOf("Returned String new value 1", String.class, value);
-        assertEquals("Returned correct new value 1", "New Value 1", value);
+        assertInstanceOf(String.class, value);
+        assertEquals("New Value 1", value);
     }
 
     /**
      * Corner cases on setIndexedProperty invalid arguments.
      */
-    @Test(expected = IndexOutOfBoundsException.class)
+    @Test
     public void testSetIndexedArguments() {
-        bean.set("intArray", -1, Integer.valueOf(0));
+        assertThrows(IndexOutOfBoundsException.class, () -> bean.set("intArray", -1, 0));
     }
 
     /**
@@ -499,40 +477,35 @@ public class TestConfigurationDynaBean {
      */
     @Test
     public void testSetIndexedValues() {
-        bean.set("intArray", 0, Integer.valueOf(1));
+        bean.set("intArray", 0, 1);
         Object value = bean.get("intArray", 0);
 
-        assertNotNull("Returned new value 0", value);
-        ObjectAssert.assertInstanceOf("Returned Integer new value 0", Integer.class, value);
-        assertEquals("Returned correct new value 0", 1, ((Integer) value).intValue());
+        int intValue = assertInstanceOf(Integer.class, value);
+        assertEquals(1, intValue);
 
-        bean.set("intIndexed", 1, Integer.valueOf(11));
+        bean.set("intIndexed", 1, 11);
         value = bean.get("intIndexed", 1);
 
-        assertNotNull("Returned new value 1", value);
-        ObjectAssert.assertInstanceOf("Returned Integer new value 1", Integer.class, value);
-        assertEquals("Returned correct new value 1", 11, ((Integer) value).intValue());
+        intValue = assertInstanceOf(Integer.class, value);
+        assertEquals(11, intValue);
 
         bean.set("listIndexed", 2, "New Value 2");
         value = bean.get("listIndexed", 2);
 
-        assertNotNull("Returned new value 2", value);
-        ObjectAssert.assertInstanceOf("Returned String new value 2", String.class, value);
-        assertEquals("Returned correct new value 2", "New Value 2", value);
+        assertInstanceOf(String.class, value);
+        assertEquals("New Value 2", value);
 
         bean.set("stringArray", 3, "New Value 3");
         value = bean.get("stringArray", 3);
 
-        assertNotNull("Returned new value 3", value);
-        ObjectAssert.assertInstanceOf("Returned String new value 3", String.class, value);
-        assertEquals("Returned correct new value 3", "New Value 3", value);
+        assertInstanceOf(String.class, value);
+        assertEquals("New Value 3", value);
 
         bean.set("stringIndexed", 4, "New Value 4");
         value = bean.get("stringIndexed", 4);
 
-        assertNotNull("Returned new value 4", value);
-        ObjectAssert.assertInstanceOf("Returned String new value 4", String.class, value);
-        assertEquals("Returned correct new value 4", "New Value 4", value);
+        assertInstanceOf(String.class, value);
+        assertEquals("New Value 4", value);
     }
 
     /**
@@ -541,19 +514,19 @@ public class TestConfigurationDynaBean {
     @Test
     public void testSetMappedValues() {
         bean.set("mappedProperty", "First Key", "New First Value");
-        assertEquals("Can replace old value", "New First Value", bean.get("mappedProperty", "First Key"));
+        assertEquals("New First Value", bean.get("mappedProperty", "First Key"));
 
         bean.set("mappedProperty", "Fourth Key", "Fourth Value");
-        assertEquals("Can set new value", "Fourth Value", bean.get("mappedProperty", "Fourth Key"));
+        assertEquals("Fourth Value", bean.get("mappedProperty", "Fourth Key"));
     }
 
     /**
      * Tests if writing a non-indexed property using the index set method with an index &gt; 0 throws an
      * IllegalArgumentException as it should.
      */
-    @Test(expected = IllegalArgumentException.class)
+    @Test
     public void testSetNonIndexedProperties() {
-        bean.set("booleanProperty", 1, Boolean.TRUE);
+        assertThrows(IllegalArgumentException.class, () -> bean.set("booleanProperty", 1, Boolean.TRUE));
     }
 
     /**
@@ -563,8 +536,8 @@ public class TestConfigurationDynaBean {
     public void testSetSimpleBoolean() {
         final boolean oldValue = ((Boolean) bean.get("booleanProperty")).booleanValue();
         final boolean newValue = !oldValue;
-        bean.set("booleanProperty", Boolean.valueOf(newValue));
-        assertEquals("Matched new value", newValue, ((Boolean) bean.get("booleanProperty")).booleanValue());
+        bean.set("booleanProperty", newValue);
+        assertEquals(newValue, ((Boolean) bean.get("booleanProperty")).booleanValue());
     }
 
     /**
@@ -574,8 +547,8 @@ public class TestConfigurationDynaBean {
     public void testSetSimpleDouble() {
         final double oldValue = ((Double) bean.get("doubleProperty")).doubleValue();
         final double newValue = oldValue + 1.0;
-        bean.set("doubleProperty", Double.valueOf(newValue));
-        assertEquals("Matched new value", newValue, ((Double) bean.get("doubleProperty")).doubleValue(), 0.005);
+        bean.set("doubleProperty", newValue);
+        assertEquals(newValue, ((Double) bean.get("doubleProperty")).doubleValue(), 0.005);
     }
 
     /**
@@ -585,8 +558,8 @@ public class TestConfigurationDynaBean {
     public void testSetSimpleFloat() {
         final float oldValue = ((Float) bean.get("floatProperty")).floatValue();
         final float newValue = oldValue + (float) 1.0;
-        bean.set("floatProperty", Float.valueOf(newValue));
-        assertEquals("Matched new value", newValue, ((Float) bean.get("floatProperty")).floatValue(), 0.005f);
+        bean.set("floatProperty", newValue);
+        assertEquals(newValue, ((Float) bean.get("floatProperty")).floatValue(), 0.005f);
     }
 
     /**
@@ -596,8 +569,8 @@ public class TestConfigurationDynaBean {
     public void testSetSimpleInt() {
         final int oldValue = ((Integer) bean.get("intProperty")).intValue();
         final int newValue = oldValue + 1;
-        bean.set("intProperty", Integer.valueOf(newValue));
-        assertEquals("Matched new value", newValue, ((Integer) bean.get("intProperty")).intValue());
+        bean.set("intProperty", newValue);
+        assertEquals(newValue, ((Integer) bean.get("intProperty")).intValue());
     }
 
     /**
@@ -607,8 +580,8 @@ public class TestConfigurationDynaBean {
     public void testSetSimpleLong() {
         final long oldValue = ((Long) bean.get("longProperty")).longValue();
         final long newValue = oldValue + 1;
-        bean.set("longProperty", Long.valueOf(newValue));
-        assertEquals("Matched new value", newValue, ((Long) bean.get("longProperty")).longValue());
+        bean.set("longProperty", newValue);
+        assertEquals(newValue, ((Long) bean.get("longProperty")).longValue());
     }
 
     /**
@@ -618,8 +591,8 @@ public class TestConfigurationDynaBean {
     public void testSetSimpleShort() {
         final short oldValue = ((Short) bean.get("shortProperty")).shortValue();
         final short newValue = (short) (oldValue + 1);
-        bean.set("shortProperty", Short.valueOf(newValue));
-        assertEquals("Matched new value", newValue, ((Short) bean.get("shortProperty")).shortValue());
+        bean.set("shortProperty", newValue);
+        assertEquals(newValue, ((Short) bean.get("shortProperty")).shortValue());
     }
 
     /**
@@ -630,6 +603,6 @@ public class TestConfigurationDynaBean {
         final String oldValue = (String) bean.get("stringProperty");
         final String newValue = oldValue + " Extra Value";
         bean.set("stringProperty", newValue);
-        assertEquals("Matched new value", newValue, bean.get("stringProperty"));
+        assertEquals(newValue, bean.get("stringProperty"));
     }
 }
