@@ -16,12 +16,17 @@
  */
 package org.apache.commons.configuration2.builder;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertNotSame;
-import static org.junit.Assert.assertNull;
-import static org.junit.Assert.assertSame;
-import static org.junit.Assert.assertTrue;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNotSame;
+import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.assertSame;
+import static org.junit.jupiter.api.Assertions.assertThrows;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.verify;
+import static org.mockito.Mockito.verifyNoMoreInteractions;
+import static org.mockito.Mockito.when;
 
 import java.util.ArrayList;
 import java.util.Collection;
@@ -30,7 +35,6 @@ import java.util.HashMap;
 import java.util.Map;
 
 import org.apache.commons.configuration2.ConfigurationDecoder;
-import org.apache.commons.configuration2.io.ConfigurationLogger;
 import org.apache.commons.configuration2.beanutils.BeanHelper;
 import org.apache.commons.configuration2.convert.ConversionHandler;
 import org.apache.commons.configuration2.convert.DefaultConversionHandler;
@@ -39,21 +43,20 @@ import org.apache.commons.configuration2.convert.ListDelimiterHandler;
 import org.apache.commons.configuration2.interpol.ConfigurationInterpolator;
 import org.apache.commons.configuration2.interpol.InterpolatorSpecification;
 import org.apache.commons.configuration2.interpol.Lookup;
+import org.apache.commons.configuration2.io.ConfigurationLogger;
 import org.apache.commons.configuration2.sync.ReadWriteSynchronizer;
 import org.apache.commons.configuration2.sync.Synchronizer;
-import org.easymock.EasyMock;
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 /**
  * Test class for {@code BasicBuilderParameters}.
- *
  */
 public class TestBasicBuilderParameters {
     /** The instance to be tested. */
     private BasicBuilderParameters params;
 
-    @Before
+    @BeforeEach
     public void setUp() throws Exception {
         params = new BasicBuilderParameters();
     }
@@ -63,15 +66,15 @@ public class TestBasicBuilderParameters {
      */
     @Test
     public void testCloneDefaultLookups() {
-        final Lookup look = EasyMock.createMock(Lookup.class);
+        final Lookup look = mock(Lookup.class);
         final Collection<Lookup> looks = Collections.singleton(look);
         params.setDefaultLookups(looks);
         final BasicBuilderParameters clone = params.clone();
         Collection<?> defLooks = (Collection<?>) params.getParameters().get("defaultLookups");
         defLooks.clear();
         defLooks = (Collection<?>) clone.getParameters().get("defaultLookups");
-        assertEquals("Wrong number of default lookups", 1, defLooks.size());
-        assertTrue("Wrong default lookup", defLooks.contains(look));
+        assertEquals(1, defLooks.size());
+        assertTrue(defLooks.contains(look));
     }
 
     /**
@@ -79,15 +82,15 @@ public class TestBasicBuilderParameters {
      */
     @Test
     public void testClonePrefixLookups() {
-        final Lookup look = EasyMock.createMock(Lookup.class);
+        final Lookup look = mock(Lookup.class);
         final Map<String, Lookup> lookups = Collections.singletonMap("test", look);
         params.setPrefixLookups(lookups);
         final BasicBuilderParameters clone = params.clone();
         Map<?, ?> map = (Map<?, ?>) params.getParameters().get("prefixLookups");
         map.clear();
         map = (Map<?, ?>) clone.getParameters().get("prefixLookups");
-        assertEquals("Wrong number of lookups", 1, map.size());
-        assertSame("Wrong lookup", look, map.get("test"));
+        assertEquals(1, map.size());
+        assertSame(look, map.get("test"));
     }
 
     /**
@@ -95,10 +98,10 @@ public class TestBasicBuilderParameters {
      */
     @Test
     public void testCloneValues() {
-        final ConfigurationLogger log = EasyMock.createMock(ConfigurationLogger.class);
-        final ConfigurationInterpolator ci = EasyMock.createMock(ConfigurationInterpolator.class);
-        final ListDelimiterHandler handler1 = EasyMock.createMock(ListDelimiterHandler.class);
-        final ListDelimiterHandler handler2 = EasyMock.createMock(ListDelimiterHandler.class);
+        final ConfigurationLogger log = mock(ConfigurationLogger.class);
+        final ConfigurationInterpolator ci = mock(ConfigurationInterpolator.class);
+        final ListDelimiterHandler handler1 = mock(ListDelimiterHandler.class);
+        final ListDelimiterHandler handler2 = mock(ListDelimiterHandler.class);
         params.setListDelimiterHandler(handler1);
         params.setLogger(log);
         params.setInterpolator(ci);
@@ -107,10 +110,10 @@ public class TestBasicBuilderParameters {
         params.setListDelimiterHandler(handler2);
         params.setThrowExceptionOnMissing(false);
         final Map<String, Object> map = clone.getParameters();
-        assertSame("Wrong logger", log, map.get("logger"));
-        assertSame("Wrong interpolator", ci, map.get("interpolator"));
-        assertEquals("Wrong list delimiter handler", handler1, map.get("listDelimiterHandler"));
-        assertEquals("Wrong exception flag", Boolean.TRUE, map.get("throwExceptionOnMissing"));
+        assertSame(log, map.get("logger"));
+        assertSame(ci, map.get("interpolator"));
+        assertEquals(handler1, map.get("listDelimiterHandler"));
+        assertEquals(Boolean.TRUE, map.get("throwExceptionOnMissing"));
     }
 
     /**
@@ -119,7 +122,7 @@ public class TestBasicBuilderParameters {
     @Test
     public void testDefaults() {
         final Map<String, Object> paramMap = params.getParameters();
-        assertTrue("Got parameters", paramMap.isEmpty());
+        assertTrue(paramMap.isEmpty());
     }
 
     /**
@@ -127,15 +130,15 @@ public class TestBasicBuilderParameters {
      */
     @Test
     public void testFetchBeanHelperNoSet() {
-        assertNull("Got a BeanHelper", BasicBuilderParameters.fetchBeanHelper(params.getParameters()));
+        assertNull(BasicBuilderParameters.fetchBeanHelper(params.getParameters()));
     }
 
     /**
      * Tries to invoke fetchBeanHelper() on a null map.
      */
-    @Test(expected = IllegalArgumentException.class)
+    @Test
     public void testFetchBeanHelperNullMap() {
-        BasicBuilderParameters.fetchBeanHelper(null);
+        assertThrows(IllegalArgumentException.class, () -> BasicBuilderParameters.fetchBeanHelper(null));
     }
 
     /**
@@ -143,10 +146,10 @@ public class TestBasicBuilderParameters {
      */
     @Test
     public void testFetchInterpolatorSpecification() {
-        final ConfigurationInterpolator parent = EasyMock.createMock(ConfigurationInterpolator.class);
-        final Lookup l1 = EasyMock.createMock(Lookup.class);
-        final Lookup l2 = EasyMock.createMock(Lookup.class);
-        final Lookup l3 = EasyMock.createMock(Lookup.class);
+        final ConfigurationInterpolator parent = mock(ConfigurationInterpolator.class);
+        final Lookup l1 = mock(Lookup.class);
+        final Lookup l2 = mock(Lookup.class);
+        final Lookup l3 = mock(Lookup.class);
         final Map<String, Lookup> prefixLookups = new HashMap<>();
         prefixLookups.put("p1", l1);
         prefixLookups.put("p2", l2);
@@ -156,10 +159,10 @@ public class TestBasicBuilderParameters {
         params.setDefaultLookups(defLookups);
         final Map<String, Object> map = params.getParameters();
         final InterpolatorSpecification spec = BasicBuilderParameters.fetchInterpolatorSpecification(map);
-        assertSame("Wrong parent", parent, spec.getParentInterpolator());
-        assertEquals("Wrong prefix lookups", prefixLookups, spec.getPrefixLookups());
-        assertEquals("Wrong number of default lookups", 1, spec.getDefaultLookups().size());
-        assertTrue("Wrong default lookup", spec.getDefaultLookups().contains(l3));
+        assertSame(parent, spec.getParentInterpolator());
+        assertEquals(prefixLookups, spec.getPrefixLookups());
+        assertEquals(1, spec.getDefaultLookups().size());
+        assertTrue(spec.getDefaultLookups().contains(l3));
     }
 
     /**
@@ -168,60 +171,60 @@ public class TestBasicBuilderParameters {
     @Test
     public void testFetchInterpolatorSpecificationEmpty() {
         final InterpolatorSpecification spec = BasicBuilderParameters.fetchInterpolatorSpecification(params.getParameters());
-        assertNull("Got an interpolator", spec.getInterpolator());
-        assertTrue("Got lookups", spec.getDefaultLookups().isEmpty());
+        assertNull(spec.getInterpolator());
+        assertTrue(spec.getDefaultLookups().isEmpty());
     }
 
     /**
      * Tests fetchInterpolatorSpecification() if the collection with default lookups contains an invalid value.
      */
-    @Test(expected = IllegalArgumentException.class)
+    @Test
     public void testFetchInterpolatorSpecificationInvalidCollectionValue() {
         final Map<String, Object> map = new HashMap<>();
         map.put("defaultLookups", Collections.singleton("not a lookup"));
-        BasicBuilderParameters.fetchInterpolatorSpecification(map);
+        assertThrows(IllegalArgumentException.class, () -> BasicBuilderParameters.fetchInterpolatorSpecification(map));
     }
 
     /**
      * Tests fetchInterpolatorSpecification() if the map contains a property of an invalid data type.
      */
-    @Test(expected = IllegalArgumentException.class)
+    @Test
     public void testFetchInterpolatorSpecificationInvalidDataType() {
         final Map<String, Object> map = new HashMap<>();
         map.put("interpolator", this);
-        BasicBuilderParameters.fetchInterpolatorSpecification(map);
+        assertThrows(IllegalArgumentException.class, () -> BasicBuilderParameters.fetchInterpolatorSpecification(map));
     }
 
     /**
      * Tests fetchInterpolatorSpecification() if the map with prefix lookups contains an invalid key.
      */
-    @Test(expected = IllegalArgumentException.class)
+    @Test
     public void testFetchInterpolatorSpecificationInvalidMapKey() {
         final Map<String, Object> map = new HashMap<>();
         final Map<Object, Object> prefix = new HashMap<>();
-        prefix.put(42, EasyMock.createMock(Lookup.class));
+        prefix.put(42, mock(Lookup.class));
         map.put("prefixLookups", prefix);
-        BasicBuilderParameters.fetchInterpolatorSpecification(map);
+        assertThrows(IllegalArgumentException.class, () -> BasicBuilderParameters.fetchInterpolatorSpecification(map));
     }
 
     /**
      * Tests fetchInterpolatorSpecification() if the map with prefix lookups contains an invalid value.
      */
-    @Test(expected = IllegalArgumentException.class)
+    @Test
     public void testFetchInterpolatorSpecificationInvalidMapValue() {
         final Map<String, Object> map = new HashMap<>();
         final Map<Object, Object> prefix = new HashMap<>();
         prefix.put("test", this);
         map.put("prefixLookups", prefix);
-        BasicBuilderParameters.fetchInterpolatorSpecification(map);
+        assertThrows(IllegalArgumentException.class, () -> BasicBuilderParameters.fetchInterpolatorSpecification(map));
     }
 
     /**
      * Tries to obtain an {@code InterpolatorSpecification} from a null map.
      */
-    @Test(expected = IllegalArgumentException.class)
+    @Test
     public void testFetchInterpolatorSpecificationNull() {
-        BasicBuilderParameters.fetchInterpolatorSpecification(null);
+        assertThrows(IllegalArgumentException.class, () -> BasicBuilderParameters.fetchInterpolatorSpecification(null));
     }
 
     /**
@@ -229,11 +232,11 @@ public class TestBasicBuilderParameters {
      */
     @Test
     public void testFetchInterpolatorSpecificationWithInterpolator() {
-        final ConfigurationInterpolator ci = EasyMock.createMock(ConfigurationInterpolator.class);
+        final ConfigurationInterpolator ci = mock(ConfigurationInterpolator.class);
         params.setInterpolator(ci);
         final InterpolatorSpecification spec = BasicBuilderParameters.fetchInterpolatorSpecification(params.getParameters());
-        assertSame("Wrong interpolator", ci, spec.getInterpolator());
-        assertNull("Got a parent", spec.getParentInterpolator());
+        assertSame(ci, spec.getInterpolator());
+        assertNull(spec.getParentInterpolator());
     }
 
     /**
@@ -245,8 +248,8 @@ public class TestBasicBuilderParameters {
         final Map<String, Object> mapCopy = new HashMap<>(map1);
         map1.put("otherProperty", "value");
         final Map<String, Object> map2 = params.getParameters();
-        assertNotSame("Same map returned", map1, map2);
-        assertEquals("Different properties", mapCopy, map2);
+        assertNotSame(map1, map2);
+        assertEquals(mapCopy, map2);
     }
 
     /**
@@ -255,7 +258,7 @@ public class TestBasicBuilderParameters {
     @Test
     public void testInheritFrom() {
         final BeanHelper beanHelper = new BeanHelper();
-        final ConfigurationDecoder decoder = EasyMock.createMock(ConfigurationDecoder.class);
+        final ConfigurationDecoder decoder = mock(ConfigurationDecoder.class);
         final ConversionHandler conversionHandler = new DefaultConversionHandler();
         final ListDelimiterHandler listDelimiterHandler = new DefaultListDelimiterHandler('#');
         final ConfigurationLogger logger = new ConfigurationLogger("test");
@@ -266,21 +269,21 @@ public class TestBasicBuilderParameters {
 
         p2.inheritFrom(params.getParameters());
         final Map<String, Object> parameters = p2.getParameters();
-        assertEquals("Bean helper not set", beanHelper, parameters.get("config-BeanHelper"));
-        assertEquals("Decoder not set", decoder, parameters.get("configurationDecoder"));
-        assertEquals("Conversion handler not set", conversionHandler, parameters.get("conversionHandler"));
-        assertEquals("Delimiter handler not set", listDelimiterHandler, parameters.get("listDelimiterHandler"));
-        assertEquals("Logger not set", logger, parameters.get("logger"));
-        assertEquals("Synchronizer not set", synchronizer, parameters.get("synchronizer"));
-        assertEquals("Exception flag not set", Boolean.TRUE, parameters.get("throwExceptionOnMissing"));
+        assertEquals(beanHelper, parameters.get("config-BeanHelper"));
+        assertEquals(decoder, parameters.get("configurationDecoder"));
+        assertEquals(conversionHandler, parameters.get("conversionHandler"));
+        assertEquals(listDelimiterHandler, parameters.get("listDelimiterHandler"));
+        assertEquals(logger, parameters.get("logger"));
+        assertEquals(synchronizer, parameters.get("synchronizer"));
+        assertEquals(Boolean.TRUE, parameters.get("throwExceptionOnMissing"));
     }
 
     /**
      * Tests whether null input is handled by inheritFrom().
      */
-    @Test(expected = IllegalArgumentException.class)
+    @Test
     public void testInheritFromNull() {
-        params.inheritFrom(null);
+        assertThrows(IllegalArgumentException.class, () -> params.inheritFrom(null));
     }
 
     /**
@@ -292,8 +295,7 @@ public class TestBasicBuilderParameters {
 
         p2.inheritFrom(Collections.<String, Object>emptyMap());
         final Map<String, Object> parameters = p2.getParameters();
-        assertEquals("Wrong number of properties", 1, parameters.size());
-        assertEquals("Exception flag not set", Boolean.TRUE, parameters.get("throwExceptionOnMissing"));
+        assertEquals(Collections.singletonMap("throwExceptionOnMissing", Boolean.TRUE), parameters);
     }
 
     /**
@@ -301,31 +303,35 @@ public class TestBasicBuilderParameters {
      */
     @Test
     public void testMerge() {
-        final ListDelimiterHandler handler1 = EasyMock.createMock(ListDelimiterHandler.class);
-        final ListDelimiterHandler handler2 = EasyMock.createMock(ListDelimiterHandler.class);
+        final ListDelimiterHandler handler1 = mock(ListDelimiterHandler.class);
+        final ListDelimiterHandler handler2 = mock(ListDelimiterHandler.class);
         final Map<String, Object> props = new HashMap<>();
         props.put("throwExceptionOnMissing", Boolean.TRUE);
         props.put("listDelimiterHandler", handler1);
         props.put("other", "test");
         props.put(BuilderParameters.RESERVED_PARAMETER_PREFIX + "test", "reserved");
-        final BuilderParameters p = EasyMock.createMock(BuilderParameters.class);
-        EasyMock.expect(p.getParameters()).andReturn(props);
-        EasyMock.replay(p);
+        final BuilderParameters p = mock(BuilderParameters.class);
+
+        when(p.getParameters()).thenReturn(props);
+
         params.setListDelimiterHandler(handler2);
         params.merge(p);
         final Map<String, Object> map = params.getParameters();
-        assertEquals("Wrong list delimiter handler", handler2, map.get("listDelimiterHandler"));
-        assertEquals("Wrong exception flag", Boolean.TRUE, map.get("throwExceptionOnMissing"));
-        assertEquals("Wrong other property", "test", map.get("other"));
-        assertFalse("Reserved property was copied", map.containsKey(BuilderParameters.RESERVED_PARAMETER_PREFIX + "test"));
+        assertEquals(handler2, map.get("listDelimiterHandler"));
+        assertEquals(Boolean.TRUE, map.get("throwExceptionOnMissing"));
+        assertEquals("test", map.get("other"));
+        assertFalse(map.containsKey(BuilderParameters.RESERVED_PARAMETER_PREFIX + "test"));
+
+        verify(p).getParameters();
+        verifyNoMoreInteractions(p);
     }
 
     /**
      * Tries a merge with a null object.
      */
-    @Test(expected = IllegalArgumentException.class)
+    @Test
     public void testMergeNull() {
-        params.merge(null);
+        assertThrows(IllegalArgumentException.class, () -> params.merge(null));
     }
 
     /**
@@ -334,8 +340,8 @@ public class TestBasicBuilderParameters {
     @Test
     public void testSetBeanHelper() {
         final BeanHelper helper = new BeanHelper();
-        assertSame("Wrong result", params, params.setBeanHelper(helper));
-        assertSame("BeanHelper not set", helper, BasicBuilderParameters.fetchBeanHelper(params.getParameters()));
+        assertSame(params, params.setBeanHelper(helper));
+        assertSame(helper, BasicBuilderParameters.fetchBeanHelper(params.getParameters()));
     }
 
     /**
@@ -343,10 +349,9 @@ public class TestBasicBuilderParameters {
      */
     @Test
     public void testSetConfigurationDecoder() {
-        final ConfigurationDecoder decoder = EasyMock.createMock(ConfigurationDecoder.class);
-        EasyMock.replay(decoder);
-        assertSame("Wrong result", params, params.setConfigurationDecoder(decoder));
-        assertSame("Decoder not set", decoder, params.getParameters().get("configurationDecoder"));
+        final ConfigurationDecoder decoder = mock(ConfigurationDecoder.class);
+        assertSame(params, params.setConfigurationDecoder(decoder));
+        assertSame(decoder, params.getParameters().get("configurationDecoder"));
     }
 
     /**
@@ -354,10 +359,9 @@ public class TestBasicBuilderParameters {
      */
     @Test
     public void testSetConversionHandler() {
-        final ConversionHandler handler = EasyMock.createMock(ConversionHandler.class);
-        EasyMock.replay(handler);
-        assertSame("Wrong result", params, params.setConversionHandler(handler));
-        assertSame("ConversionHandler not set", handler, params.getParameters().get("conversionHandler"));
+        final ConversionHandler handler = mock(ConversionHandler.class);
+        assertSame(params, params.setConversionHandler(handler));
+        assertSame(handler, params.getParameters().get("conversionHandler"));
     }
 
     /**
@@ -365,15 +369,15 @@ public class TestBasicBuilderParameters {
      */
     @Test
     public void testSetDefaultLookups() {
-        final Lookup look = EasyMock.createMock(Lookup.class);
+        final Lookup look = mock(Lookup.class);
         final Collection<Lookup> looks = Collections.singleton(look);
-        assertSame("Wrong result", params, params.setDefaultLookups(looks));
+        assertSame(params, params.setDefaultLookups(looks));
         final Collection<?> col = (Collection<?>) params.getParameters().get("defaultLookups");
-        assertNotSame("No copy was created", col, looks);
-        assertEquals("Wrong number of lookups", 1, col.size());
-        assertSame("Wrong lookup", look, col.iterator().next());
+        assertNotSame(col, looks);
+        assertEquals(1, col.size());
+        assertSame(look, col.iterator().next());
         final Collection<?> col2 = (Collection<?>) params.getParameters().get("defaultLookups");
-        assertNotSame("No copy in parameters", col, col2);
+        assertNotSame(col, col2);
     }
 
     /**
@@ -383,7 +387,7 @@ public class TestBasicBuilderParameters {
     public void testSetDefaultLookupsNull() {
         params.setDefaultLookups(new ArrayList<>());
         params.setDefaultLookups(null);
-        assertFalse("Found key", params.getParameters().containsKey("defaultLookups"));
+        assertFalse(params.getParameters().containsKey("defaultLookups"));
     }
 
     /**
@@ -391,10 +395,9 @@ public class TestBasicBuilderParameters {
      */
     @Test
     public void testSetInterpolator() {
-        final ConfigurationInterpolator ci = EasyMock.createMock(ConfigurationInterpolator.class);
-        EasyMock.replay(ci);
-        assertSame("Wrong result", params, params.setInterpolator(ci));
-        assertSame("Wrong interpolator", ci, params.getParameters().get("interpolator"));
+        final ConfigurationInterpolator ci = mock(ConfigurationInterpolator.class);
+        assertSame(params, params.setInterpolator(ci));
+        assertSame(ci, params.getParameters().get("interpolator"));
     }
 
     /**
@@ -402,10 +405,9 @@ public class TestBasicBuilderParameters {
      */
     @Test
     public void testSetListDelimiter() {
-        final ListDelimiterHandler handler = EasyMock.createMock(ListDelimiterHandler.class);
-        EasyMock.replay(handler);
-        assertSame("Wrong result", params, params.setListDelimiterHandler(handler));
-        assertSame("Wrong delimiter handler", handler, params.getParameters().get("listDelimiterHandler"));
+        final ListDelimiterHandler handler = mock(ListDelimiterHandler.class);
+        assertSame(params, params.setListDelimiterHandler(handler));
+        assertSame(handler, params.getParameters().get("listDelimiterHandler"));
     }
 
     /**
@@ -413,10 +415,9 @@ public class TestBasicBuilderParameters {
      */
     @Test
     public void testSetLogger() {
-        final ConfigurationLogger log = EasyMock.createMock(ConfigurationLogger.class);
-        EasyMock.replay(log);
-        assertSame("Wrong result", params, params.setLogger(log));
-        assertSame("Wrong logger parameter", log, params.getParameters().get("logger"));
+        final ConfigurationLogger log = mock(ConfigurationLogger.class);
+        assertSame(params, params.setLogger(log));
+        assertSame(log, params.getParameters().get("logger"));
     }
 
     /**
@@ -424,18 +425,18 @@ public class TestBasicBuilderParameters {
      */
     @Test
     public void testSetLookupsAndInterpolator() {
-        final Lookup look1 = EasyMock.createMock(Lookup.class);
-        final Lookup look2 = EasyMock.createMock(Lookup.class);
-        final ConfigurationInterpolator parent = EasyMock.createMock(ConfigurationInterpolator.class);
-        final ConfigurationInterpolator ci = EasyMock.createMock(ConfigurationInterpolator.class);
+        final Lookup look1 = mock(Lookup.class);
+        final Lookup look2 = mock(Lookup.class);
+        final ConfigurationInterpolator parent = mock(ConfigurationInterpolator.class);
+        final ConfigurationInterpolator ci = mock(ConfigurationInterpolator.class);
         params.setDefaultLookups(Collections.singleton(look1));
         params.setPrefixLookups(Collections.singletonMap("test", look2));
         params.setInterpolator(ci);
         params.setParentInterpolator(parent);
         final Map<String, Object> map = params.getParameters();
-        assertFalse("Got prefix lookups", map.containsKey("prefixLookups"));
-        assertFalse("Got default lookups", map.containsKey("defaultLookups"));
-        assertFalse("Got a parent interpolator", map.containsKey("parentInterpolator"));
+        assertFalse(map.containsKey("prefixLookups"));
+        assertFalse(map.containsKey("defaultLookups"));
+        assertFalse(map.containsKey("parentInterpolator"));
     }
 
     /**
@@ -443,10 +444,9 @@ public class TestBasicBuilderParameters {
      */
     @Test
     public void testSetParentInterpolator() {
-        final ConfigurationInterpolator parent = EasyMock.createMock(ConfigurationInterpolator.class);
-        EasyMock.replay(parent);
-        assertSame("Wrong result", params, params.setParentInterpolator(parent));
-        assertSame("Wrong parent", parent, params.getParameters().get("parentInterpolator"));
+        final ConfigurationInterpolator parent = mock(ConfigurationInterpolator.class);
+        assertSame(params, params.setParentInterpolator(parent));
+        assertSame(parent, params.getParameters().get("parentInterpolator"));
     }
 
     /**
@@ -454,15 +454,14 @@ public class TestBasicBuilderParameters {
      */
     @Test
     public void testSetPrefixLookups() {
-        final Lookup look = EasyMock.createMock(Lookup.class);
+        final Lookup look = mock(Lookup.class);
         final Map<String, Lookup> lookups = Collections.singletonMap("test", look);
-        assertSame("Wrong result", params, params.setPrefixLookups(lookups));
+        assertSame(params, params.setPrefixLookups(lookups));
         final Map<?, ?> map = (Map<?, ?>) params.getParameters().get("prefixLookups");
-        assertNotSame("No copy was created", lookups, map);
-        assertEquals("Wrong lookup", look, map.get("test"));
-        assertEquals("Wrong number of lookups", 1, map.size());
+        assertNotSame(lookups, map);
+        assertEquals(Collections.singletonMap("test", look), map);
         final Map<?, ?> map2 = (Map<?, ?>) params.getParameters().get("prefixLookups");
-        assertNotSame("No copy in parameters", map, map2);
+        assertNotSame(map, map2);
     }
 
     /**
@@ -472,7 +471,7 @@ public class TestBasicBuilderParameters {
     public void testSetPrefixLookupsNull() {
         params.setPrefixLookups(new HashMap<>());
         params.setPrefixLookups(null);
-        assertFalse("Found key", params.getParameters().containsKey("prefixLookups"));
+        assertFalse(params.getParameters().containsKey("prefixLookups"));
     }
 
     /**
@@ -480,10 +479,9 @@ public class TestBasicBuilderParameters {
      */
     @Test
     public void testSetSynchronizer() {
-        final Synchronizer sync = EasyMock.createMock(Synchronizer.class);
-        EasyMock.replay(sync);
-        assertSame("Wrong result", params, params.setSynchronizer(sync));
-        assertSame("Synchronizer not set", sync, params.getParameters().get("synchronizer"));
+        final Synchronizer sync = mock(Synchronizer.class);
+        assertSame(params, params.setSynchronizer(sync));
+        assertSame(sync, params.getParameters().get("synchronizer"));
     }
 
     /**
@@ -491,7 +489,7 @@ public class TestBasicBuilderParameters {
      */
     @Test
     public void testSetThrowExceptionOnMissing() {
-        assertSame("Wrong result", params, params.setThrowExceptionOnMissing(true));
-        assertEquals("Wrong flag value", Boolean.TRUE, params.getParameters().get("throwExceptionOnMissing"));
+        assertSame(params, params.setThrowExceptionOnMissing(true));
+        assertEquals(Boolean.TRUE, params.getParameters().get("throwExceptionOnMissing"));
     }
 }
