@@ -16,11 +16,16 @@
  */
 package org.apache.commons.configuration2.builder;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertNotSame;
-import static org.junit.Assert.assertSame;
-import static org.junit.Assert.assertTrue;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNotSame;
+import static org.junit.jupiter.api.Assertions.assertSame;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.times;
+import static org.mockito.Mockito.verify;
+import static org.mockito.Mockito.verifyNoMoreInteractions;
+import static org.mockito.Mockito.when;
 
 import java.util.HashMap;
 import java.util.Map;
@@ -30,18 +35,16 @@ import org.apache.commons.configuration2.ex.ConfigurationException;
 import org.apache.commons.configuration2.io.FileHandler;
 import org.apache.commons.configuration2.reloading.FileHandlerReloadingDetector;
 import org.apache.commons.configuration2.reloading.ReloadingDetector;
-import org.easymock.EasyMock;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 /**
  * Test class for {@code ReloadingFileBasedConfigurationBuilder}.
- *
  */
 public class TestReloadingFileBasedConfigurationBuilder {
     /**
      * A test builder implementation which allows mocking the underlying reloading detector.
      */
-    private static class ReloadingFileBasedConfigurationBuilderTestImpl extends ReloadingFileBasedConfigurationBuilder<PropertiesConfiguration> {
+    private static final class ReloadingFileBasedConfigurationBuilderTestImpl extends ReloadingFileBasedConfigurationBuilder<PropertiesConfiguration> {
         /** The mock for the reloading detector. */
         private final ReloadingDetector mockDetector;
 
@@ -90,8 +93,8 @@ public class TestReloadingFileBasedConfigurationBuilder {
         final long refreshDelay = 60000L;
         params.setReloadingRefreshDelay(refreshDelay);
         final FileHandlerReloadingDetector detector = (FileHandlerReloadingDetector) builder.createReloadingDetector(handler, params);
-        assertSame("Wrong file handler", handler, detector.getFileHandler());
-        assertEquals("Wrong refresh delay", refreshDelay, detector.getRefreshDelay());
+        assertSame(handler, detector.getFileHandler());
+        assertEquals(refreshDelay, detector.getRefreshDelay());
     }
 
     /**
@@ -99,17 +102,20 @@ public class TestReloadingFileBasedConfigurationBuilder {
      */
     @Test
     public void testCreateReloadingDetectoryCustomFactory() throws ConfigurationException {
-        final ReloadingDetector detector = EasyMock.createMock(ReloadingDetector.class);
-        final ReloadingDetectorFactory factory = EasyMock.createMock(ReloadingDetectorFactory.class);
+        final ReloadingDetector detector = mock(ReloadingDetector.class);
+        final ReloadingDetectorFactory factory = mock(ReloadingDetectorFactory.class);
         final FileHandler handler = new FileHandler();
         final FileBasedBuilderParametersImpl params = new FileBasedBuilderParametersImpl();
-        EasyMock.expect(factory.createReloadingDetector(handler, params)).andReturn(detector);
-        EasyMock.replay(detector, factory);
+
+        when(factory.createReloadingDetector(handler, params)).thenReturn(detector);
+
         params.setReloadingDetectorFactory(factory);
         final ReloadingFileBasedConfigurationBuilder<PropertiesConfiguration> builder = new ReloadingFileBasedConfigurationBuilder<>(
             PropertiesConfiguration.class);
-        assertSame("Wrong detector", detector, builder.createReloadingDetector(handler, params));
-        EasyMock.verify(factory);
+        assertSame(detector, builder.createReloadingDetector(handler, params));
+
+        verify(factory).createReloadingDetector(handler, params);
+        verifyNoMoreInteractions(factory);
     }
 
     /**
@@ -123,8 +129,8 @@ public class TestReloadingFileBasedConfigurationBuilder {
         final ReloadingFileBasedConfigurationBuilder<PropertiesConfiguration> builder = new ReloadingFileBasedConfigurationBuilder<>(
             PropertiesConfiguration.class, params);
         final PropertiesConfiguration conf = builder.getConfiguration();
-        assertTrue("Property not set", conf.isThrowExceptionOnMissing());
-        assertTrue("Not empty", conf.isEmpty());
+        assertTrue(conf.isThrowExceptionOnMissing());
+        assertTrue(conf.isEmpty());
     }
 
     /**
@@ -134,7 +140,7 @@ public class TestReloadingFileBasedConfigurationBuilder {
     public void testInitAllowFailOnInitFlag() {
         final ReloadingFileBasedConfigurationBuilder<PropertiesConfiguration> builder = new ReloadingFileBasedConfigurationBuilder<>(
             PropertiesConfiguration.class, null, true);
-        assertTrue("Flag not set", builder.isAllowFailOnInit());
+        assertTrue(builder.isAllowFailOnInit());
     }
 
     /**
@@ -142,17 +148,20 @@ public class TestReloadingFileBasedConfigurationBuilder {
      */
     @Test
     public void testReloadingControllerEvents() throws ConfigurationException {
-        final ReloadingDetector detector = EasyMock.createMock(ReloadingDetector.class);
-        EasyMock.expect(detector.isReloadingRequired()).andReturn(Boolean.TRUE);
+        final ReloadingDetector detector = mock(ReloadingDetector.class);
+
+        when(detector.isReloadingRequired()).thenReturn(Boolean.TRUE);
+
         final ReloadingFileBasedConfigurationBuilderTestImpl builder = new ReloadingFileBasedConfigurationBuilderTestImpl(detector);
-        EasyMock.replay(detector);
         final BuilderEventListenerImpl listener = new BuilderEventListenerImpl();
         builder.addEventListener(ConfigurationBuilderEvent.RESET, listener);
         builder.getConfiguration();
         builder.getReloadingController().checkForReloading(null);
         listener.nextEvent(ConfigurationBuilderEvent.RESET);
         listener.assertNoMoreEvents();
-        EasyMock.verify(detector);
+
+        verify(detector).isReloadingRequired();
+        verifyNoMoreInteractions(detector);
     }
 
     /**
@@ -160,17 +169,19 @@ public class TestReloadingFileBasedConfigurationBuilder {
      */
     @Test
     public void testReloadingDetectorIsReloadingRequired() throws ConfigurationException {
-        final ReloadingDetector detector = EasyMock.createMock(ReloadingDetector.class);
-        EasyMock.expect(detector.isReloadingRequired()).andReturn(Boolean.TRUE);
-        EasyMock.expect(detector.isReloadingRequired()).andReturn(Boolean.FALSE);
-        EasyMock.replay(detector);
+        final ReloadingDetector detector = mock(ReloadingDetector.class);
+
+        when(detector.isReloadingRequired()).thenReturn(Boolean.TRUE, Boolean.FALSE);
+
         final ReloadingFileBasedConfigurationBuilderTestImpl builder = new ReloadingFileBasedConfigurationBuilderTestImpl(detector);
         builder.getConfiguration();
         final ReloadingDetector ctrlDetector = builder.getReloadingController().getDetector();
-        assertTrue("Wrong result (1)", ctrlDetector.isReloadingRequired());
-        assertFalse("Wrong result (2)", ctrlDetector.isReloadingRequired());
-        assertSame("Wrong file handler", builder.getFileHandler(), builder.getHandlerForDetector());
-        EasyMock.verify(detector);
+        assertTrue(ctrlDetector.isReloadingRequired());
+        assertFalse(ctrlDetector.isReloadingRequired());
+        assertSame(builder.getFileHandler(), builder.getHandlerForDetector());
+
+        verify(detector, times(2)).isReloadingRequired();
+        verifyNoMoreInteractions(detector);
     }
 
     /**
@@ -182,7 +193,7 @@ public class TestReloadingFileBasedConfigurationBuilder {
             PropertiesConfiguration.class);
         final ReloadingDetector ctrlDetector = builder.getReloadingController().getDetector();
         ctrlDetector.reloadingPerformed();
-        assertFalse("Wrong result", ctrlDetector.isReloadingRequired());
+        assertFalse(ctrlDetector.isReloadingRequired());
     }
 
     /**
@@ -190,14 +201,14 @@ public class TestReloadingFileBasedConfigurationBuilder {
      */
     @Test
     public void testReloadingDetectorReloadingPerformed() throws ConfigurationException {
-        final ReloadingDetector detector = EasyMock.createMock(ReloadingDetector.class);
-        detector.reloadingPerformed();
-        EasyMock.replay(detector);
+        final ReloadingDetector detector = mock(ReloadingDetector.class);
         final ReloadingFileBasedConfigurationBuilderTestImpl builder = new ReloadingFileBasedConfigurationBuilderTestImpl(detector);
         builder.getConfiguration();
         final ReloadingDetector ctrlDetector = builder.getReloadingController().getDetector();
         ctrlDetector.reloadingPerformed();
-        EasyMock.verify(detector);
+
+        verify(detector).reloadingPerformed();
+        verifyNoMoreInteractions(detector);
     }
 
     /**
@@ -205,16 +216,19 @@ public class TestReloadingFileBasedConfigurationBuilder {
      */
     @Test
     public void testResetReloadingStateInGetConfiguration() throws ConfigurationException {
-        final ReloadingDetector detector = EasyMock.createMock(ReloadingDetector.class);
-        EasyMock.expect(detector.isReloadingRequired()).andReturn(Boolean.TRUE);
-        detector.reloadingPerformed();
-        EasyMock.replay(detector);
+        final ReloadingDetector detector = mock(ReloadingDetector.class);
+
+        when(detector.isReloadingRequired()).thenReturn(Boolean.TRUE);
+
         final ReloadingFileBasedConfigurationBuilderTestImpl builder = new ReloadingFileBasedConfigurationBuilderTestImpl(detector);
         final PropertiesConfiguration config1 = builder.getConfiguration();
         builder.getReloadingController().checkForReloading(null);
         final PropertiesConfiguration config2 = builder.getConfiguration();
-        assertNotSame("No new configuration instance", config1, config2);
-        assertFalse("Still in reloading state", builder.getReloadingController().isInReloadingState());
-        EasyMock.verify(detector);
+        assertNotSame(config1, config2);
+        assertFalse(builder.getReloadingController().isInReloadingState());
+
+        verify(detector).isReloadingRequired();
+        verify(detector).reloadingPerformed();
+        verifyNoMoreInteractions(detector);
     }
 }
