@@ -16,18 +16,26 @@
  */
 package org.apache.commons.configuration2.io;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.assertNull;
-import static org.junit.Assert.assertSame;
-import static org.junit.Assert.assertTrue;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertInstanceOf;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.assertSame;
+import static org.junit.jupiter.api.Assertions.assertThrows;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.mockito.ArgumentMatchers.any;
+import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.verify;
+import static org.mockito.Mockito.verifyNoMoreInteractions;
+import static org.mockito.Mockito.when;
 
 import java.io.File;
 import java.net.MalformedURLException;
 import java.net.URI;
 import java.net.URISyntaxException;
 import java.net.URL;
+import java.nio.charset.StandardCharsets;
 import java.util.HashMap;
 import java.util.Iterator;
 import java.util.Map;
@@ -35,13 +43,11 @@ import java.util.Map;
 import org.apache.commons.configuration2.ConfigurationAssert;
 import org.apache.commons.configuration2.XMLConfiguration;
 import org.apache.commons.configuration2.ex.ConfigurationException;
-import org.easymock.EasyMock;
-import org.junit.BeforeClass;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.Test;
 
 /**
  * Test class for {@code FileLocatorUtils}.
- *
  */
 public class TestFileLocatorUtils {
     /** Constant for a file name. */
@@ -51,7 +57,7 @@ public class TestFileLocatorUtils {
     private static final String BASE_PATH = "/etc/test/path/";
 
     /** Constant for a test encoding. */
-    private static final String ENCODING = "utf-8";
+    private static final String ENCODING = StandardCharsets.UTF_8.name();
 
     /** A test URL. */
     private static URL sourceURL;
@@ -66,9 +72,9 @@ public class TestFileLocatorUtils {
      * @throws ConfigurationException if an error occurs
      */
     private static void checkFullyInitializedLocator(final FileLocator locator) throws ConfigurationException {
-        assertNotNull("No base path", locator.getBasePath());
-        assertNotNull("No file name", locator.getFileName());
-        assertNotNull("No source URL", locator.getSourceURL());
+        assertNotNull(locator.getBasePath());
+        assertNotNull(locator.getFileName());
+        assertNotNull(locator.getSourceURL());
 
         FileHandler handler = new FileHandler();
         handler.setBasePath(locator.getBasePath());
@@ -90,14 +96,13 @@ public class TestFileLocatorUtils {
         final XMLConfiguration config = new XMLConfiguration();
         final FileHandler h2 = new FileHandler(config, handler);
         h2.load();
-        assertEquals("Wrong content", "value", config.getString("element"));
+        assertEquals("value", config.getString("element"));
     }
 
-    @BeforeClass
+    @BeforeAll
     public static void setUpOnce() throws Exception {
         sourceURL = ConfigurationAssert.getTestURL(FILE_NAME);
-        fileSystem = EasyMock.createMock(FileSystem.class);
-        EasyMock.replay(fileSystem);
+        fileSystem = mock(FileSystem.class);
     }
 
     /**
@@ -117,7 +122,7 @@ public class TestFileLocatorUtils {
     @Test
     public void testConvertToURIException() throws URISyntaxException {
         final URI uri = new URI("test://test/path/file.tst");
-        assertNull("Got a URL", FileLocatorUtils.convertURIToURL(uri));
+        assertNull(FileLocatorUtils.convertURIToURL(uri));
     }
 
     /**
@@ -127,17 +132,17 @@ public class TestFileLocatorUtils {
     public void testDefaultFileLocationStrategy() {
         final CombinedLocationStrategy strategy = (CombinedLocationStrategy) FileLocatorUtils.DEFAULT_LOCATION_STRATEGY;
         final Iterator<FileLocationStrategy> it = strategy.getSubStrategies().iterator();
-        assertTrue("Wrong strategy (1)", it.next() instanceof ProvidedURLLocationStrategy);
-        assertTrue("Wrong strategy (2)", it.next() instanceof FileSystemLocationStrategy);
-        assertTrue("Wrong strategy (3)", it.next() instanceof AbsoluteNameLocationStrategy);
-        assertTrue("Wrong strategy (4)", it.next() instanceof BasePathLocationStrategy);
+        assertInstanceOf(ProvidedURLLocationStrategy.class, it.next());
+        assertInstanceOf(FileSystemLocationStrategy.class, it.next());
+        assertInstanceOf(AbsoluteNameLocationStrategy.class, it.next());
+        assertInstanceOf(BasePathLocationStrategy.class, it.next());
         FileLocationStrategy sub = it.next();
-        assertTrue("Wrong strategy (5)", sub instanceof HomeDirectoryLocationStrategy);
-        assertTrue("Base path ignored", ((HomeDirectoryLocationStrategy) sub).isEvaluateBasePath());
+        HomeDirectoryLocationStrategy subStrategy = assertInstanceOf(HomeDirectoryLocationStrategy.class, sub);
+        assertTrue(subStrategy.isEvaluateBasePath());
         sub = it.next();
-        assertTrue("Wrong strategy (6)", sub instanceof HomeDirectoryLocationStrategy);
-        assertFalse("Base path not ignored", ((HomeDirectoryLocationStrategy) sub).isEvaluateBasePath());
-        assertTrue("Wrong strategy (7)", it.next() instanceof ClasspathLocationStrategy);
+        subStrategy = assertInstanceOf(HomeDirectoryLocationStrategy.class, sub);
+        assertFalse(subStrategy.isEvaluateBasePath());
+        assertInstanceOf(ClasspathLocationStrategy.class, it.next());
     }
 
     /**
@@ -145,7 +150,7 @@ public class TestFileLocatorUtils {
      */
     @Test
     public void testFileFromURLNull() throws Exception {
-        assertNull("Wrong file for null URL", FileLocatorUtils.fileFromURL(null));
+        assertNull(FileLocatorUtils.fileFromURL(null));
     }
 
     /**
@@ -157,7 +162,7 @@ public class TestFileLocatorUtils {
         final File file = new File("https%3A%2F%2Fwww.apache.org%2F.url").getAbsoluteFile();
         final URL fileURL = file.toURI().toURL();
         final File file2 = FileLocatorUtils.fileFromURL(fileURL);
-        assertEquals("Wrong file", file, file2);
+        assertEquals(file, file2);
     }
 
     /**
@@ -169,7 +174,7 @@ public class TestFileLocatorUtils {
         final File file = new File(new File("target"), "foo+bar.txt").getAbsoluteFile();
         final URL fileURL = file.toURI().toURL();
         final File file2 = FileLocatorUtils.fileFromURL(fileURL);
-        assertEquals("Wrong file", file, file2);
+        assertEquals(file, file2);
     }
 
     /**
@@ -178,7 +183,7 @@ public class TestFileLocatorUtils {
     @Test
     public void testFromMapNoMap() {
         final FileLocator fileLocator = FileLocatorUtils.fromMap(null);
-        assertEquals("Locator is initialized", FileLocatorUtils.fileLocator().create(), fileLocator);
+        assertEquals(FileLocatorUtils.fileLocator().create(), fileLocator);
     }
 
     /**
@@ -188,7 +193,7 @@ public class TestFileLocatorUtils {
     public void testFullyInitializedLocatorAlreadyComplete() {
         final FileLocator locator = FileLocatorUtils.fileLocator().fileName(FILE_NAME).create();
         final FileLocator fullLocator = FileLocatorUtils.fullyInitializedLocator(locator);
-        assertSame("Different instance", fullLocator, FileLocatorUtils.fullyInitializedLocator(fullLocator));
+        assertSame(fullLocator, FileLocatorUtils.fullyInitializedLocator(fullLocator));
     }
 
     /**
@@ -206,7 +211,7 @@ public class TestFileLocatorUtils {
     @Test
     public void testFullyInitializedLocatorLocateFails() {
         final FileLocator locator = FileLocatorUtils.fileLocator().fileName("non existing file").create();
-        assertNull("Wrong result", FileLocatorUtils.fullyInitializedLocator(locator));
+        assertNull(FileLocatorUtils.fullyInitializedLocator(locator));
     }
 
     /**
@@ -214,7 +219,7 @@ public class TestFileLocatorUtils {
      */
     @Test
     public void testFullyInitializedLocatorUndefined() {
-        assertNull("Got a result", FileLocatorUtils.fullyInitializedLocator(FileLocatorUtils.fileLocator().create()));
+        assertNull(FileLocatorUtils.fullyInitializedLocator(FileLocatorUtils.fileLocator().create()));
     }
 
     /**
@@ -229,19 +234,19 @@ public class TestFileLocatorUtils {
     @Test
     public void testGetBasePath() throws Exception {
         URL url = new URL("http://xyz.net/foo/bar.xml");
-        assertEquals("base path of " + url, "http://xyz.net/foo/", FileLocatorUtils.getBasePath(url));
+        assertEquals("http://xyz.net/foo/", FileLocatorUtils.getBasePath(url));
 
         url = new URL("http://xyz.net/foo/");
-        assertEquals("base path of " + url, "http://xyz.net/foo/", FileLocatorUtils.getBasePath(url));
+        assertEquals("http://xyz.net/foo/", FileLocatorUtils.getBasePath(url));
 
         url = new URL("http://xyz.net/foo");
-        assertEquals("base path of " + url, "http://xyz.net/", FileLocatorUtils.getBasePath(url));
+        assertEquals("http://xyz.net/", FileLocatorUtils.getBasePath(url));
 
         url = new URL("http://xyz.net/");
-        assertEquals("base path of " + url, "http://xyz.net/", FileLocatorUtils.getBasePath(url));
+        assertEquals("http://xyz.net/", FileLocatorUtils.getBasePath(url));
 
         url = new URL("http://xyz.net");
-        assertEquals("base path of " + url, "http://xyz.net", FileLocatorUtils.getBasePath(url));
+        assertEquals("http://xyz.net", FileLocatorUtils.getBasePath(url));
     }
 
     @Test
@@ -249,23 +254,23 @@ public class TestFileLocatorUtils {
         final File directory = new File("target");
         final File reference = new File(directory, "test.txt").getAbsoluteFile();
 
-        assertEquals(reference, FileLocatorUtils.getFile(null, reference.getAbsolutePath()));
-        assertEquals(reference, FileLocatorUtils.getFile(directory.getAbsolutePath(), reference.getAbsolutePath()));
-        assertEquals(reference, FileLocatorUtils.getFile(directory.getAbsolutePath(), reference.getName()));
-        assertEquals(reference, FileLocatorUtils.getFile(directory.toURI().toURL().toString(), reference.getName()));
-        assertEquals(reference, FileLocatorUtils.getFile("invalid", reference.toURI().toURL().toString()));
-        assertEquals(reference, FileLocatorUtils.getFile("jar:file:/C:/myjar.jar!/my-config.xml/someprops.properties", reference.getAbsolutePath()));
+        assertEquals(FileLocatorUtils.getFile(null, reference.getAbsolutePath()), reference);
+        assertEquals(FileLocatorUtils.getFile(directory.getAbsolutePath(), reference.getAbsolutePath()), reference);
+        assertEquals(FileLocatorUtils.getFile(directory.getAbsolutePath(), reference.getName()), reference);
+        assertEquals(FileLocatorUtils.getFile(directory.toURI().toURL().toString(), reference.getName()), reference);
+        assertEquals(FileLocatorUtils.getFile("invalid", reference.toURI().toURL().toString()), reference);
+        assertEquals(FileLocatorUtils.getFile("jar:file:/C:/myjar.jar!/my-config.xml/someprops.properties", reference.getAbsolutePath()), reference);
     }
 
     @Test
     public void testGetFileName() throws Exception {
-        assertNull("file name for a null URL", FileLocatorUtils.getFileName(null));
+        assertNull(FileLocatorUtils.getFileName(null));
 
         URL url = new URL("http://xyz.net/foo/");
-        assertNull("file for a directory URL " + url, FileLocatorUtils.getFileName(url));
+        assertNull(FileLocatorUtils.getFileName(url));
 
         url = new URL("http://xyz.net/foo/bar.xml");
-        assertEquals("file name for a valid URL " + url, "bar.xml", FileLocatorUtils.getFileName(url));
+        assertEquals("bar.xml", FileLocatorUtils.getFileName(url));
     }
 
     /**
@@ -274,7 +279,7 @@ public class TestFileLocatorUtils {
     @Test
     public void testIsFullyInitializedNoBasePath() {
         final FileLocator locator = FileLocatorUtils.fileLocator().sourceURL(ConfigurationAssert.getTestURL(FILE_NAME)).fileName(FILE_NAME).create();
-        assertFalse("Wrong result", FileLocatorUtils.isFullyInitialized(locator));
+        assertFalse(FileLocatorUtils.isFullyInitialized(locator));
     }
 
     /**
@@ -282,7 +287,7 @@ public class TestFileLocatorUtils {
      */
     @Test
     public void testIsFullyInitializedNull() {
-        assertFalse("Wrong result", FileLocatorUtils.isFullyInitialized(null));
+        assertFalse(FileLocatorUtils.isFullyInitialized(null));
     }
 
     /**
@@ -292,7 +297,7 @@ public class TestFileLocatorUtils {
     public void testIsLocationDefinedFalse() {
         final FileLocator locator = FileLocatorUtils.fileLocator().encoding(ENCODING).basePath(BASE_PATH).fileSystem(FileLocatorUtils.DEFAULT_FILE_SYSTEM)
             .create();
-        assertFalse("Wrong result", FileLocatorUtils.isLocationDefined(locator));
+        assertFalse(FileLocatorUtils.isLocationDefined(locator));
     }
 
     /**
@@ -301,7 +306,7 @@ public class TestFileLocatorUtils {
     @Test
     public void testIsLocationDefinedFileName() {
         final FileLocator locator = FileLocatorUtils.fileLocator().fileName(FILE_NAME).create();
-        assertTrue("Wrong result", FileLocatorUtils.isLocationDefined(locator));
+        assertTrue(FileLocatorUtils.isLocationDefined(locator));
     }
 
     /**
@@ -309,7 +314,7 @@ public class TestFileLocatorUtils {
      */
     @Test
     public void testIsLocationDefinedNull() {
-        assertFalse("Wrong result", FileLocatorUtils.isLocationDefined(null));
+        assertFalse(FileLocatorUtils.isLocationDefined(null));
     }
 
     /**
@@ -318,7 +323,7 @@ public class TestFileLocatorUtils {
     @Test
     public void testIsLocationDefinedURL() {
         final FileLocator locator = FileLocatorUtils.fileLocator().sourceURL(ConfigurationAssert.getTestURL(FILE_NAME)).create();
-        assertTrue("Wrong result", FileLocatorUtils.isLocationDefined(locator));
+        assertTrue(FileLocatorUtils.isLocationDefined(locator));
     }
 
     /**
@@ -326,19 +331,20 @@ public class TestFileLocatorUtils {
      */
     @Test
     public void testLocateNullLocator() {
-        assertNull("Wrong result", FileLocatorUtils.locate(null));
+        assertNull(FileLocatorUtils.locate(null));
     }
 
     /**
      * Tests whether an exception is thrown for a failed locate() operation.
      */
-    @Test(expected = ConfigurationException.class)
-    public void testLocateOrThrowFailed() throws ConfigurationException {
-        final FileLocationStrategy strategy = EasyMock.createMock(FileLocationStrategy.class);
-        EasyMock.expect(strategy.locate(EasyMock.anyObject(FileSystem.class), EasyMock.anyObject(FileLocator.class))).andReturn(null);
-        EasyMock.replay(strategy);
+    @Test
+    public void testLocateOrThrowFailed() {
+        final FileLocationStrategy strategy = mock(FileLocationStrategy.class);
+
+        when(strategy.locate(any(), any())).thenReturn(null);
+
         final FileLocator locator = FileLocatorUtils.fileLocator().locationStrategy(strategy).create();
-        FileLocatorUtils.locateOrThrow(locator);
+        assertThrows(ConfigurationException.class, () -> FileLocatorUtils.locateOrThrow(locator));
     }
 
     /**
@@ -347,7 +353,7 @@ public class TestFileLocatorUtils {
     @Test
     public void testLocateSuccessWithDefaults() {
         final FileLocator locator = FileLocatorUtils.fileLocator().sourceURL(sourceURL).create();
-        assertSame("Wrong URL", sourceURL, FileLocatorUtils.locate(locator));
+        assertSame(sourceURL, FileLocatorUtils.locate(locator));
     }
 
     /**
@@ -355,13 +361,16 @@ public class TestFileLocatorUtils {
      */
     @Test
     public void testLocateSuccessWithStrategyAndFileSystem() throws ConfigurationException {
-        final FileSystem fs = EasyMock.createMock(FileSystem.class);
-        final FileLocationStrategy strategy = EasyMock.createMock(FileLocationStrategy.class);
+        final FileSystem fs = mock(FileSystem.class);
+        final FileLocationStrategy strategy = mock(FileLocationStrategy.class);
         final FileLocator locator = FileLocatorUtils.fileLocator().fileSystem(fs).locationStrategy(strategy).create();
-        EasyMock.expect(strategy.locate(fs, locator)).andReturn(sourceURL);
-        EasyMock.replay(fs, strategy);
-        assertSame("Wrong URL", sourceURL, FileLocatorUtils.locateOrThrow(locator));
-        EasyMock.verify(strategy);
+
+        when(strategy.locate(fs, locator)).thenReturn(sourceURL);
+
+        assertSame(sourceURL, FileLocatorUtils.locateOrThrow(locator));
+
+        verify(strategy).locate(fs, locator);
+        verifyNoMoreInteractions(strategy);
     }
 
     /**
@@ -369,12 +378,15 @@ public class TestFileLocatorUtils {
      */
     @Test
     public void testLocateSuccessWithStrategyDefaultFileSystem() throws ConfigurationException {
-        final FileLocationStrategy strategy = EasyMock.createMock(FileLocationStrategy.class);
+        final FileLocationStrategy strategy = mock(FileLocationStrategy.class);
         final FileLocator locator = FileLocatorUtils.fileLocator().locationStrategy(strategy).create();
-        EasyMock.expect(strategy.locate(FileLocatorUtils.DEFAULT_FILE_SYSTEM, locator)).andReturn(sourceURL);
-        EasyMock.replay(strategy);
-        assertSame("Wrong URL", sourceURL, FileLocatorUtils.locateOrThrow(locator));
-        EasyMock.verify(strategy);
+
+        when(strategy.locate(FileLocatorUtils.DEFAULT_FILE_SYSTEM, locator)).thenReturn(sourceURL);
+
+        assertSame(sourceURL, FileLocatorUtils.locateOrThrow(locator));
+
+        verify(strategy).locate(FileLocatorUtils.DEFAULT_FILE_SYSTEM, locator);
+        verifyNoMoreInteractions(strategy);
     }
 
     @Test
@@ -393,7 +405,7 @@ public class TestFileLocatorUtils {
      */
     @Test
     public void testObtainFileSystemNotSetInLocator() {
-        assertSame("Wrong file system", FileLocatorUtils.DEFAULT_FILE_SYSTEM, FileLocatorUtils.obtainFileSystem(FileLocatorUtils.fileLocator().create()));
+        assertSame(FileLocatorUtils.DEFAULT_FILE_SYSTEM, FileLocatorUtils.getFileSystem(FileLocatorUtils.fileLocator().create()));
     }
 
     /**
@@ -401,7 +413,7 @@ public class TestFileLocatorUtils {
      */
     @Test
     public void testObtainFileSystemNullLocator() {
-        assertSame("Wrong file system", FileLocatorUtils.DEFAULT_FILE_SYSTEM, FileLocatorUtils.obtainFileSystem(null));
+        assertSame(FileLocatorUtils.DEFAULT_FILE_SYSTEM, FileLocatorUtils.getFileSystem(null));
     }
 
     /**
@@ -409,9 +421,9 @@ public class TestFileLocatorUtils {
      */
     @Test
     public void testObtainFileSystemSetInLocator() {
-        final FileSystem fs = EasyMock.createMock(FileSystem.class);
+        final FileSystem fs = mock(FileSystem.class);
         final FileLocator locator = FileLocatorUtils.fileLocator().fileSystem(fs).create();
-        assertSame("Wrong file system", fs, FileLocatorUtils.obtainFileSystem(locator));
+        assertSame(fs, FileLocatorUtils.getFileSystem(locator));
     }
 
     /**
@@ -420,7 +432,7 @@ public class TestFileLocatorUtils {
     @Test
     public void testObtainLocationStrategyNotSetInLocator() {
         final FileLocator locator = FileLocatorUtils.fileLocator().create();
-        assertSame("Wrong strategy", FileLocatorUtils.DEFAULT_LOCATION_STRATEGY, FileLocatorUtils.obtainLocationStrategy(locator));
+        assertSame(FileLocatorUtils.DEFAULT_LOCATION_STRATEGY, FileLocatorUtils.getLocationStrategy(locator));
     }
 
     /**
@@ -428,7 +440,7 @@ public class TestFileLocatorUtils {
      */
     @Test
     public void testObtainLocationStrategyNullLocator() {
-        assertSame("Wrong strategy", FileLocatorUtils.DEFAULT_LOCATION_STRATEGY, FileLocatorUtils.obtainLocationStrategy(null));
+        assertSame(FileLocatorUtils.DEFAULT_LOCATION_STRATEGY, FileLocatorUtils.getLocationStrategy(null));
     }
 
     /**
@@ -436,10 +448,9 @@ public class TestFileLocatorUtils {
      */
     @Test
     public void testObtainLocationStrategySetInLocator() {
-        final FileLocationStrategy strategy = EasyMock.createMock(FileLocationStrategy.class);
-        EasyMock.replay(strategy);
+        final FileLocationStrategy strategy = mock(FileLocationStrategy.class);
         final FileLocator locator = FileLocatorUtils.fileLocator().locationStrategy(strategy).create();
-        assertSame("Wrong strategy", strategy, FileLocatorUtils.obtainLocationStrategy(locator));
+        assertSame(strategy, FileLocatorUtils.getLocationStrategy(locator));
     }
 
     /**
@@ -449,15 +460,16 @@ public class TestFileLocatorUtils {
     public void testPutNoLocator() {
         final Map<String, Object> map = new HashMap<>();
         FileLocatorUtils.put(null, map);
-        assertTrue("Got properties", map.isEmpty());
+        assertTrue(map.isEmpty());
     }
 
     /**
      * Tries to call put() without a map.
      */
-    @Test(expected = IllegalArgumentException.class)
+    @Test
     public void testPutNoMap() {
-        FileLocatorUtils.put(FileLocatorUtils.fileLocator().create(), null);
+        final FileLocator fileLocator = FileLocatorUtils.fileLocator().create();
+        assertThrows(IllegalArgumentException.class, () -> FileLocatorUtils.put(fileLocator, null));
     }
 
     /**
@@ -465,13 +477,12 @@ public class TestFileLocatorUtils {
      */
     @Test
     public void testStoreFileLocatorInMap() {
-        final FileLocationStrategy strategy = EasyMock.createMock(FileLocationStrategy.class);
-        EasyMock.replay(strategy);
+        final FileLocationStrategy strategy = mock(FileLocationStrategy.class);
         final FileLocator locator = FileLocatorUtils.fileLocator().basePath(BASE_PATH).encoding(ENCODING).fileName(FILE_NAME).fileSystem(fileSystem)
             .locationStrategy(strategy).sourceURL(sourceURL).create();
         final Map<String, Object> map = new HashMap<>();
         FileLocatorUtils.put(locator, map);
         final FileLocator locator2 = FileLocatorUtils.fromMap(map);
-        assertEquals("Different locators", locator, locator2);
+        assertEquals(locator, locator2);
     }
 }
