@@ -16,22 +16,28 @@
  */
 package org.apache.commons.configuration2.reloading;
 
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.assertTrue;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertThrows;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.mockito.ArgumentMatchers.any;
+import static org.mockito.ArgumentMatchers.eq;
+import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.verify;
+import static org.mockito.Mockito.verifyNoMoreInteractions;
+import static org.mockito.Mockito.when;
 
 import java.util.concurrent.ScheduledExecutorService;
 import java.util.concurrent.ScheduledFuture;
 import java.util.concurrent.TimeUnit;
 
 import org.apache.commons.lang3.mutable.MutableObject;
-import org.easymock.EasyMock;
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
+import org.mockito.stubbing.OngoingStubbing;
 
 /**
  * Test class for {@code PeriodicReloadingTrigger}.
- *
  */
 public class TestPeriodicReloadingTrigger {
     /** Constant for a parameter to be passed to the controller. */
@@ -48,8 +54,9 @@ public class TestPeriodicReloadingTrigger {
      *
      * @return the mock
      */
+    @SuppressWarnings("unchecked")
     private static ScheduledFuture<Void> createFutureMock() {
-        return EasyMock.createMock(ScheduledFuture.class);
+        return mock(ScheduledFuture.class);
     }
 
     /** A mock for the executor service. */
@@ -67,22 +74,10 @@ public class TestPeriodicReloadingTrigger {
         return new PeriodicReloadingTrigger(controller, CTRL_PARAM, PERIOD, UNIT, executor);
     }
 
-    /**
-     * Prepares the executor mock to expect an invocation which schedules the trigger task.
-     *
-     * @param future the future object to return
-     */
-    private void expectSchedule(final ScheduledFuture<Void> future) {
-        executor.scheduleAtFixedRate(EasyMock.anyObject(Runnable.class), EasyMock.eq(PERIOD), EasyMock.eq(PERIOD), EasyMock.eq(UNIT));
-        if (future != null) {
-            EasyMock.expectLastCall().andReturn(future);
-        }
-    }
-
-    @Before
+    @BeforeEach
     public void setUp() throws Exception {
-        executor = EasyMock.createMock(ScheduledExecutorService.class);
-        controller = EasyMock.createMock(ReloadingController.class);
+        executor = mock(ScheduledExecutorService.class);
+        controller = mock(ReloadingController.class);
     }
 
     /**
@@ -91,15 +86,15 @@ public class TestPeriodicReloadingTrigger {
     @Test
     public void testDefaultExecutor() {
         final PeriodicReloadingTrigger trigger = new PeriodicReloadingTrigger(controller, CTRL_PARAM, PERIOD, UNIT);
-        assertNotNull("No executor service", trigger.getExecutorService());
+        assertNotNull(trigger.getExecutorService());
     }
 
     /**
      * Tries to create an instance without a controller.
      */
-    @Test(expected = IllegalArgumentException.class)
+    @Test
     public void testInitNoController() {
-        new PeriodicReloadingTrigger(null, CTRL_PARAM, PERIOD, UNIT);
+        assertThrows(IllegalArgumentException.class, () -> new PeriodicReloadingTrigger(null, CTRL_PARAM, PERIOD, UNIT));
     }
 
     /**
@@ -107,7 +102,7 @@ public class TestPeriodicReloadingTrigger {
      */
     @Test
     public void testIsRunningAfterInit() {
-        assertFalse("Running", createTrigger().isRunning());
+        assertFalse(createTrigger().isRunning());
     }
 
     /**
@@ -116,14 +111,18 @@ public class TestPeriodicReloadingTrigger {
     @Test
     public void testShutdown() {
         final ScheduledFuture<Void> future = createFutureMock();
-        expectSchedule(future);
-        EasyMock.expect(future.cancel(false)).andReturn(Boolean.TRUE);
-        executor.shutdown();
-        EasyMock.replay(future, controller, executor);
+
+        whenScheduled().thenReturn(future);
+        when(future.cancel(false)).thenReturn(Boolean.TRUE);
+
         final PeriodicReloadingTrigger trigger = createTrigger();
         trigger.start();
         trigger.shutdown();
-        EasyMock.verify(future, controller, executor);
+
+        verifyScheduled();
+        verify(future).cancel(false);
+        verify(executor).shutdown();
+        verifyNoMoreInteractions(future, controller, executor);
     }
 
     /**
@@ -131,7 +130,6 @@ public class TestPeriodicReloadingTrigger {
      */
     @Test
     public void testShutdownNoExecutor() {
-        EasyMock.replay(controller, executor);
         createTrigger().shutdown(false);
     }
 
@@ -142,18 +140,21 @@ public class TestPeriodicReloadingTrigger {
     public void testStart() {
         final ScheduledFuture<Void> future = createFutureMock();
         final MutableObject<Runnable> refTask = new MutableObject<>();
-        expectSchedule(null);
-        EasyMock.expectLastCall().andAnswer(() -> {
-            refTask.setValue((Runnable) EasyMock.getCurrentArguments()[0]);
+
+        whenScheduled().thenAnswer(invocation -> {
+            refTask.setValue(invocation.getArgument(0, Runnable.class));
             return future;
         });
-        EasyMock.expect(controller.checkForReloading(CTRL_PARAM)).andReturn(Boolean.FALSE);
-        EasyMock.replay(future, controller, executor);
+        when(controller.checkForReloading(CTRL_PARAM)).thenReturn(Boolean.FALSE);
+
         final PeriodicReloadingTrigger trigger = createTrigger();
         trigger.start();
-        assertTrue("Not started", trigger.isRunning());
+        assertTrue(trigger.isRunning());
         refTask.getValue().run();
-        EasyMock.verify(future, controller, executor);
+
+        verifyScheduled();
+        verify(controller).checkForReloading(CTRL_PARAM);
+        verifyNoMoreInteractions(future, controller, executor);
     }
 
     /**
@@ -162,12 +163,15 @@ public class TestPeriodicReloadingTrigger {
     @Test
     public void testStartTwice() {
         final ScheduledFuture<Void> future = createFutureMock();
-        expectSchedule(future);
-        EasyMock.replay(future, controller, executor);
+
+        whenScheduled().thenReturn(future);
+
         final PeriodicReloadingTrigger trigger = createTrigger();
         trigger.start();
         trigger.start();
-        EasyMock.verify(future, controller, executor);
+
+        verifyScheduled();
+        verifyNoMoreInteractions(future, controller, executor);
     }
 
     /**
@@ -176,14 +180,18 @@ public class TestPeriodicReloadingTrigger {
     @Test
     public void testStop() {
         final ScheduledFuture<Void> future = createFutureMock();
-        expectSchedule(future);
-        EasyMock.expect(future.cancel(false)).andReturn(Boolean.TRUE);
-        EasyMock.replay(future, controller, executor);
+
+        whenScheduled().thenReturn(future);
+        when(future.cancel(false)).thenReturn(Boolean.TRUE);
+
         final PeriodicReloadingTrigger trigger = createTrigger();
         trigger.start();
         trigger.stop();
-        assertFalse("Still running", trigger.isRunning());
-        EasyMock.verify(future, controller, executor);
+        assertFalse(trigger.isRunning());
+
+        verifyScheduled();
+        verify(future).cancel(false);
+        verifyNoMoreInteractions(future, controller, executor);
     }
 
     /**
@@ -191,7 +199,23 @@ public class TestPeriodicReloadingTrigger {
      */
     @Test
     public void testStopNotRunning() {
-        EasyMock.replay(controller, executor);
         createTrigger().stop();
     }
+
+    /**
+     * Verifies that an invocation has occurred on the executor mock which schedules the trigger task.
+     */
+    private void verifyScheduled() {
+        verify(executor).scheduleAtFixedRate(any(), eq(PERIOD), eq(PERIOD), eq(UNIT));
+    }
+
+    /**
+     * Prepares the executor mock to for any invocation which schedules the trigger task.
+     * This method should be used to call one of the {@code thenReturn}, {@code thenAnswer} or {@code thenThrow} methods.
+     *
+     * @return An ongoing stubbing for the future
+     */
+    private OngoingStubbing<ScheduledFuture<?>> whenScheduled() {
+        return when(executor.scheduleAtFixedRate(any(), eq(PERIOD), eq(PERIOD), eq(UNIT)));
+    }
 }
