@@ -16,21 +16,20 @@
  */
 package org.apache.commons.configuration2.tree;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertNotEquals;
-import static org.junit.Assert.assertNull;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNotEquals;
+import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.assertThrows;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 
 import java.util.NoSuchElementException;
 
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 /**
  * Test class for DefaultConfigurationKey.
- *
  */
 public class TestDefaultConfigurationKey {
     /** Constant for a test key. */
@@ -58,7 +57,7 @@ public class TestDefaultConfigurationKey {
         return new DefaultConfigurationKey(expressionEngine, k);
     }
 
-    @Before
+    @BeforeEach
     public void setUp() throws Exception {
         expressionEngine = DefaultExpressionEngine.INSTANCE;
         key = new DefaultConfigurationKey(expressionEngine);
@@ -81,7 +80,7 @@ public class TestDefaultConfigurationKey {
         key.append("tables").append("table(0).");
         key.append("fields.").append("field(1)");
         key.append(null).append(TESTATTR);
-        assertEquals("Wrong key", TESTKEY, key.toString());
+        assertEquals(TESTKEY, key.toString());
     }
 
     /**
@@ -90,7 +89,7 @@ public class TestDefaultConfigurationKey {
     @Test
     public void testAppendAttribute() {
         key.appendAttribute("dataType");
-        assertEquals("Attribute key not correctly appended", TESTATTR, key.toString());
+        assertEquals(TESTATTR, key.toString());
     }
 
     /**
@@ -101,7 +100,7 @@ public class TestDefaultConfigurationKey {
         key.append("tables").append("table.").appendIndex(0);
         key.append("fields.").append("field").appendIndex(1);
         key.appendAttribute("dataType");
-        assertEquals("Wrong complex key", TESTKEY, key.toString());
+        assertEquals(TESTKEY, key.toString());
     }
 
     /**
@@ -110,7 +109,7 @@ public class TestDefaultConfigurationKey {
     @Test
     public void testAppendDecoratedAttributeKey() {
         key.appendAttribute(TESTATTR);
-        assertEquals("Decorated attribute key not correctly appended", TESTATTR, key.toString());
+        assertEquals(TESTATTR, key.toString());
     }
 
     /**
@@ -120,7 +119,7 @@ public class TestDefaultConfigurationKey {
     public void testAppendDelimiters() {
         key.append("key..").append("test").append(".");
         key.append(".more").append("..tests");
-        assertEquals("Wrong key", "key...test.more...tests", key.toString());
+        assertEquals("key...test.more...tests", key.toString());
     }
 
     /**
@@ -132,7 +131,7 @@ public class TestDefaultConfigurationKey {
         key = new DefaultConfigurationKey(expressionEngine);
         key.append("key.......").append("test").append(".");
         key.append(".more").append("..tests");
-        assertEquals("Wrong constructed key", "key.test.more.tests", key.toString());
+        assertEquals("key.test.more.tests", key.toString());
     }
 
     /**
@@ -141,7 +140,7 @@ public class TestDefaultConfigurationKey {
     @Test
     public void testAppendIndex() {
         key.append("test").appendIndex(42);
-        assertEquals("Index was not correctly appended", "test(42)", key.toString());
+        assertEquals("test(42)", key.toString());
     }
 
     /**
@@ -150,7 +149,7 @@ public class TestDefaultConfigurationKey {
     @Test
     public void testAppendNullAttributeKey() {
         key.appendAttribute(null);
-        assertEquals("Null attribute key not correctly appended", "", key.toString());
+        assertEquals("", key.toString());
     }
 
     /**
@@ -160,7 +159,7 @@ public class TestDefaultConfigurationKey {
     public void testAppendWithEscapeFlag() {
         key.append(".key.test.", true);
         key.append(".more").append(".tests", true);
-        assertEquals("Wrong constructed key", "..key..test...more...tests", key.toString());
+        assertEquals("..key..test...more...tests", key.toString());
     }
 
     /**
@@ -170,16 +169,16 @@ public class TestDefaultConfigurationKey {
     public void testAttributeKeyWithIndex() {
         key.append(TESTATTR);
         key.appendIndex(0);
-        assertEquals("Wrong attribute key with index", TESTATTR + "(0)", key.toString());
+        assertEquals(TESTATTR + "(0)", key.toString());
 
         final DefaultConfigurationKey.KeyIterator it = key.iterator();
-        assertTrue("No first element", it.hasNext());
+        assertTrue(it.hasNext());
         it.next();
-        assertTrue("Index not found", it.hasIndex());
-        assertEquals("Incorrect index", 0, it.getIndex());
-        assertTrue("Attribute not found", it.isAttribute());
-        assertEquals("Wrong plain key", "dataType", it.currentKey(false));
-        assertEquals("Wrong decorated key", TESTATTR, it.currentKey(true));
+        assertTrue(it.hasIndex());
+        assertEquals(0, it.getIndex());
+        assertTrue(it.isAttribute());
+        assertEquals("dataType", it.currentKey(false));
+        assertEquals(TESTATTR, it.currentKey(true));
     }
 
     /**
@@ -187,9 +186,9 @@ public class TestDefaultConfigurationKey {
      */
     @Test
     public void testAttributeName() {
-        assertEquals("Plain key not detected", "test", key.attributeName("test"));
-        assertEquals("Attribute markers not stripped", "dataType", key.attributeName(TESTATTR));
-        assertNull("Null key not processed", key.attributeName(null));
+        assertEquals("test", key.attributeName("test"));
+        assertEquals("dataType", key.attributeName(TESTATTR));
+        assertNull(key.attributeName(null));
     }
 
     /**
@@ -200,30 +199,30 @@ public class TestDefaultConfigurationKey {
         final DefaultConfigurationKey k1 = key(TESTKEY);
         DefaultConfigurationKey k2 = key("tables.table(0).name");
         DefaultConfigurationKey kc = k1.commonKey(k2);
-        assertEquals("Wrong common key (1)", key("tables.table(0)"), kc);
-        assertEquals("Not symmetric", kc, k2.commonKey(k1));
+        assertEquals(key("tables.table(0)"), kc);
+        assertEquals(kc, k2.commonKey(k1));
 
         k2 = key("tables.table(1).fields.field(1)");
         kc = k1.commonKey(k2);
-        assertEquals("Wrong common key (2)", key("tables"), kc);
+        assertEquals(key("tables"), kc);
 
         k2 = key("completely.different.key");
         kc = k1.commonKey(k2);
-        assertEquals("Got a common key for different keys", 0, kc.length());
+        assertEquals(0, kc.length());
 
         kc = k1.commonKey(key);
-        assertEquals("Got a common key for empty key", 0, kc.length());
+        assertEquals(0, kc.length());
 
         kc = k1.commonKey(k1);
-        assertEquals("Wrong result for reflexiv invocation", kc, k1);
+        assertEquals(kc, k1);
     }
 
     /**
      * Tries to call commonKey() with null input.
      */
-    @Test(expected = IllegalArgumentException.class)
+    @Test
     public void testCommonKeyNull() {
-        key.commonKey(null);
+        assertThrows(IllegalArgumentException.class, () -> key.commonKey(null));
     }
 
     /**
@@ -231,9 +230,9 @@ public class TestDefaultConfigurationKey {
      */
     @Test
     public void testConstructAttributeKey() {
-        assertEquals("Wrong attribute key", TESTATTR, key.constructAttributeKey("dataType"));
-        assertEquals("Attribute key was incorrectly converted", TESTATTR, key.constructAttributeKey(TESTATTR));
-        assertEquals("Null key could not be processed", "", key.constructAttributeKey(null));
+        assertEquals(TESTATTR, key.constructAttributeKey("dataType"));
+        assertEquals(TESTATTR, key.constructAttributeKey(TESTATTR));
+        assertEquals("", key.constructAttributeKey(null));
     }
 
     /**
@@ -246,8 +245,8 @@ public class TestDefaultConfigurationKey {
             .create();
         expressionEngine = new DefaultExpressionEngine(symbols);
         key = new DefaultConfigurationKey(expressionEngine);
-        assertEquals("Wrong attribute key", ".test", key.constructAttributeKey("test"));
-        assertEquals("Attribute key was incorrectly converted", ".test", key.constructAttributeKey(".test"));
+        assertEquals(".test", key.constructAttributeKey("test"));
+        assertEquals(".test", key.constructAttributeKey(".test"));
     }
 
     /**
@@ -258,15 +257,15 @@ public class TestDefaultConfigurationKey {
         final DefaultConfigurationKey k1 = key(TESTKEY);
         DefaultConfigurationKey k2 = key("tables.table(0).name");
         DefaultConfigurationKey kd = k1.differenceKey(k2);
-        assertEquals("Wrong difference (1)", "name", kd.toString());
+        assertEquals("name", kd.toString());
 
         k2 = key("tables.table(1).fields.field(1)");
         kd = k1.differenceKey(k2);
-        assertEquals("Wrong difference (2)", "table(1).fields.field(1)", kd.toString());
+        assertEquals("table(1).fields.field(1)", kd.toString());
 
         k2 = key("completely.different.key");
         kd = k1.differenceKey(k2);
-        assertEquals("Wrong difference (3)", k2, kd);
+        assertEquals(k2, kd);
     }
 
     /**
@@ -276,7 +275,7 @@ public class TestDefaultConfigurationKey {
     public void testDifferenceKeySame() {
         final DefaultConfigurationKey k1 = key(TESTKEY);
         final DefaultConfigurationKey kd = k1.differenceKey(k1);
-        assertEquals("Got difference for same keys", 0, kd.length());
+        assertEquals(0, kd.length());
     }
 
     /**
@@ -285,16 +284,16 @@ public class TestDefaultConfigurationKey {
     @Test
     public void testEquals() {
         final DefaultConfigurationKey k1 = key(TESTKEY);
-        assertEquals("Key not equal to itself", k1, k1);
+        assertEquals(k1, k1);
         final DefaultConfigurationKey k2 = key(TESTKEY);
-        assertEquals("Keys are not equal", k1, k2);
-        assertEquals("Not reflexiv", k2, k1);
-        assertEquals("Hash codes not equal", k1.hashCode(), k2.hashCode());
+        assertEquals(k1, k2);
+        assertEquals(k2, k1);
+        assertEquals(k1.hashCode(), k2.hashCode());
         k2.append("anotherPart");
-        assertNotEquals("Keys considered equal", k1, k2);
-        assertNotEquals("Keys considered equal (2)", k2, k1);
-        assertNotEquals("Key equals null key", null, k1);
-        assertNotEquals("Equal with string", TESTKEY, k1);
+        assertNotEquals(k1, k2);
+        assertNotEquals(k2, k1);
+        assertNotEquals(null, k1);
+        assertNotEquals(TESTKEY, k1);
     }
 
     /**
@@ -302,9 +301,9 @@ public class TestDefaultConfigurationKey {
      */
     @Test
     public void testIsAttributeKey() {
-        assertTrue("Attribute key not detected", key.isAttributeKey(TESTATTR));
-        assertFalse("Property key considered as attribute", key.isAttributeKey(TESTPROPS));
-        assertFalse("Null key considered as attribute", key.isAttributeKey(null));
+        assertTrue(key.isAttributeKey(TESTATTR));
+        assertFalse(key.isAttributeKey(TESTPROPS));
+        assertFalse(key.isAttributeKey(null));
     }
 
     /**
@@ -317,8 +316,8 @@ public class TestDefaultConfigurationKey {
             .setAttributeStart(DefaultExpressionEngineSymbols.DEFAULT_PROPERTY_DELIMITER).create();
         expressionEngine = new DefaultExpressionEngine(symbols);
         key = new DefaultConfigurationKey(expressionEngine);
-        assertTrue("Attribute key not detected", key.isAttributeKey(DefaultExpressionEngineSymbols.DEFAULT_PROPERTY_DELIMITER + "test"));
-        assertFalse("Property key considered as attribute key", key.isAttributeKey(TESTATTR));
+        assertTrue(key.isAttributeKey(DefaultExpressionEngineSymbols.DEFAULT_PROPERTY_DELIMITER + "test"));
+        assertFalse(key.isAttributeKey(TESTATTR));
     }
 
     /**
@@ -328,27 +327,22 @@ public class TestDefaultConfigurationKey {
     public void testIterate() {
         key.append(TESTKEY);
         final DefaultConfigurationKey.KeyIterator it = key.iterator();
-        assertTrue("No key parts", it.hasNext());
-        assertEquals("Wrong key part", "tables", it.nextKey());
-        assertEquals("Wrong key part", "table", it.nextKey());
-        assertTrue("No index found", it.hasIndex());
-        assertEquals("Wrong index", 0, it.getIndex());
-        assertEquals("Wrong key part", "fields", it.nextKey());
-        assertFalse("Found an index", it.hasIndex());
-        assertEquals("Wrong key part", "field", it.nextKey(true));
-        assertEquals("Wrong index", 1, it.getIndex());
-        assertFalse("Found an attribute", it.isAttribute());
-        assertEquals("Wrong current key", "field", it.currentKey(true));
-        assertEquals("Wrong key part", "dataType", it.nextKey());
-        assertEquals("Wrong decorated key part", "[@dataType]", it.currentKey(true));
-        assertTrue("Attribute not found", it.isAttribute());
-        assertFalse("Too many key parts", it.hasNext());
-        try {
-            it.next();
-            fail("Could iterate over the iteration's end!");
-        } catch (final NoSuchElementException nex) {
-            // ok
-        }
+        assertTrue(it.hasNext());
+        assertEquals("tables", it.nextKey());
+        assertEquals("table", it.nextKey());
+        assertTrue(it.hasIndex());
+        assertEquals(0, it.getIndex());
+        assertEquals("fields", it.nextKey());
+        assertFalse(it.hasIndex());
+        assertEquals("field", it.nextKey(true));
+        assertEquals(1, it.getIndex());
+        assertFalse(it.isAttribute());
+        assertEquals("field", it.currentKey(true));
+        assertEquals("dataType", it.nextKey());
+        assertEquals("[@dataType]", it.currentKey(true));
+        assertTrue(it.isAttribute());
+        assertFalse(it.hasNext());
+        assertThrows(NoSuchElementException.class, it::next);
     }
 
     /**
@@ -363,10 +357,10 @@ public class TestDefaultConfigurationKey {
         key.append(".strange");
         assertEquals("\\.my\\.elem.trailing\\.dot\\..strange", key.toString());
         final DefaultConfigurationKey.KeyIterator kit = key.iterator();
-        assertEquals("Wrong first part", ".my.elem", kit.nextKey());
-        assertEquals("Wrong second part", "trailing.dot.", kit.nextKey());
-        assertEquals("Wrong third part", "strange", kit.nextKey());
-        assertFalse("Too many parts", kit.hasNext());
+        assertEquals(".my.elem", kit.nextKey());
+        assertEquals("trailing.dot.", kit.nextKey());
+        assertEquals("strange", kit.nextKey());
+        assertFalse(kit.hasNext());
     }
 
     /**
@@ -379,16 +373,16 @@ public class TestDefaultConfigurationKey {
         key = new DefaultConfigurationKey(expressionEngine);
         key.append("this.isa.key");
         final DefaultConfigurationKey.KeyIterator kit = key.iterator();
-        assertEquals("Wrong first key part", "this", kit.next());
-        assertFalse("First part is an attribute", kit.isAttribute());
-        assertTrue("First part is not a property key", kit.isPropertyKey());
-        assertEquals("Wrong second key part", "isa", kit.next());
-        assertFalse("Second part is an attribute", kit.isAttribute());
-        assertTrue("Second part is not a property key", kit.isPropertyKey());
-        assertEquals("Wrong third key part", "key", kit.next());
-        assertTrue("Third part is not an attribute", kit.isAttribute());
-        assertTrue("Third part is not a property key", kit.isPropertyKey());
-        assertEquals("Wrong decorated key part", "key", kit.currentKey(true));
+        assertEquals("this", kit.next());
+        assertFalse(kit.isAttribute());
+        assertTrue(kit.isPropertyKey());
+        assertEquals("isa", kit.next());
+        assertFalse(kit.isAttribute());
+        assertTrue(kit.isPropertyKey());
+        assertEquals("key", kit.next());
+        assertTrue(kit.isAttribute());
+        assertTrue(kit.isPropertyKey());
+        assertEquals("key", kit.currentKey(true));
     }
 
     /**
@@ -401,10 +395,10 @@ public class TestDefaultConfigurationKey {
         key.append(".strange");
         assertEquals("my..elem.trailing..dot...strange", key.toString());
         final DefaultConfigurationKey.KeyIterator kit = key.iterator();
-        assertEquals("Wrong first part", "my.elem", kit.nextKey());
-        assertEquals("Wrong second part", "trailing.dot.", kit.nextKey());
-        assertEquals("Wrong third part", "strange", kit.nextKey());
-        assertFalse("Too many parts", kit.hasNext());
+        assertEquals("my.elem", kit.nextKey());
+        assertEquals("trailing.dot.", kit.nextKey());
+        assertEquals("strange", kit.nextKey());
+        assertFalse(kit.hasNext());
     }
 
     /**
@@ -414,21 +408,21 @@ public class TestDefaultConfigurationKey {
     public void testIterateStrangeKeys() {
         key = new DefaultConfigurationKey(expressionEngine, "key.");
         DefaultConfigurationKey.KeyIterator it = key.iterator();
-        assertTrue("Too few key parts", it.hasNext());
-        assertEquals("Wrong key part", "key", it.next());
-        assertFalse("Too many key parts", it.hasNext());
+        assertTrue(it.hasNext());
+        assertEquals("key", it.next());
+        assertFalse(it.hasNext());
 
         key = new DefaultConfigurationKey(expressionEngine, ".");
         it = key.iterator();
-        assertFalse("Simple delimiter key has more parts", it.hasNext());
+        assertFalse(it.hasNext());
 
         key = new DefaultConfigurationKey(expressionEngine, "key().index()undefined(0).test");
         it = key.iterator();
-        assertEquals("Wrong first part", "key()", it.next());
-        assertFalse("Index detected in first part", it.hasIndex());
-        assertEquals("Wrong second part", "index()undefined", it.nextKey(false));
-        assertTrue("No index detected in second part", it.hasIndex());
-        assertEquals("Wrong index value", 0, it.getIndex());
+        assertEquals("key()", it.next());
+        assertFalse(it.hasIndex());
+        assertEquals("index()undefined", it.nextKey(false));
+        assertTrue(it.hasIndex());
+        assertEquals(0, it.getIndex());
     }
 
     /**
@@ -439,15 +433,15 @@ public class TestDefaultConfigurationKey {
         key.append("directory.platform(x86).path");
         final DefaultConfigurationKey.KeyIterator kit = key.iterator();
         String part = kit.nextKey();
-        assertEquals("Wrong part 1", "directory", part);
-        assertFalse("Has index 1", kit.hasIndex());
+        assertEquals("directory", part);
+        assertFalse(kit.hasIndex());
         part = kit.nextKey();
-        assertEquals("Wrong part 2", "platform(x86)", part);
-        assertFalse("Has index 2", kit.hasIndex());
+        assertEquals("platform(x86)", part);
+        assertFalse(kit.hasIndex());
         part = kit.nextKey();
-        assertEquals("Wrong part 3", "path", part);
-        assertFalse("Has index 3", kit.hasIndex());
-        assertFalse("Too many elements", kit.hasNext());
+        assertEquals("path", part);
+        assertFalse(kit.hasIndex());
+        assertFalse(kit.hasNext());
     }
 
     /**
@@ -458,26 +452,26 @@ public class TestDefaultConfigurationKey {
         expressionEngine = new DefaultExpressionEngine(symbols().setEscapedDelimiter(null).create());
         key = new DefaultConfigurationKey(expressionEngine);
         key.append("..my..elem.trailing..dot...strange");
-        assertEquals("Wrong key", "my..elem.trailing..dot...strange", key.toString());
+        assertEquals("my..elem.trailing..dot...strange", key.toString());
         final DefaultConfigurationKey.KeyIterator kit = key.iterator();
         final String[] parts = {"my", "elem", "trailing", "dot", "strange"};
         for (int i = 0; i < parts.length; i++) {
-            assertEquals("Wrong key part " + i, parts[i], kit.next());
+            assertEquals(parts[i], kit.next(), "Wrong key part " + i);
         }
-        assertFalse("Too many parts", kit.hasNext());
+        assertFalse(kit.hasNext());
     }
 
     /**
      * Tests an iteration where the remove() method is called. This is not supported.
      */
-    @Test(expected = UnsupportedOperationException.class)
+    @Test
     public void testIterateWithRemove() {
         assertFalse(key.iterator().hasNext());
         key.append("simple");
         final DefaultConfigurationKey.KeyIterator it = key.iterator();
         assertTrue(it.hasNext());
         assertEquals("simple", it.next());
-        it.remove();
+        assertThrows(UnsupportedOperationException.class, it::remove);
     }
 
     /**
@@ -486,20 +480,20 @@ public class TestDefaultConfigurationKey {
     @Test
     public void testLength() {
         key.append(TESTPROPS);
-        assertEquals("Wrong length", TESTPROPS.length(), key.length());
+        assertEquals(TESTPROPS.length(), key.length());
         key.appendAttribute("dataType");
-        assertEquals("Wrong length", TESTKEY.length(), key.length());
+        assertEquals(TESTKEY.length(), key.length());
         key.setLength(TESTPROPS.length());
-        assertEquals("Wrong length after shortening", TESTPROPS.length(), key.length());
-        assertEquals("Wrong resulting key", TESTPROPS, key.toString());
+        assertEquals(TESTPROPS.length(), key.length());
+        assertEquals(TESTPROPS, key.toString());
     }
 
     /**
      * Tests setting the expression engine to null. This should not be allowed.
      */
-    @Test(expected = IllegalArgumentException.class)
+    @Test
     public void testSetNullExpressionEngine() {
-        new DefaultConfigurationKey(null);
+        assertThrows(IllegalArgumentException.class, () -> new DefaultConfigurationKey(null));
     }
 
     /**
@@ -507,9 +501,9 @@ public class TestDefaultConfigurationKey {
      */
     @Test
     public void testTrim() {
-        assertEquals("Key was not trimmed", "test", key.trim(".test."));
-        assertEquals("Null key could not be processed", "", key.trim(null));
-        assertEquals("Delimiter could not be processed", "", key.trim(DefaultExpressionEngineSymbols.DEFAULT_PROPERTY_DELIMITER));
+        assertEquals("test", key.trim(".test."));
+        assertEquals("", key.trim(null));
+        assertEquals("", key.trim(DefaultExpressionEngineSymbols.DEFAULT_PROPERTY_DELIMITER));
     }
 
     /**
@@ -517,8 +511,8 @@ public class TestDefaultConfigurationKey {
      */
     @Test
     public void testTrimLeft() {
-        assertEquals("Key was not left trimmed", "test.", key.trimLeft(".test."));
-        assertEquals("Too much left trimming", "..test.", key.trimLeft("..test."));
+        assertEquals("test.", key.trimLeft(".test."));
+        assertEquals("..test.", key.trimLeft("..test."));
     }
 
     /**
@@ -526,7 +520,7 @@ public class TestDefaultConfigurationKey {
      */
     @Test
     public void testTrimRight() {
-        assertEquals("Key was not right trimmed", ".test", key.trimRight(".test."));
-        assertEquals("Too much right trimming", ".test..", key.trimRight(".test.."));
+        assertEquals(".test", key.trimRight(".test."));
+        assertEquals(".test..", key.trimRight(".test.."));
     }
 }
