@@ -16,31 +16,33 @@
  */
 package org.apache.commons.configuration2.tree;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertSame;
-import static org.junit.Assert.assertTrue;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertSame;
+import static org.junit.jupiter.api.Assertions.assertThrows;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 
-import java.util.Iterator;
+import java.util.Arrays;
 import java.util.List;
 
 import org.apache.commons.lang3.StringUtils;
-import org.junit.Before;
-import org.junit.BeforeClass;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 /**
  * Test class for DefaultExpressionEngine.
  */
 public class TestDefaultExpressionEngine {
+
     /** Stores the names of the test nodes representing tables. */
-    private static final String[] tables = {"users", "documents"};
+    private static final String[] TABLES = {"users", "documents"};
 
     /** Stores the types of the test table nodes. */
-    private static final String[] tabTypes = {"system", "application"};
+    private static final String[] TAB_TYPES = {"system", "application"};
 
     /** Test data fields for the node hierarchy. */
-    private static final String[][] fields = {{"uid", "uname", "firstName", "lastName", "email"}, {"docid", "name", "creationDate", "authorID", "version"}};
+    private static final String[][] FIELDS = {{"uid", "uname", "firstName", "lastName", "email"}, {"docid", "name", "creationDate", "authorID", "version"}};
 
     /** The root of a hierarchy with test nodes. */
     private static ImmutableNode root;
@@ -71,7 +73,7 @@ public class TestDefaultExpressionEngine {
         return new ImmutableNode.Builder().name(name).value(value).create();
     }
 
-    @BeforeClass
+    @BeforeAll
     public static void setUpBeforeClass() {
         root = setUpNodes();
         handler = new InMemoryNodeModel(root).getNodeHandler();
@@ -94,17 +96,17 @@ public class TestDefaultExpressionEngine {
      * @return the root of the test node hierarchy
      */
     private static ImmutableNode setUpNodes() {
-        final ImmutableNode.Builder nodeTablesBuilder = new ImmutableNode.Builder(tables.length);
+        final ImmutableNode.Builder nodeTablesBuilder = new ImmutableNode.Builder(TABLES.length);
         nodeTablesBuilder.name("tables");
-        for (int i = 0; i < tables.length; i++) {
+        for (int i = 0; i < TABLES.length; i++) {
             final ImmutableNode.Builder nodeTableBuilder = new ImmutableNode.Builder(2);
             nodeTableBuilder.name("table");
-            nodeTableBuilder.addChild(new ImmutableNode.Builder().name("name").value(tables[i]).create());
-            nodeTableBuilder.addAttribute("type", tabTypes[i]);
+            nodeTableBuilder.addChild(new ImmutableNode.Builder().name("name").value(TABLES[i]).create());
+            nodeTableBuilder.addAttribute("type", TAB_TYPES[i]);
 
-            final ImmutableNode.Builder nodeFieldsBuilder = new ImmutableNode.Builder(fields[i].length);
-            for (int j = 0; j < fields[i].length; j++) {
-                nodeFieldsBuilder.addChild(createFieldNode(fields[i][j]));
+            final ImmutableNode.Builder nodeFieldsBuilder = new ImmutableNode.Builder(FIELDS[i].length);
+            for (int j = 0; j < FIELDS[i].length; j++) {
+                nodeFieldsBuilder.addChild(createFieldNode(FIELDS[i][j]));
             }
             nodeTableBuilder.addChild(nodeFieldsBuilder.name("fields").create());
             nodeTablesBuilder.addChild(nodeTableBuilder.create());
@@ -135,8 +137,8 @@ public class TestDefaultExpressionEngine {
     private void checkAttributeValue(final String key, final String attr, final Object expValue) {
         final List<QueryResult<ImmutableNode>> results = checkKey(key, attr, 1);
         final QueryResult<ImmutableNode> result = results.get(0);
-        assertTrue("Not an attribute result", result.isAttributeResult());
-        assertEquals("Wrong attribute value for key " + key, expValue, result.getAttributeValue(handler));
+        assertTrue(result.isAttributeResult());
+        assertEquals(expValue, result.getAttributeValue(handler), "Wrong attribute value for key " + key);
     }
 
     /**
@@ -152,9 +154,9 @@ public class TestDefaultExpressionEngine {
         final List<QueryResult<ImmutableNode>> nodes = query(key, count);
         for (final QueryResult<ImmutableNode> result : nodes) {
             if (result.isAttributeResult()) {
-                assertEquals("Wrong attribute name for key " + key, name, result.getAttributeName());
+                assertEquals(name, result.getAttributeName(), "Wrong attribute name for key " + key);
             } else {
-                assertEquals("Wrong result node for key " + key, name, result.getNode().getNodeName());
+                assertEquals(name, result.getNode().getNodeName(), "Wrong result node for key " + key);
             }
         }
         return nodes;
@@ -171,8 +173,8 @@ public class TestDefaultExpressionEngine {
     private void checkKeyValue(final String key, final String name, final String value) {
         final List<QueryResult<ImmutableNode>> results = checkKey(key, name, 1);
         final QueryResult<ImmutableNode> result = results.get(0);
-        assertFalse("No node result", result.isAttributeResult());
-        assertEquals("Wrong value for key " + key, value, result.getNode().getValue());
+        assertFalse(result.isAttributeResult());
+        assertEquals(value, result.getNode().getValue(), "Wrong value for key " + key);
     }
 
     /**
@@ -182,11 +184,7 @@ public class TestDefaultExpressionEngine {
      * @param expected the expected path nodes
      */
     private void checkNodePath(final NodeAddData<ImmutableNode> data, final String... expected) {
-        assertEquals("Wrong number of path nodes", expected.length, data.getPathNodes().size());
-        final Iterator<String> it = data.getPathNodes().iterator();
-        for (int i = 0; i < expected.length; i++) {
-            assertEquals("Wrong path node " + i, expected[i], it.next());
-        }
+        assertEquals(Arrays.asList(expected), data.getPathNodes());
     }
 
     /**
@@ -197,8 +195,8 @@ public class TestDefaultExpressionEngine {
     private void checkQueryRootNode(final String key) {
         final List<QueryResult<ImmutableNode>> results = checkKey(key, null, 1);
         final QueryResult<ImmutableNode> result = results.get(0);
-        assertFalse("No node result", result.isAttributeResult());
-        assertSame("Not the root node", root, result.getNode());
+        assertFalse(result.isAttributeResult());
+        assertSame(root, result.getNode());
     }
 
     /**
@@ -209,7 +207,7 @@ public class TestDefaultExpressionEngine {
      */
     private ImmutableNode fetchNode(final String key) {
         final QueryResult<ImmutableNode> result = query(key, 1).get(0);
-        assertFalse("An attribute result", result.isAttributeResult());
+        assertFalse(result.isAttributeResult());
         return result.getNode();
     }
 
@@ -222,11 +220,11 @@ public class TestDefaultExpressionEngine {
      */
     private List<QueryResult<ImmutableNode>> query(final String key, final int expCount) {
         final List<QueryResult<ImmutableNode>> nodes = engine.query(root, key, handler);
-        assertEquals("Wrong number of result nodes for key " + key, expCount, nodes.size());
+        assertEquals(expCount, nodes.size());
         return nodes;
     }
 
-    @Before
+    @BeforeEach
     public void setUp() throws Exception {
         engine = DefaultExpressionEngine.INSTANCE;
     }
@@ -259,7 +257,7 @@ public class TestDefaultExpressionEngine {
      */
     @Test
     public void testAttributeKey() {
-        assertEquals("Wrong attribute key", "tables.table[@type]", engine.attributeKey("tables.table", "type"));
+        assertEquals("tables.table[@type]", engine.attributeKey("tables.table", "type"));
     }
 
     /**
@@ -267,7 +265,7 @@ public class TestDefaultExpressionEngine {
      */
     @Test
     public void testAttributeKeyNoParent() {
-        assertEquals("Wrong key for null parent", "[@test]", engine.attributeKey(null, "test"));
+        assertEquals("[@test]", engine.attributeKey(null, "test"));
     }
 
     /**
@@ -275,7 +273,7 @@ public class TestDefaultExpressionEngine {
      */
     @Test
     public void testAttributeKeyRoot() {
-        assertEquals("Wrong key for root attribute", "[@test]", engine.attributeKey("", "test"));
+        assertEquals("[@test]", engine.attributeKey("", "test"));
     }
 
     /**
@@ -284,7 +282,7 @@ public class TestDefaultExpressionEngine {
     @Test
     public void testAttributeKeyWithAlternativeSyntax() {
         setUpAlternativeSyntax();
-        assertEquals("Wrong attribute key", "@test", engine.attributeKey("", "test"));
+        assertEquals("@test", engine.attributeKey("", "test"));
     }
 
     /**
@@ -293,7 +291,7 @@ public class TestDefaultExpressionEngine {
     @Test
     public void testCanonicalKeyNoDuplicates() {
         final ImmutableNode node = fetchNode("tables.table(0).name");
-        assertEquals("Wrong canonical key", "table.name(0)", engine.canonicalKey(node, "table", handler));
+        assertEquals("table.name(0)", engine.canonicalKey(node, "table", handler));
     }
 
     /**
@@ -302,7 +300,7 @@ public class TestDefaultExpressionEngine {
     @Test
     public void testCanonicalKeyNoParentKey() {
         final ImmutableNode node = fetchNode("tables.table(0).fields.field(1).name");
-        assertEquals("Wrong key", "name(0)", engine.canonicalKey(node, null, handler));
+        assertEquals("name(0)", engine.canonicalKey(node, null, handler));
     }
 
     /**
@@ -310,7 +308,7 @@ public class TestDefaultExpressionEngine {
      */
     @Test
     public void testCanonicalKeyRootNoParentKey() {
-        assertEquals("Wrong key", "", engine.canonicalKey(root, null, handler));
+        assertEquals("", engine.canonicalKey(root, null, handler));
     }
 
     /**
@@ -318,7 +316,7 @@ public class TestDefaultExpressionEngine {
      */
     @Test
     public void testCanonicalKeyRootWithParentKey() {
-        assertEquals("Wrong key", "parent", engine.canonicalKey(root, "parent", handler));
+        assertEquals("parent", engine.canonicalKey(root, "parent", handler));
     }
 
     /**
@@ -328,8 +326,8 @@ public class TestDefaultExpressionEngine {
     public void testCanonicalKeyWithDuplicates() {
         final ImmutableNode tab1 = fetchNode("tables.table(0)");
         final ImmutableNode tab2 = fetchNode("tables.table(1)");
-        assertEquals("Wrong key 1", "tables.table(0)", engine.canonicalKey(tab1, "tables", handler));
-        assertEquals("Wrong key 2", "tables.table(1)", engine.canonicalKey(tab2, "tables", handler));
+        assertEquals("tables.table(0)", engine.canonicalKey(tab1, "tables", handler));
+        assertEquals("tables.table(1)", engine.canonicalKey(tab2, "tables", handler));
     }
 
     /**
@@ -337,15 +335,15 @@ public class TestDefaultExpressionEngine {
      */
     @Test
     public void testDefaultSymbols() {
-        assertSame("Wrong default symbols", DefaultExpressionEngineSymbols.DEFAULT_SYMBOLS, engine.getSymbols());
+        assertSame(DefaultExpressionEngineSymbols.DEFAULT_SYMBOLS, engine.getSymbols());
     }
 
     /**
      * Tries to create an instance without symbols.
      */
-    @Test(expected = IllegalArgumentException.class)
+    @Test
     public void testInitNoSymbols() {
-        new DefaultExpressionEngine(null);
+        assertThrows(IllegalArgumentException.class, () -> new DefaultExpressionEngine(null));
     }
 
     /**
@@ -354,9 +352,9 @@ public class TestDefaultExpressionEngine {
     @Test
     public void testNodeKey() {
         final ImmutableNode node = root.getChildren().get(0);
-        assertEquals("Invalid name for descendant of root", "tables", engine.nodeKey(node, "", handler));
-        assertEquals("Parent key not respected", "test.tables", engine.nodeKey(node, "test", handler));
-        assertEquals("Full parent key not taken into account", "a.full.parent.key.tables", engine.nodeKey(node, "a.full.parent.key", handler));
+        assertEquals("tables", engine.nodeKey(node, "", handler));
+        assertEquals("test.tables", engine.nodeKey(node, "test", handler));
+        assertEquals("a.full.parent.key.tables", engine.nodeKey(node, "a.full.parent.key", handler));
     }
 
     /**
@@ -365,7 +363,7 @@ public class TestDefaultExpressionEngine {
     @Test
     public void testNodeKeyWithAlternativeSyntax() {
         setUpAlternativeSyntax();
-        assertEquals("Wrong child key", "tables/table", engine.nodeKey(root.getChildren().get(0).getChildren().get(0), "tables", handler));
+        assertEquals("tables/table", engine.nodeKey(root.getChildren().get(0).getChildren().get(0), "tables", handler));
     }
 
     /**
@@ -378,7 +376,7 @@ public class TestDefaultExpressionEngine {
         final DefaultExpressionEngineSymbols symbols = new DefaultExpressionEngineSymbols.Builder(engine.getSymbols())
             .setAttributeStart(engine.getSymbols().getPropertyDelimiter()).create();
         engine = new DefaultExpressionEngine(symbols);
-        assertEquals("Wrong attribute key", "/test", engine.attributeKey("", "test"));
+        assertEquals("/test", engine.attributeKey("", "test"));
     }
 
     /**
@@ -387,9 +385,8 @@ public class TestDefaultExpressionEngine {
     @Test
     public void testNodeKeyWithEscapedDelimiters() {
         final ImmutableNode node = root.getChildren().get(1);
-        assertEquals("Wrong escaped key", "connection..settings", engine.nodeKey(node, "", handler));
-        assertEquals("Wrong complex escaped key", "connection..settings.usr..name",
-            engine.nodeKey(node.getChildren().get(0), engine.nodeKey(node, "", handler), handler));
+        assertEquals("connection..settings", engine.nodeKey(node, "", handler));
+        assertEquals("connection..settings.usr..name", engine.nodeKey(node.getChildren().get(0), engine.nodeKey(node, "", handler), handler));
     }
 
     /**
@@ -397,8 +394,8 @@ public class TestDefaultExpressionEngine {
      */
     @Test
     public void testNodeKeyWithRoot() {
-        assertEquals("Wrong name for root node", "", engine.nodeKey(root, null, handler));
-        assertEquals("Null name not detected", "test", engine.nodeKey(root, "test", handler));
+        assertEquals("", engine.nodeKey(root, null, handler));
+        assertEquals("test", engine.nodeKey(root, "test", handler));
     }
 
     /**
@@ -407,10 +404,10 @@ public class TestDefaultExpressionEngine {
     @Test
     public void testPrepareAddAttribute() {
         final NodeAddData<ImmutableNode> data = engine.prepareAdd(root, "tables.table(0)[@tableSpace]", handler);
-        assertEquals("Wrong table node", tables[0], data.getParent().getChildren().get(0).getValue());
-        assertEquals("Wrong name of new node", "tableSpace", data.getNewNodeName());
-        assertTrue("Attribute not detected", data.isAttribute());
-        assertTrue("Path nodes available", data.getPathNodes().isEmpty());
+        assertEquals(TABLES[0], data.getParent().getChildren().get(0).getValue());
+        assertEquals("tableSpace", data.getNewNodeName());
+        assertTrue(data.isAttribute());
+        assertTrue(data.getPathNodes().isEmpty());
     }
 
     /**
@@ -419,9 +416,9 @@ public class TestDefaultExpressionEngine {
     @Test
     public void testPrepareAddAttributeRoot() {
         final NodeAddData<ImmutableNode> data = engine.prepareAdd(root, "[@newAttr]", handler);
-        assertSame("Root node is not parent", root, data.getParent());
-        assertEquals("Wrong name of new node", "newAttr", data.getNewNodeName());
-        assertTrue("Attribute not detected", data.isAttribute());
+        assertSame(root, data.getParent());
+        assertEquals("newAttr", data.getNewNodeName());
+        assertTrue(data.isAttribute());
     }
 
     /**
@@ -430,41 +427,42 @@ public class TestDefaultExpressionEngine {
     @Test
     public void testPrepareAddDirectly() {
         NodeAddData<ImmutableNode> data = engine.prepareAdd(root, "newNode", handler);
-        assertSame("Wrong parent node", root, data.getParent());
-        assertTrue("Path nodes available", data.getPathNodes().isEmpty());
-        assertEquals("Wrong name of new node", "newNode", data.getNewNodeName());
-        assertFalse("New node is an attribute", data.isAttribute());
+        assertSame(root, data.getParent());
+        assertTrue(data.getPathNodes().isEmpty());
+        assertEquals("newNode", data.getNewNodeName());
+        assertFalse(data.isAttribute());
 
         data = engine.prepareAdd(root, "tables.table.fields.field.name", handler);
-        assertEquals("Wrong name of new node", "name", data.getNewNodeName());
-        assertTrue("Path nodes available", data.getPathNodes().isEmpty());
-        assertEquals("Wrong parent node", "field", data.getParent().getNodeName());
+        assertEquals("name", data.getNewNodeName());
+        assertTrue(data.getPathNodes().isEmpty());
+        assertEquals("field", data.getParent().getNodeName());
         final ImmutableNode nd = data.getParent().getChildren().get(0);
-        assertEquals("Field has no name node", "name", nd.getNodeName());
-        assertEquals("Incorrect name", "version", nd.getValue());
+        assertEquals("name", nd.getNodeName());
+        assertEquals("version", nd.getValue());
     }
 
-    @Test(expected = IllegalArgumentException.class)
+    @Test
     public void testPrepareAddEmptyKey() {
-        engine.prepareAdd(root, "", handler);
+        assertThrows(IllegalArgumentException.class, () -> engine.prepareAdd(root, "", handler));
     }
 
     /**
      * Tests using invalid keys, e.g. if something should be added to attributes.
      */
-    @Test(expected = IllegalArgumentException.class)
+    @Test
     public void testPrepareAddInvalidKey() {
-        engine.prepareAdd(root, "tables.table(0)[@type].new", handler);
+        assertThrows(IllegalArgumentException.class, () -> engine.prepareAdd(root, "tables.table(0)[@type].new", handler));
     }
 
-    @Test(expected = IllegalArgumentException.class)
+    @Test
     public void testPrepareAddInvalidKeyAttribute() {
-        engine.prepareAdd(root, "a.complete.new.path.with.an[@attribute].at.a.non.allowed[@position]", handler);
+        assertThrows(IllegalArgumentException.class,
+                () -> engine.prepareAdd(root, "a.complete.new.path.with.an[@attribute].at.a.non.allowed[@position]", handler));
     }
 
-    @Test(expected = IllegalArgumentException.class)
+    @Test
     public void testPrepareAddNullKey() {
-        engine.prepareAdd(root, null, handler);
+        assertThrows(IllegalArgumentException.class, () -> engine.prepareAdd(root, null, handler));
     }
 
     /**
@@ -474,8 +472,8 @@ public class TestDefaultExpressionEngine {
     public void testPrepareAddWithAlternativeMatcher() {
         setUpAlternativeMatcher();
         final NodeAddData<ImmutableNode> data = engine.prepareAdd(root, "tables_.table._fields__._field.name", handler);
-        assertEquals("Wrong name of new node", "name", data.getNewNodeName());
-        assertTrue("Path nodes available", data.getPathNodes().isEmpty());
+        assertEquals("name", data.getNewNodeName());
+        assertTrue(data.getPathNodes().isEmpty());
     }
 
     /**
@@ -485,14 +483,14 @@ public class TestDefaultExpressionEngine {
     public void testPrepareAddWithAlternativeSyntax() {
         setUpAlternativeSyntax();
         NodeAddData<ImmutableNode> data = engine.prepareAdd(root, "tables/table[0]/test", handler);
-        assertEquals("Wrong name of new node", "test", data.getNewNodeName());
-        assertFalse("New node is attribute", data.isAttribute());
-        assertEquals("Wrong parent node", tables[0], data.getParent().getChildren().get(0).getValue());
+        assertEquals("test", data.getNewNodeName());
+        assertFalse(data.isAttribute());
+        assertEquals(TABLES[0], data.getParent().getChildren().get(0).getValue());
 
         data = engine.prepareAdd(root, "a/complete/new/path@attr", handler);
-        assertEquals("Wrong name of new attribute", "attr", data.getNewNodeName());
+        assertEquals("attr", data.getNewNodeName());
         checkNodePath(data, "a", "complete", "new", "path");
-        assertSame("Root is not parent", root, data.getParent());
+        assertSame(root, data.getParent());
     }
 
     /**
@@ -501,16 +499,16 @@ public class TestDefaultExpressionEngine {
     @Test
     public void testPrepareAddWithIndex() {
         NodeAddData<ImmutableNode> data = engine.prepareAdd(root, "tables.table(0).tableSpace", handler);
-        assertEquals("Wrong name of new node", "tableSpace", data.getNewNodeName());
-        assertTrue("Path nodes available", data.getPathNodes().isEmpty());
-        assertEquals("Wrong type of parent node", "table", data.getParent().getNodeName());
+        assertEquals("tableSpace", data.getNewNodeName());
+        assertTrue(data.getPathNodes().isEmpty());
+        assertEquals("table", data.getParent().getNodeName());
         final ImmutableNode node = data.getParent().getChildren().get(0);
-        assertEquals("Wrong table", tables[0], node.getValue());
+        assertEquals(TABLES[0], node.getValue());
 
         data = engine.prepareAdd(root, "tables.table(1).fields.field(2).alias", handler);
-        assertEquals("Wrong name of new node", "alias", data.getNewNodeName());
-        assertEquals("Wrong type of parent node", "field", data.getParent().getNodeName());
-        assertEquals("Wrong field node", "creationDate", data.getParent().getChildren().get(0).getValue());
+        assertEquals("alias", data.getNewNodeName());
+        assertEquals("field", data.getParent().getNodeName());
+        assertEquals("creationDate", data.getParent().getChildren().get(0).getValue());
     }
 
     /**
@@ -519,19 +517,19 @@ public class TestDefaultExpressionEngine {
     @Test
     public void testPrepareAddWithPath() {
         NodeAddData<ImmutableNode> data = engine.prepareAdd(root, "tables.table(1).fields.field(-1).name", handler);
-        assertEquals("Wrong name of new node", "name", data.getNewNodeName());
+        assertEquals("name", data.getNewNodeName());
         checkNodePath(data, "field");
-        assertEquals("Wrong type of parent node", "fields", data.getParent().getNodeName());
+        assertEquals("fields", data.getParent().getNodeName());
 
         data = engine.prepareAdd(root, "tables.table(-1).name", handler);
-        assertEquals("Wrong name of new node", "name", data.getNewNodeName());
+        assertEquals("name", data.getNewNodeName());
         checkNodePath(data, "table");
-        assertEquals("Wrong type of parent node", "tables", data.getParent().getNodeName());
+        assertEquals("tables", data.getParent().getNodeName());
 
         data = engine.prepareAdd(root, "a.complete.new.path", handler);
-        assertEquals("Wrong name of new node", "path", data.getNewNodeName());
+        assertEquals("path", data.getNewNodeName());
         checkNodePath(data, "a", "complete", "new");
-        assertSame("Root is not parent", root, data.getParent());
+        assertSame(root, data.getParent());
     }
 
     /**
@@ -545,12 +543,12 @@ public class TestDefaultExpressionEngine {
         engine = new DefaultExpressionEngine(symbols);
 
         NodeAddData<ImmutableNode> data = engine.prepareAdd(root, "tables.table(0).test", handler);
-        assertEquals("Wrong name of new node", "test", data.getNewNodeName());
-        assertFalse("New node is an attribute", data.isAttribute());
-        assertEquals("Wrong type of parent node", "table", data.getParent().getNodeName());
+        assertEquals("test", data.getNewNodeName());
+        assertFalse(data.isAttribute());
+        assertEquals("table", data.getParent().getNodeName());
 
         data = engine.prepareAdd(root, "a.complete.new.path", handler);
-        assertFalse("New node is an attribute", data.isAttribute());
+        assertFalse(data.isAttribute());
         checkNodePath(data, "a", "complete", "new");
     }
 
@@ -560,8 +558,8 @@ public class TestDefaultExpressionEngine {
     @Test
     public void testQueryAlternativeSyntax() {
         setUpAlternativeSyntax();
-        checkKeyValue("tables/table[1]/name", "name", tables[1]);
-        checkAttributeValue("tables/table[0]@type", "type", tabTypes[0]);
+        checkKeyValue("tables/table[1]/name", "name", TABLES[1]);
+        checkAttributeValue("tables/table[0]@type", "type", TAB_TYPES[0]);
         checkAttributeValue("@test", "test", "true");
         checkKeyValue("connection.settings/usr.name", "usr.name", "scott");
     }
@@ -574,8 +572,8 @@ public class TestDefaultExpressionEngine {
         final DefaultExpressionEngineSymbols symbols = new DefaultExpressionEngineSymbols.Builder(DefaultExpressionEngineSymbols.DEFAULT_SYMBOLS)
             .setAttributeEnd(null).setAttributeStart(DefaultExpressionEngineSymbols.DEFAULT_PROPERTY_DELIMITER).create();
         engine = new DefaultExpressionEngine(symbols);
-        checkKeyValue("tables.table(0).name", "name", tables[0]);
-        checkAttributeValue("tables.table(0).type", "type", tabTypes[0]);
+        checkKeyValue("tables.table(0).name", "name", TABLES[0]);
+        checkAttributeValue("tables.table(0).type", "type", TAB_TYPES[0]);
         checkKey("tables.table.type", "type", 2);
     }
 
@@ -615,12 +613,12 @@ public class TestDefaultExpressionEngine {
      */
     @Test
     public void testQueryNodes() {
-        for (int i = 0; i < tables.length; i++) {
-            checkKeyValue("tables.table(" + i + ").name", "name", tables[i]);
-            checkAttributeValue("tables.table(" + i + ")[@type]", "type", tabTypes[i]);
+        for (int i = 0; i < TABLES.length; i++) {
+            checkKeyValue("tables.table(" + i + ").name", "name", TABLES[i]);
+            checkAttributeValue("tables.table(" + i + ")[@type]", "type", TAB_TYPES[i]);
 
-            for (int j = 0; j < fields[i].length; j++) {
-                checkKeyValue("tables.table(" + i + ").fields.field(" + j + ").name", "name", fields[i][j]);
+            for (int j = 0; j < FIELDS[i].length; j++) {
+                checkKeyValue("tables.table(" + i + ").fields.field(" + j + ").name", "name", FIELDS[i][j]);
             }
         }
     }
