@@ -16,14 +16,18 @@
  */
 package org.apache.commons.configuration2.tree;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.assertNotSame;
-import static org.junit.Assert.assertNull;
-import static org.junit.Assert.assertSame;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertInstanceOf;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertNotSame;
+import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.assertSame;
+import static org.junit.jupiter.api.Assertions.assertThrows;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.mockito.ArgumentMatchers.any;
+import static org.mockito.ArgumentMatchers.eq;
+import static org.mockito.Mockito.when;
 
 import java.util.ArrayList;
 import java.util.Arrays;
@@ -37,14 +41,12 @@ import java.util.Map;
 import java.util.Set;
 
 import org.apache.commons.configuration2.ex.ConfigurationRuntimeException;
-import org.easymock.EasyMock;
-import org.junit.Before;
-import org.junit.BeforeClass;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 /**
  * A special test class for {@code InMemoryNodeModel} which tests the facilities for tracking nodes.
- *
  */
 public class TestInMemoryNodeModelTrackedNodes {
     /** Constant for the name of a new table field. */
@@ -69,7 +71,7 @@ public class TestInMemoryNodeModelTrackedNodes {
      * @param idx the index of the changed node
      */
     private static void checkedForChangedField(final ImmutableNode nodeFields, final int idx) {
-        assertEquals("Wrong number of field nodes", NodeStructureHelper.fieldsLength(1), nodeFields.getChildren().size());
+        assertEquals(NodeStructureHelper.fieldsLength(1), nodeFields.getChildren().size());
         int childIndex = 0;
         for (final ImmutableNode field : nodeFields) {
             final String expName = childIndex == idx ? NEW_FIELD : NodeStructureHelper.field(1, childIndex);
@@ -85,11 +87,11 @@ public class TestInMemoryNodeModelTrackedNodes {
      * @param name the expected name of this field
      */
     private static void checkFieldNode(final ImmutableNode nodeField, final String name) {
-        assertEquals("Wrong node name", "field", nodeField.getNodeName());
-        assertEquals("Wrong number of children of field node", 1, nodeField.getChildren().size());
+        assertEquals("field", nodeField.getNodeName());
+        assertEquals(1, nodeField.getChildren().size());
         final ImmutableNode nodeName = nodeField.getChildren().get(0);
-        assertEquals("Wrong name of name node", "name", nodeName.getNodeName());
-        assertEquals("Wrong node value", name, nodeName.getValue());
+        assertEquals("name", nodeName.getNodeName());
+        assertEquals(name, nodeName.getValue());
     }
 
     /**
@@ -98,7 +100,7 @@ public class TestInMemoryNodeModelTrackedNodes {
      * @param nodeFields the fields node
      */
     private static void checkForAddedField(final ImmutableNode nodeFields) {
-        assertEquals("Wrong number of children", NodeStructureHelper.fieldsLength(1) + 1, nodeFields.getChildren().size());
+        assertEquals(NodeStructureHelper.fieldsLength(1) + 1, nodeFields.getChildren().size());
         final ImmutableNode nodeField = nodeFields.getChildren().get(NodeStructureHelper.fieldsLength(1));
         checkFieldNode(nodeField, NEW_FIELD);
     }
@@ -110,7 +112,7 @@ public class TestInMemoryNodeModelTrackedNodes {
      * @param idx the index of the removed field
      */
     private static void checkForRemovedField(final ImmutableNode nodeFields, final int idx) {
-        assertEquals("Field not removed", NodeStructureHelper.fieldsLength(1) - 1, nodeFields.getChildren().size());
+        assertEquals(NodeStructureHelper.fieldsLength(1) - 1, nodeFields.getChildren().size());
         final Set<String> expectedNames = new HashSet<>();
         final Set<String> actualNames = new HashSet<>();
         for (int i = 0; i < NodeStructureHelper.fieldsLength(1); i++) {
@@ -122,7 +124,7 @@ public class TestInMemoryNodeModelTrackedNodes {
             final ImmutableNode nodeName = field.getChildren().get(0);
             actualNames.add(String.valueOf(nodeName.getValue()));
         }
-        assertEquals("Wrong field names", expectedNames, actualNames);
+        assertEquals(expectedNames, actualNames);
     }
 
     /**
@@ -131,22 +133,8 @@ public class TestInMemoryNodeModelTrackedNodes {
      * @return the resolver
      */
     private static NodeKeyResolver<ImmutableNode> createResolver() {
-        return createResolver(true);
-    }
-
-    /**
-     * Creates a default resolver which supports arbitrary queries on a target node and allows specifying the replay flag.
-     * If the boolean parameter is false, the mock is not replayed; so additional behaviors can be defined.
-     *
-     * @param replay the replay flag
-     * @return the resolver mock
-     */
-    private static NodeKeyResolver<ImmutableNode> createResolver(final boolean replay) {
         final NodeKeyResolver<ImmutableNode> resolver = NodeStructureHelper.createResolverMock();
-        NodeStructureHelper.expectResolveKeyForQueries(resolver);
-        if (replay) {
-            EasyMock.replay(resolver);
-        }
+        NodeStructureHelper.prepareResolveKeyForQueries(resolver);
         return resolver;
     }
 
@@ -157,19 +145,17 @@ public class TestInMemoryNodeModelTrackedNodes {
      * @param resolver the {@code NodeKeyResolver} mock
      */
     private static void prepareResolverForUpdateKeys(final NodeKeyResolver<ImmutableNode> resolver) {
-        EasyMock.expect(
-            resolver.resolveUpdateKey(EasyMock.anyObject(ImmutableNode.class), EasyMock.anyString(), EasyMock.anyObject(), EasyMock.anyObject(TreeData.class)))
-            .andAnswer(() -> {
-                final ImmutableNode root = (ImmutableNode) EasyMock.getCurrentArguments()[0];
-                final String key = (String) EasyMock.getCurrentArguments()[1];
-                final TreeData handler = (TreeData) EasyMock.getCurrentArguments()[3];
-                final List<QueryResult<ImmutableNode>> results = DefaultExpressionEngine.INSTANCE.query(root, key, handler);
-                assertEquals("Wrong number of query results", 1, results.size());
-                return new NodeUpdateData<>(Collections.singletonMap(results.get(0), EasyMock.getCurrentArguments()[2]), null, null, null);
-            }).anyTimes();
+        when(resolver.resolveUpdateKey(any(), any(), any(), any())).thenAnswer(invocation -> {
+            final ImmutableNode root = invocation.getArgument(0, ImmutableNode.class);
+            final String key = invocation.getArgument(1, String.class);
+            final TreeData handler = invocation.getArgument(3, TreeData.class);
+            final List<QueryResult<ImmutableNode>> results = DefaultExpressionEngine.INSTANCE.query(root, key, handler);
+            assertEquals(1, results.size());
+            return new NodeUpdateData<>(Collections.singletonMap(results.get(0), invocation.getArgument(2)), null, null, null);
+        });
     }
 
-    @BeforeClass
+    @BeforeAll
     public static void setUpBeforeClass() throws Exception {
         root = new ImmutableNode.Builder(1).addChild(NodeStructureHelper.ROOT_TABLES_TREE).create();
         selector = new NodeSelector(SELECTOR_KEY);
@@ -184,8 +170,8 @@ public class TestInMemoryNodeModelTrackedNodes {
     private void checkReplaceTrackedNode() {
         final ImmutableNode newNode = new ImmutableNode.Builder().name("newNode").create();
         model.replaceTrackedNode(selector, newNode);
-        assertSame("Node not changed", newNode, model.getTrackedNode(selector));
-        assertTrue("Node not detached", model.isTrackedNodeDetached(selector));
+        assertSame(newNode, model.getTrackedNode(selector));
+        assertTrue(model.isTrackedNodeDetached(selector));
     }
 
     /**
@@ -194,13 +180,13 @@ public class TestInMemoryNodeModelTrackedNodes {
      * @param queryResult the result set of the key
      */
     private void checkTrackChildNodesNoResult(final List<ImmutableNode> queryResult) {
-        final NodeKeyResolver<ImmutableNode> resolver = createResolver(false);
-        EasyMock.expect(resolver.resolveNodeKey(root, TEST_KEY, model.getNodeHandler())).andReturn(queryResult);
-        EasyMock.replay(resolver);
+        final NodeKeyResolver<ImmutableNode> resolver = createResolver();
+        when(resolver.resolveNodeKey(root, TEST_KEY, model.getNodeHandler())).thenReturn(queryResult);
+
         final TreeData oldData = model.getTreeData();
 
-        assertTrue("Got selectors", model.trackChildNodes(TEST_KEY, resolver).isEmpty());
-        assertSame("Model was changed", oldData, model.getTreeData());
+        assertTrue(model.trackChildNodes(TEST_KEY, resolver).isEmpty());
+        assertSame(oldData, model.getTreeData());
     }
 
     /**
@@ -209,22 +195,10 @@ public class TestInMemoryNodeModelTrackedNodes {
      * @param queryResult the result set of the key
      */
     private void checkTrackChildNodeWithCreationInvalidKey(final List<ImmutableNode> queryResult) {
-        final NodeKeyResolver<ImmutableNode> resolver = createResolver(false);
-        EasyMock.expect(resolver.resolveNodeKey(model.getRootNode(), TEST_KEY, model.getNodeHandler())).andReturn(queryResult);
-        EasyMock.replay(resolver);
-        model.trackChildNodeWithCreation(TEST_KEY, "someChild", resolver);
-    }
+        final NodeKeyResolver<ImmutableNode> resolver = createResolver();
+        when(resolver.resolveNodeKey(model.getRootNode(), TEST_KEY, model.getNodeHandler())).thenReturn(queryResult);
 
-    /**
-     * Prepares the resolver mock to expect a nodeKey() request.
-     *
-     * @param resolver the {@code NodeKeyResolver}
-     * @param node the node whose name is to be resolved
-     * @param key the key to be returned for this node
-     */
-    private void expectNodeKey(final NodeKeyResolver<ImmutableNode> resolver, final ImmutableNode node, final String key) {
-        final Map<ImmutableNode, String> cache = new HashMap<>();
-        EasyMock.expect(resolver.nodeKey(node, cache, model.getNodeHandler())).andReturn(key);
+        assertThrows(ConfigurationRuntimeException.class, () -> model.trackChildNodeWithCreation(TEST_KEY, "someChild", resolver));
     }
 
     /**
@@ -255,7 +229,19 @@ public class TestInMemoryNodeModelTrackedNodes {
         model.clearTree("tables.table(0)", resolver);
     }
 
-    @Before
+    /**
+     * Prepares the resolver mock to expect a nodeKey() request.
+     *
+     * @param resolver the {@code NodeKeyResolver}
+     * @param node the node whose name is to be resolved
+     * @param key the key to be returned for this node
+     */
+    private void prepareNodeKey(final NodeKeyResolver<ImmutableNode> resolver, final ImmutableNode node, final String key) {
+        final Map<ImmutableNode, String> cache = new HashMap<>();
+        when(resolver.nodeKey(node, cache, model.getNodeHandler())).thenReturn(key);
+    }
+
+    @BeforeEach
     public void setUp() throws Exception {
         model = new InMemoryNodeModel(root);
     }
@@ -265,14 +251,13 @@ public class TestInMemoryNodeModelTrackedNodes {
      */
     @Test
     public void testAddNodesOnDetachedNode() {
-        final NodeKeyResolver<ImmutableNode> resolver = createResolver(false);
-        NodeStructureHelper.expectResolveAddKeys(resolver);
-        EasyMock.replay(resolver);
+        final NodeKeyResolver<ImmutableNode> resolver = createResolver();
+        NodeStructureHelper.prepareResolveAddKeys(resolver);
         model.trackNode(selector, resolver);
         initDetachedNode(resolver);
         final ImmutableNode rootNode = model.getRootNode();
         model.addNodes("fields", selector, Collections.singleton(NodeStructureHelper.createFieldNode(NEW_FIELD)), resolver);
-        assertSame("Root node was changed", rootNode, model.getRootNode());
+        assertSame(rootNode, model.getRootNode());
         checkForAddedField(fieldsNodeFromTrackedNode());
     }
 
@@ -281,9 +266,8 @@ public class TestInMemoryNodeModelTrackedNodes {
      */
     @Test
     public void testAddNodesOnTrackedNode() {
-        final NodeKeyResolver<ImmutableNode> resolver = createResolver(false);
-        NodeStructureHelper.expectResolveAddKeys(resolver);
-        EasyMock.replay(resolver);
+        final NodeKeyResolver<ImmutableNode> resolver = createResolver();
+        NodeStructureHelper.prepareResolveAddKeys(resolver);
         model.trackNode(selector, resolver);
         model.addNodes("fields", selector, Collections.singleton(NodeStructureHelper.createFieldNode(NEW_FIELD)), resolver);
         checkForAddedField(fieldsNodeFromModel());
@@ -295,14 +279,13 @@ public class TestInMemoryNodeModelTrackedNodes {
      */
     @Test
     public void testAddPropertyOnDetachedNode() {
-        final NodeKeyResolver<ImmutableNode> resolver = createResolver(false);
-        NodeStructureHelper.expectResolveAddKeys(resolver);
-        EasyMock.replay(resolver);
+        final NodeKeyResolver<ImmutableNode> resolver = createResolver();
+        NodeStructureHelper.prepareResolveAddKeys(resolver);
         model.trackNode(selector, resolver);
         initDetachedNode(resolver);
         final ImmutableNode rootNode = model.getRootNode();
         model.addProperty("fields.field(-1).name", selector, Collections.singleton(NEW_FIELD), resolver);
-        assertSame("Root node was changed", rootNode, model.getRootNode());
+        assertSame(rootNode, model.getRootNode());
         checkForAddedField(fieldsNodeFromTrackedNode());
     }
 
@@ -311,9 +294,8 @@ public class TestInMemoryNodeModelTrackedNodes {
      */
     @Test
     public void testAddPropertyOnTrackedNode() {
-        final NodeKeyResolver<ImmutableNode> resolver = createResolver(false);
-        NodeStructureHelper.expectResolveAddKeys(resolver);
-        EasyMock.replay(resolver);
+        final NodeKeyResolver<ImmutableNode> resolver = createResolver();
+        NodeStructureHelper.prepareResolveAddKeys(resolver);
         model.trackNode(selector, resolver);
         model.addProperty("fields.field(-1).name", selector, Collections.singleton(NEW_FIELD), resolver);
         checkForAddedField(fieldsNodeFromModel());
@@ -329,7 +311,7 @@ public class TestInMemoryNodeModelTrackedNodes {
         initDetachedNode(resolver);
         final ImmutableNode rootNode = model.getRootNode();
         model.clearProperty("fields.field(0).name", selector, resolver);
-        assertSame("Model root was changed", rootNode, model.getRootNode());
+        assertSame(rootNode, model.getRootNode());
         final ImmutableNode nodeFields = fieldsNodeFromTrackedNode();
         checkForRemovedField(nodeFields, 0);
     }
@@ -355,7 +337,7 @@ public class TestInMemoryNodeModelTrackedNodes {
         initDetachedNode(resolver);
         final ImmutableNode rootNode = model.getRootNode();
         model.clearTree("fields.field(1)", selector, resolver);
-        assertSame("Model root was changed", rootNode, model.getRootNode());
+        assertSame(rootNode, model.getRootNode());
         final ImmutableNode nodeFields = fieldsNodeFromTrackedNode();
         checkForRemovedField(nodeFields, 1);
     }
@@ -381,7 +363,7 @@ public class TestInMemoryNodeModelTrackedNodes {
         final NodeKeyResolver<ImmutableNode> resolver = createResolver();
         model.trackNode(selector, resolver);
         model.clear(resolver);
-        assertSame("Wrong node", node, model.getTrackedNode(selector));
+        assertSame(node, model.getTrackedNode(selector));
     }
 
     /**
@@ -393,7 +375,7 @@ public class TestInMemoryNodeModelTrackedNodes {
         final NodeKeyResolver<ImmutableNode> resolver = createResolver();
         model.trackNode(selector, resolver);
         model.setRootNode(root);
-        assertSame("Wrong node", node, model.getTrackedNode(selector));
+        assertSame(node, model.getTrackedNode(selector));
     }
 
     /**
@@ -405,7 +387,7 @@ public class TestInMemoryNodeModelTrackedNodes {
         model.trackNode(selector, resolver);
         model.clearProperty("tables.table(1).fields.field(1).name", resolver);
         final ImmutableNode node = model.getTrackedNode(selector);
-        assertEquals("Wrong node", NodeStructureHelper.table(1), node.getChildren().get(0).getValue());
+        assertEquals(NodeStructureHelper.table(1), node.getChildren().get(0).getValue());
     }
 
     /**
@@ -416,7 +398,7 @@ public class TestInMemoryNodeModelTrackedNodes {
         final ImmutableNode node = NodeStructureHelper.nodeForKey(model, "tables/table(1)");
         final NodeKeyResolver<ImmutableNode> resolver = createResolver();
         initDetachedNode(resolver);
-        assertSame("Wrong node", node, model.getTrackedNode(selector));
+        assertSame(node, model.getTrackedNode(selector));
     }
 
     /**
@@ -426,7 +408,7 @@ public class TestInMemoryNodeModelTrackedNodes {
     public void testGetTrackedNodeExisting() {
         final ImmutableNode node = NodeStructureHelper.nodeForKey(model, "tables/table(1)");
         model.trackNode(selector, createResolver());
-        assertSame("Wrong node", node, model.getTrackedNode(selector));
+        assertSame(node, model.getTrackedNode(selector));
     }
 
     /**
@@ -437,10 +419,9 @@ public class TestInMemoryNodeModelTrackedNodes {
         final NodeKeyResolver<ImmutableNode> resolver = createResolver();
         model.trackNode(selector, resolver);
         final NodeHandler<ImmutableNode> handler = model.getTrackedNodeHandler(selector);
-        assertTrue("Wrong node handler: " + handler, handler instanceof TrackedNodeHandler);
-        assertSame("Wrong root node", model.getTrackedNode(selector), handler.getRootNode());
-        final TrackedNodeHandler tnh = (TrackedNodeHandler) handler;
-        assertSame("Wrong parent handler", model.getTreeData(), tnh.getParentHandler());
+        final TrackedNodeHandler tnh = assertInstanceOf(TrackedNodeHandler.class, handler);
+        assertSame(model.getTrackedNode(selector), handler.getRootNode());
+        assertSame(model.getTreeData(), tnh.getParentHandler());
     }
 
     /**
@@ -452,17 +433,17 @@ public class TestInMemoryNodeModelTrackedNodes {
         model.trackNode(selector, resolver);
         initDetachedNode(resolver);
         final NodeHandler<ImmutableNode> handler = model.getTrackedNodeHandler(selector);
-        assertSame("Wrong root node", model.getTrackedNode(selector), handler.getRootNode());
-        assertTrue("Wrong handler: " + handler, handler instanceof TreeData);
-        assertNotSame("Shared handler", model.getNodeHandler(), handler);
+        assertSame(model.getTrackedNode(selector), handler.getRootNode());
+        assertInstanceOf(TreeData.class, handler);
+        assertNotSame(model.getNodeHandler(), handler);
     }
 
     /**
      * Tries to obtain a tracked node which is unknown.
      */
-    @Test(expected = ConfigurationRuntimeException.class)
+    @Test
     public void testGetTrackedNodeNonExisting() {
-        model.getTrackedNode(selector);
+        assertThrows(ConfigurationRuntimeException.class, () -> model.getTrackedNode(selector));
     }
 
     /**
@@ -473,7 +454,7 @@ public class TestInMemoryNodeModelTrackedNodes {
         final NodeKeyResolver<ImmutableNode> resolver = createResolver();
         model.trackNode(selector, resolver);
         model.clear(resolver);
-        assertTrue("Node is not detached", model.isTrackedNodeDetached(selector));
+        assertTrue(model.isTrackedNodeDetached(selector));
     }
 
     /**
@@ -485,7 +466,7 @@ public class TestInMemoryNodeModelTrackedNodes {
         model.trackNode(selector, resolver);
         model.clearProperty("tables.table(1).fields.field(1).name", resolver);
         model.setRootNode(root);
-        assertTrue("Node is not detached", model.isTrackedNodeDetached(selector));
+        assertTrue(model.isTrackedNodeDetached(selector));
     }
 
     /**
@@ -496,7 +477,7 @@ public class TestInMemoryNodeModelTrackedNodes {
         final NodeKeyResolver<ImmutableNode> resolver = createResolver();
         model.trackNode(selector, resolver);
         model.clearProperty("tables.table(1).fields.field(1).name", resolver);
-        assertFalse("Node is detached", model.isTrackedNodeDetached(selector));
+        assertFalse(model.isTrackedNodeDetached(selector));
     }
 
     /**
@@ -506,7 +487,7 @@ public class TestInMemoryNodeModelTrackedNodes {
     public void testIsDetachedFalseNoUpdates() {
         final NodeKeyResolver<ImmutableNode> resolver = createResolver();
         model.trackNode(selector, resolver);
-        assertFalse("Node is detached", model.isTrackedNodeDetached(selector));
+        assertFalse(model.isTrackedNodeDetached(selector));
     }
 
     /**
@@ -516,7 +497,7 @@ public class TestInMemoryNodeModelTrackedNodes {
     public void testIsDetachedTrue() {
         final NodeKeyResolver<ImmutableNode> resolver = createResolver();
         initDetachedNode(resolver);
-        assertTrue("Node is not detached", model.isTrackedNodeDetached(selector));
+        assertTrue(model.isTrackedNodeDetached(selector));
     }
 
     /**
@@ -543,10 +524,10 @@ public class TestInMemoryNodeModelTrackedNodes {
     /**
      * Tries to replace a tracked node with a null node.
      */
-    @Test(expected = IllegalArgumentException.class)
+    @Test
     public void testReplaceTrackedNodeNull() {
         model.trackNode(selector, createResolver());
-        model.replaceTrackedNode(selector, null);
+        assertThrows(IllegalArgumentException.class, () -> model.replaceTrackedNode(selector, null));
     }
 
     /**
@@ -554,25 +535,25 @@ public class TestInMemoryNodeModelTrackedNodes {
      */
     @Test
     public void testSelectAndTrackNodes() {
-        final NodeKeyResolver<ImmutableNode> resolver = createResolver(false);
+        final NodeKeyResolver<ImmutableNode> resolver = createResolver();
         final String nodeKey1 = "tables/table(0)";
         final String nodeKey2 = "tables/table(1)";
         final ImmutableNode node1 = NodeStructureHelper.nodeForKey(root, nodeKey1);
         final ImmutableNode node2 = NodeStructureHelper.nodeForKey(root, nodeKey2);
-        EasyMock.expect(resolver.resolveNodeKey(root, TEST_KEY, model.getNodeHandler())).andReturn(Arrays.asList(node1, node2));
-        expectNodeKey(resolver, node1, nodeKey1);
-        expectNodeKey(resolver, node2, nodeKey2);
-        EasyMock.replay(resolver);
+
+        when(resolver.resolveNodeKey(root, TEST_KEY, model.getNodeHandler())).thenReturn(Arrays.asList(node1, node2));
+        prepareNodeKey(resolver, node1, nodeKey1);
+        prepareNodeKey(resolver, node2, nodeKey2);
 
         final Collection<NodeSelector> selectors = model.selectAndTrackNodes(TEST_KEY, resolver);
         final Iterator<NodeSelector> it = selectors.iterator();
         NodeSelector sel = it.next();
-        assertEquals("Wrong selector 1", new NodeSelector(nodeKey1), sel);
-        assertSame("Wrong tracked node 1", node1, model.getTrackedNode(sel));
+        assertEquals(new NodeSelector(nodeKey1), sel);
+        assertSame(node1, model.getTrackedNode(sel));
         sel = it.next();
-        assertEquals("Wrong selector 2", new NodeSelector(nodeKey2), sel);
-        assertSame("Wrong tracked node 2", node2, model.getTrackedNode(sel));
-        assertFalse("Too many selectors", it.hasNext());
+        assertEquals(new NodeSelector(nodeKey2), sel);
+        assertSame(node2, model.getTrackedNode(sel));
+        assertFalse(it.hasNext());
     }
 
     /**
@@ -582,17 +563,17 @@ public class TestInMemoryNodeModelTrackedNodes {
     public void testSelectAndTrackNodesNodeAlreadyTracked() {
         NodeKeyResolver<ImmutableNode> resolver = createResolver();
         model.trackNode(selector, resolver);
-        resolver = createResolver(false);
+        resolver = createResolver();
         final ImmutableNode node = model.getTrackedNode(selector);
-        EasyMock.expect(resolver.resolveNodeKey(root, TEST_KEY, model.getNodeHandler())).andReturn(Collections.singletonList(node));
-        expectNodeKey(resolver, node, SELECTOR_KEY);
-        EasyMock.replay(resolver);
+
+        when(resolver.resolveNodeKey(root, TEST_KEY, model.getNodeHandler())).thenReturn(Collections.singletonList(node));
+        prepareNodeKey(resolver, node, SELECTOR_KEY);
 
         final Collection<NodeSelector> selectors = model.selectAndTrackNodes(TEST_KEY, resolver);
-        assertEquals("Wrong number of selectors", 1, selectors.size());
-        assertEquals("Wrong selector", selector, selectors.iterator().next());
+        assertEquals(1, selectors.size());
+        assertEquals(selector, selectors.iterator().next());
         model.untrackNode(selector);
-        assertSame("Node not tracked", node, model.getTrackedNode(selector));
+        assertSame(node, model.getTrackedNode(selector));
     }
 
     /**
@@ -600,11 +581,11 @@ public class TestInMemoryNodeModelTrackedNodes {
      */
     @Test
     public void testSelectAndTrackNodesNoSelection() {
-        final NodeKeyResolver<ImmutableNode> resolver = createResolver(false);
-        EasyMock.expect(resolver.resolveNodeKey(root, TEST_KEY, model.getNodeHandler())).andReturn(Collections.<ImmutableNode>emptyList());
-        EasyMock.replay(resolver);
+        final NodeKeyResolver<ImmutableNode> resolver = createResolver();
 
-        assertTrue("Got selectors", model.selectAndTrackNodes(TEST_KEY, resolver).isEmpty());
+        when(resolver.resolveNodeKey(root, TEST_KEY, model.getNodeHandler())).thenReturn(Collections.<ImmutableNode>emptyList());
+
+        assertTrue(model.selectAndTrackNodes(TEST_KEY, resolver).isEmpty());
     }
 
     /**
@@ -612,14 +593,13 @@ public class TestInMemoryNodeModelTrackedNodes {
      */
     @Test
     public void testSetPropertyOnDetachedNode() {
-        final NodeKeyResolver<ImmutableNode> resolver = createResolver(false);
+        final NodeKeyResolver<ImmutableNode> resolver = createResolver();
         prepareResolverForUpdateKeys(resolver);
-        EasyMock.replay(resolver);
         model.trackNode(selector, resolver);
         initDetachedNode(resolver);
         final ImmutableNode rootNode = model.getRootNode();
         model.setProperty("fields.field(0).name", selector, NEW_FIELD, resolver);
-        assertSame("Root node of model was changed", rootNode, model.getRootNode());
+        assertSame(rootNode, model.getRootNode());
         checkedForChangedField(fieldsNodeFromTrackedNode(), 0);
     }
 
@@ -628,9 +608,8 @@ public class TestInMemoryNodeModelTrackedNodes {
      */
     @Test
     public void testSetPropertyOnTrackedNode() {
-        final NodeKeyResolver<ImmutableNode> resolver = createResolver(false);
+        final NodeKeyResolver<ImmutableNode> resolver = createResolver();
         prepareResolverForUpdateKeys(resolver);
-        EasyMock.replay(resolver);
         model.trackNode(selector, resolver);
         model.setProperty("fields.field(0).name", selector, NEW_FIELD, resolver);
         checkedForChangedField(fieldsNodeFromModel(), 0);
@@ -642,23 +621,23 @@ public class TestInMemoryNodeModelTrackedNodes {
      */
     @Test
     public void testTrackChildNodes() {
-        final NodeKeyResolver<ImmutableNode> resolver = createResolver(false);
+        final NodeKeyResolver<ImmutableNode> resolver = createResolver();
         final ImmutableNode node = NodeStructureHelper.nodeForKey(root, "tables");
         final String[] keys = new String[node.getChildren().size()];
+
         for (int i = 0; i < keys.length; i++) {
             final ImmutableNode child = node.getChildren().get(i);
             keys[i] = String.format("%s.%s(%d)", node.getNodeName(), child.getNodeName(), i);
-            expectNodeKey(resolver, child, keys[i]);
+            prepareNodeKey(resolver, child, keys[i]);
         }
-        EasyMock.expect(resolver.resolveNodeKey(root, TEST_KEY, model.getNodeHandler())).andReturn(Collections.singletonList(node));
-        EasyMock.replay(resolver);
+        when(resolver.resolveNodeKey(root, TEST_KEY, model.getNodeHandler())).thenReturn(Collections.singletonList(node));
 
         final Collection<NodeSelector> selectors = model.trackChildNodes(TEST_KEY, resolver);
-        assertEquals("Wrong number of selectors", node.getChildren().size(), selectors.size());
+        assertEquals(node.getChildren().size(), selectors.size());
         int idx = 0;
         for (final NodeSelector sel : selectors) {
-            assertEquals("Wrong selector", new NodeSelector(keys[idx]), sel);
-            assertEquals("Wrong tracked node for " + sel, node.getChildren().get(idx), model.getTrackedNode(sel));
+            assertEquals(new NodeSelector(keys[idx]), sel);
+            assertEquals(node.getChildren().get(idx), model.getTrackedNode(sel), "Wrong tracked node for " + sel);
             idx++;
         }
     }
@@ -693,25 +672,25 @@ public class TestInMemoryNodeModelTrackedNodes {
      */
     @Test
     public void testTrackChildNodeWithCreationExisting() {
-        final NodeKeyResolver<ImmutableNode> resolver = createResolver(false);
+        final NodeKeyResolver<ImmutableNode> resolver = createResolver();
         final String childName = "name";
         final String parentKey = "tables/table(0)";
         final String childKey = parentKey + "/" + childName;
         final ImmutableNode node = NodeStructureHelper.nodeForKey(model, parentKey);
         final ImmutableNode child = NodeStructureHelper.nodeForKey(node, childName);
-        EasyMock.expect(resolver.resolveNodeKey(root, TEST_KEY, model.getNodeHandler())).andReturn(Collections.singletonList(node));
-        expectNodeKey(resolver, child, childKey);
-        EasyMock.replay(resolver);
+
+        when(resolver.resolveNodeKey(root, TEST_KEY, model.getNodeHandler())).thenReturn(Collections.singletonList(node));
+        prepareNodeKey(resolver, child, childKey);
 
         final NodeSelector childSelector = model.trackChildNodeWithCreation(TEST_KEY, childName, resolver);
-        assertEquals("Wrong selector", new NodeSelector(childKey), childSelector);
-        assertSame("Wrong tracked node", child, model.getTrackedNode(childSelector));
+        assertEquals(new NodeSelector(childKey), childSelector);
+        assertSame(child, model.getTrackedNode(childSelector));
     }
 
     /**
      * Tests trackChildNodeWithCreation() if the passed in key selects multiple nodes.
      */
-    @Test(expected = ConfigurationRuntimeException.class)
+    @Test
     public void testTrackChildNodeWithCreationMultipleResults() {
         final List<ImmutableNode> nodes = Arrays.asList(NodeStructureHelper.nodeForKey(root, "tables/table(0)"),
             NodeStructureHelper.nodeForKey(root, "tables/table(1)"));
@@ -723,30 +702,29 @@ public class TestInMemoryNodeModelTrackedNodes {
      */
     @Test
     public void testTrackChildNodeWithCreationNonExisting() {
-        final NodeKeyResolver<ImmutableNode> resolver = createResolver(false);
+        final NodeKeyResolver<ImmutableNode> resolver = createResolver();
         final String childName = "space";
         final String parentKey = "tables/table(0)";
         final String childKey = parentKey + "/" + childName;
         final ImmutableNode node = NodeStructureHelper.nodeForKey(model, parentKey);
-        EasyMock.expect(resolver.resolveNodeKey(root, TEST_KEY, model.getNodeHandler())).andReturn(Collections.singletonList(node));
-        EasyMock.expect(resolver.nodeKey(EasyMock.anyObject(ImmutableNode.class), EasyMock.eq(new HashMap<>()), EasyMock.anyObject(TreeData.class)))
-            .andReturn(childKey);
-        EasyMock.replay(resolver);
+
+        when(resolver.resolveNodeKey(root, TEST_KEY, model.getNodeHandler())).thenReturn(Collections.singletonList(node));
+        when(resolver.nodeKey(any(), eq(new HashMap<>()), any())).thenReturn(childKey);
 
         final NodeSelector childSelector = model.trackChildNodeWithCreation(TEST_KEY, childName, resolver);
-        assertEquals("Wrong selector", new NodeSelector(childKey), childSelector);
+        assertEquals(new NodeSelector(childKey), childSelector);
         final ImmutableNode child = model.getTrackedNode(childSelector);
-        assertEquals("Wrong child name", childName, child.getNodeName());
-        assertNull("Got a value", child.getValue());
+        assertEquals(childName, child.getNodeName());
+        assertNull(child.getValue());
         final ImmutableNode parent = model.getNodeHandler().getParent(child);
-        assertEquals("Wrong parent node", "table", parent.getNodeName());
-        assertEquals("Wrong node path", child, NodeStructureHelper.nodeForKey(model, childKey));
+        assertEquals("table", parent.getNodeName());
+        assertEquals(child, NodeStructureHelper.nodeForKey(model, childKey));
     }
 
     /**
      * Tests trackChildNodeWithCreation() if the passed in key does not select a node.
      */
-    @Test(expected = ConfigurationRuntimeException.class)
+    @Test
     public void testTrackChildNodeWithCreationNoResults() {
         checkTrackChildNodeWithCreationInvalidKey(new ArrayList<>());
     }
@@ -760,26 +738,30 @@ public class TestInMemoryNodeModelTrackedNodes {
         final NodeKeyResolver<ImmutableNode> resolver = createResolver();
         model.trackNode(selector, resolver);
         model.clearTree(null, selector, resolver);
-        assertTrue("Node not detached", model.isTrackedNodeDetached(selector));
+        assertTrue(model.isTrackedNodeDetached(selector));
         final ImmutableNode node = model.getTrackedNode(selector);
-        assertEquals("Name was changed", "table", node.getNodeName());
-        assertFalse("Node is defined", model.getNodeHandler().isDefined(node));
+        assertEquals("table", node.getNodeName());
+        assertFalse(model.getNodeHandler().isDefined(node));
     }
 
     /**
      * Tries to call trackNode() with a key that selects multiple results.
      */
-    @Test(expected = ConfigurationRuntimeException.class)
+    @Test
     public void testTrackNodeKeyMultipleResults() {
-        model.trackNode(new NodeSelector("tables.table.fields.field.name"), createResolver());
+        final NodeSelector nodeSelector = new NodeSelector("tables.table.fields.field.name");
+        final NodeKeyResolver<ImmutableNode> resolver = createResolver();
+        assertThrows(ConfigurationRuntimeException.class, () -> model.trackNode(nodeSelector, resolver));
     }
 
     /**
      * Tries to call trackNode() with a key that does not yield any results.
      */
-    @Test(expected = ConfigurationRuntimeException.class)
+    @Test
     public void testTrackNodeKeyNoResults() {
-        model.trackNode(new NodeSelector("tables.unknown"), createResolver());
+        final NodeSelector nodeSelector = new NodeSelector("tables.unknown");
+        final NodeKeyResolver<ImmutableNode> resolver = createResolver();
+        assertThrows(ConfigurationRuntimeException.class, () -> model.trackNode(nodeSelector, resolver));
     }
 
     /**
@@ -791,7 +773,7 @@ public class TestInMemoryNodeModelTrackedNodes {
         model.trackNode(selector, resolver);
         model.trackNode(selector, resolver);
         model.untrackNode(selector);
-        assertNotNull("No tracked node", model.getTrackedNode(selector));
+        assertNotNull(model.getTrackedNode(selector));
     }
 
     /**
@@ -801,19 +783,14 @@ public class TestInMemoryNodeModelTrackedNodes {
     public void testUntrackNode() {
         model.trackNode(selector, createResolver());
         model.untrackNode(selector);
-        try {
-            model.getTrackedNode(selector);
-            fail("Could get untracked node!");
-        } catch (final ConfigurationRuntimeException crex) {
-            // expected
-        }
+        assertThrows(ConfigurationRuntimeException.class, () -> model.getTrackedNode(selector));
     }
 
     /**
      * Tries to stop tracking of a node which is not tracked.
      */
-    @Test(expected = ConfigurationRuntimeException.class)
+    @Test
     public void testUntrackNodeNonExisting() {
-        model.untrackNode(selector);
+        assertThrows(ConfigurationRuntimeException.class, () -> model.untrackNode(selector));
     }
 }
