@@ -16,24 +16,24 @@
  */
 package org.apache.commons.configuration2.tree;
 
-import static org.junit.Assert.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertThrows;
+import static org.mockito.Mockito.mock;
 
 import java.util.LinkedList;
 import java.util.List;
 
-import org.easymock.EasyMock;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 /**
  * Test class for {@code NodeTreeWalker}.
- *
  */
 public class TestNodeTreeWalker {
     /**
      * A visitor implementation used for testing purposes. The visitor produces a list with the names of the nodes visited
      * in the order it was called. With this it can be tested whether the nodes were visited in the correct order.
      */
-    private static class TestVisitor implements ConfigurationNodeVisitor<ImmutableNode> {
+    private static final class TestVisitor implements ConfigurationNodeVisitor<ImmutableNode> {
         /** A list with the names of the visited nodes. */
         private final List<String> visitedNodes = new LinkedList<>();
 
@@ -97,8 +97,9 @@ public class TestNodeTreeWalker {
      *
      * @return the handler mock
      */
+    @SuppressWarnings("unchecked")
     private static NodeHandler<ImmutableNode> handlerMock() {
-        return EasyMock.createMock(NodeHandler.class);
+        return mock(NodeHandler.class);
     }
 
     /**
@@ -116,8 +117,9 @@ public class TestNodeTreeWalker {
      *
      * @return the visitor mock
      */
+    @SuppressWarnings("unchecked")
     private static ConfigurationNodeVisitor<ImmutableNode> visitorMock() {
-        return EasyMock.createMock(ConfigurationNodeVisitor.class);
+        return mock(ConfigurationNodeVisitor.class);
     }
 
     /**
@@ -177,7 +179,7 @@ public class TestNodeTreeWalker {
         final List<String> expected = expectBFS();
         final TestVisitor visitor = new TestVisitor();
         NodeTreeWalker.INSTANCE.walkBFS(NodeStructureHelper.ROOT_AUTHORS_TREE, visitor, createHandler());
-        assertEquals("Wrong visited nodes", expected, visitor.getVisitedNodes());
+        assertEquals(expected, visitor.getVisitedNodes());
     }
 
     /**
@@ -187,7 +189,6 @@ public class TestNodeTreeWalker {
     public void testWalkBFSNoNode() {
         final ConfigurationNodeVisitor<ImmutableNode> visitor = visitorMock();
         final NodeHandler<ImmutableNode> handler = handlerMock();
-        EasyMock.replay(visitor, handler);
         NodeTreeWalker.INSTANCE.walkBFS(null, visitor, handler);
     }
 
@@ -200,7 +201,7 @@ public class TestNodeTreeWalker {
         final int nodeCount = 9;
         visitor.setMaxNodeCount(nodeCount);
         NodeTreeWalker.INSTANCE.walkBFS(NodeStructureHelper.ROOT_AUTHORS_TREE, visitor, createHandler());
-        assertEquals("Wrong number of visited nodes", nodeCount, visitor.getVisitedNodes().size());
+        assertEquals(nodeCount, visitor.getVisitedNodes().size());
     }
 
     /**
@@ -211,7 +212,7 @@ public class TestNodeTreeWalker {
         final List<String> expected = expectDFS();
         final TestVisitor visitor = new TestVisitor();
         NodeTreeWalker.INSTANCE.walkDFS(NodeStructureHelper.ROOT_AUTHORS_TREE, visitor, createHandler());
-        assertEquals("Wrong visited nodes", expected, visitor.getVisitedNodes());
+        assertEquals(expected, visitor.getVisitedNodes());
     }
 
     /**
@@ -221,7 +222,6 @@ public class TestNodeTreeWalker {
     public void testWalkDFSNoNode() {
         final ConfigurationNodeVisitor<ImmutableNode> visitor = visitorMock();
         final NodeHandler<ImmutableNode> handler = handlerMock();
-        EasyMock.replay(visitor, handler);
         NodeTreeWalker.INSTANCE.walkDFS(null, visitor, handler);
     }
 
@@ -234,22 +234,24 @@ public class TestNodeTreeWalker {
         final int nodeCount = 5;
         visitor.setMaxNodeCount(nodeCount);
         NodeTreeWalker.INSTANCE.walkDFS(NodeStructureHelper.ROOT_AUTHORS_TREE, visitor, createHandler());
-        assertEquals("Wrong number of visited nodes", nodeCount, visitor.getVisitedNodes().size());
+        assertEquals(nodeCount, visitor.getVisitedNodes().size());
     }
 
     /**
      * Tries a walk() operation without a node handler.
      */
-    @Test(expected = IllegalArgumentException.class)
+    @Test
     public void testWalkNoNodeHandler() {
-        NodeTreeWalker.INSTANCE.walkDFS(NodeStructureHelper.ROOT_AUTHORS_TREE, new TestVisitor(), null);
+        final TestVisitor visitor = new TestVisitor();
+        assertThrows(IllegalArgumentException.class, () -> NodeTreeWalker.INSTANCE.walkDFS(NodeStructureHelper.ROOT_AUTHORS_TREE, visitor, null));
     }
 
     /**
      * Tries a walk operation without a visitor.
      */
-    @Test(expected = IllegalArgumentException.class)
+    @Test
     public void testWalkNoVisitor() {
-        NodeTreeWalker.INSTANCE.walkDFS(NodeStructureHelper.ROOT_AUTHORS_TREE, null, createHandler());
+        final NodeHandler<ImmutableNode> handler = createHandler();
+        assertThrows(IllegalArgumentException.class, () -> NodeTreeWalker.INSTANCE.walkDFS(NodeStructureHelper.ROOT_AUTHORS_TREE, null, handler));
     }
 }
