@@ -16,9 +16,10 @@
  */
 package org.apache.commons.configuration2.tree.xpath;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertTrue;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertThrows;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 
 import java.util.Locale;
 
@@ -26,12 +27,11 @@ import org.apache.commons.configuration2.tree.ImmutableNode;
 import org.apache.commons.jxpath.ri.QName;
 import org.apache.commons.jxpath.ri.model.NodeIterator;
 import org.apache.commons.jxpath.ri.model.NodePointer;
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 /**
  * Test class for {@code ConfigurationNodePointer}.
- *
  */
 public class TestConfigurationNodePointer extends AbstractXPathTest {
     /** Stores the node pointer to be tested. */
@@ -45,25 +45,25 @@ public class TestConfigurationNodePointer extends AbstractXPathTest {
     private void checkIterators(final NodePointer p) {
         final ImmutableNode node = (ImmutableNode) p.getNode();
         NodeIterator it = p.childIterator(null, false, null);
-        assertEquals("Iterator count differs from children count", node.getChildren().size(), iteratorSize(it));
+        assertEquals(node.getChildren().size(), iteratorSize(it));
 
         for (int index = 1; it.setPosition(index); index++) {
             final NodePointer pchild = it.getNodePointer();
-            assertEquals("Wrong child", node.getChildren().get(index - 1), pchild.getNode());
+            assertEquals(node.getChildren().get(index - 1), pchild.getNode());
             checkIterators(pchild);
         }
 
         it = p.attributeIterator(new QName(null, "*"));
-        assertEquals("Iterator count differs from attribute count", node.getAttributes().size(), iteratorSize(it));
+        assertEquals(node.getAttributes().size(), iteratorSize(it));
         for (int index = 1; it.setPosition(index); index++) {
             final NodePointer pattr = it.getNodePointer();
-            assertTrue("Node pointer is no attribute", pattr.isAttribute());
-            assertTrue("Wrong attribute name", node.getAttributes().containsKey(pattr.getName().getName()));
+            assertTrue(pattr.isAttribute());
+            assertTrue(node.getAttributes().containsKey(pattr.getName().getName()));
         }
     }
 
     @Override
-    @Before
+    @BeforeEach
     public void setUp() throws Exception {
         super.setUp();
         pointer = new ConfigurationNodePointer<>(root, Locale.getDefault(), handler);
@@ -79,8 +79,8 @@ public class TestConfigurationNodePointer extends AbstractXPathTest {
         final ImmutableNode n2 = new ImmutableNode.Builder().name("n2").create();
         final NodePointer p1 = new ConfigurationNodePointer<>(pointer, n1, handler);
         final NodePointer p2 = new ConfigurationNodePointer<>(pointer, n2, handler);
-        assertEquals("Incorrect order", 0, pointer.compareChildNodePointers(p1, p2));
-        assertEquals("Incorrect symmetric order", 0, pointer.compareChildNodePointers(p2, p1));
+        assertEquals(0, pointer.compareChildNodePointers(p1, p2));
+        assertEquals(0, pointer.compareChildNodePointers(p2, p1));
     }
 
     /**
@@ -90,8 +90,8 @@ public class TestConfigurationNodePointer extends AbstractXPathTest {
     public void testCompareChildNodePointersChildren() {
         final NodePointer p1 = new ConfigurationNodePointer<>(pointer, root.getChildren().get(1), handler);
         final NodePointer p2 = new ConfigurationNodePointer<>(pointer, root.getChildren().get(3), handler);
-        assertEquals("Incorrect order", -1, pointer.compareChildNodePointers(p1, p2));
-        assertEquals("Incorrect symmetric order", 1, pointer.compareChildNodePointers(p2, p1));
+        assertEquals(-1, pointer.compareChildNodePointers(p1, p2));
+        assertEquals(1, pointer.compareChildNodePointers(p2, p1));
     }
 
     /**
@@ -99,7 +99,7 @@ public class TestConfigurationNodePointer extends AbstractXPathTest {
      */
     @Test
     public void testIsAttribute() {
-        assertFalse("Node is an attribute", pointer.isAttribute());
+        assertFalse(pointer.isAttribute());
     }
 
     /**
@@ -109,7 +109,7 @@ public class TestConfigurationNodePointer extends AbstractXPathTest {
     public void testIsLeafTrue() {
         final ImmutableNode leafNode = new ImmutableNode.Builder().name("leafNode").create();
         pointer = new ConfigurationNodePointer<>(pointer, leafNode, handler);
-        assertTrue("Not a leaf node", pointer.isLeaf());
+        assertTrue(pointer.isLeaf());
     }
 
     /**
@@ -117,7 +117,7 @@ public class TestConfigurationNodePointer extends AbstractXPathTest {
      */
     @Test
     public void testIsLeave() {
-        assertFalse("Root node is leaf", pointer.isLeaf());
+        assertFalse(pointer.isLeaf());
     }
 
     /**
@@ -131,8 +131,8 @@ public class TestConfigurationNodePointer extends AbstractXPathTest {
     /**
      * Tests that no new value can be set.
      */
-    @Test(expected = UnsupportedOperationException.class)
+    @Test
     public void testSetValue() {
-        pointer.setValue("newValue");
+        assertThrows(UnsupportedOperationException.class, () -> pointer.setValue("newValue"));
     }
 }
