@@ -17,6 +17,7 @@
 
 package org.apache.commons.configuration2.web;
 
+import static org.junit.jupiter.api.Assertions.assertFalse;
 import static org.junit.jupiter.api.Assertions.assertThrows;
 
 import java.util.Enumeration;
@@ -91,4 +92,11 @@ public class TestServletFilterConfiguration extends TestAbstractConfiguration {
     public void testClearProperty() {
         assertThrows(UnsupportedOperationException.class, super::testClearProperty);
     }
+
+    @Override
+    @Test
+    public void testContainsValue() {
+        assertFalse(getConfiguration().containsValue(null));
+        assertFalse(getConfiguration().containsValue(""));
+    }
 }
